/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 09522
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1988
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\09522-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cigtry    91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW'
                  98='(98) BLANK' ;
  VALUE cigrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) One to five cigarettes a day'
                  3='(3) About 1/2 pack a day(6-15 cigarettes)'
                  4='(4) About a pack a day(16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day(26-35 cigarettes)'
                  6='(6) About 2 packs or more a day(over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cigtime   91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigint    1='(1) Years' 2='(2) Months' 3='(3) Weeks' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DONT KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigage    91='(91) NEVER USED CIGARETTES' 93='(93) NEVER SMOKED DAILY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigyrs    91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day(6-15 cigarettes)'
                  3='(3) About a pack a day(16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day(26-35 cigarettes)'
                  5='(5) About 2 packs or more a day(over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snufrec   1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 94='(94) DONT KNOW' 98='(98) BLANK' ;
  VALUE snuffreq  1='(1) Daily' 2='(2) Almost daily (3-6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month(25-31 days a year)'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a year)'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  91='(91) NEVER USED SMOKELESS TOBACCO'
                  93='(93) DID NOT USE SMOKELESS TOBACCO IN PAST 12 MONTHS'
                  95='(95) BAD DATA' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctry    91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcpref   1='(1) Beer' 2='(2) Wine' 3='(3) Liquor' 4='(4) It varies'
                  91='(91) NEVER USED ALCOHOL' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcdays   91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   90='(90) 90 or more drinks per day past 30 days'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   90='(90) 90 or more drinks in one day in past 30 days'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcage    91='(91) NEVER USED ALCOHOL' 92='(92) ILLEGIBLE'
                  93='(93) NEVER USED ALCOHOL MONTHLY OR MORE OFTEN'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) Never got very high or drunk in past 12 months'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTHS'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alctran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alccoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alchal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE alcnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN PAST 12 MONTHS' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE restoril  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   122='(122) Sleep Aid' 123='(123) Unisom' 124='(124) Yellow jackets'
                  127='(127) Nytol' 134='(134) Diasetan' 136='(136) Dimetapp' 137='(137) 7-14'
                  201='(201) Valium' 228='(228) Amitriptyline' 326='(326) White cross'
                  339='(339) Amphetamines (speed)' 401='(401) Darvon' 406='(406) Percodan'
                  407='(407) Demerol' 426='(426) Fiorinal' 427='(427) Darvocet' 435='(435) Tylenol'
                  991='(991) NEVER USED SEDATIVES' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   123='(123) Unisom' 327='(327) Black Beauty, Black beauties'
                  991='(991) NEVER USED SEDATIVES' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednosp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED SEDATIVES'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedalc    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedtr     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedst     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedan     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedmj     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedcoc    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedhal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as3read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE limbtrol  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE menrium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE centrax   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE paxipam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buspar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE deprol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE durrax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    116='(116) Methaqualone (including Sopor, Quaalude)'
                  224='(224) Triavil' 225='(225) Desyrel' 227='(227) Thorazine' 418='(418) Methadone'
                  991='(991) NEVER USED TRANQUILIZERS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnosp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tralc     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trsed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trstm     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trmj      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trcoc     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trhal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tropt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnone    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZER IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as4read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mazanor   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  326='(326) White cross' 327='(327) Black Beauty, Black beauties'
                  328='(328) Pink hearts' 330='(330) Blue Birds, Blue Jays' 331='(331) Whites'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  333='(333) 357 Magnum, Magnum 44' 334='(334) Cross tops, Crossroads'
                  335='(335) Dexatrim' 336='(336) Diet pills' 337='(337) White Molly'
                  338='(338) Antiadipositum' 339='(339) Amphetamines (speed)'
                  340='(340) Tiamina 250' 343='(343) Nitroglycerine' 344='(344) Bennies'
                  345='(345) Black Molly' 346='(346) Ephedrine Sulfate' 348='(348) Crystal'
                  349='(349) Phentametrazine' 350='(350) Betin SS' 351='(351) Qat' 352='(352) Lemons'
                  991='(991) NEVER USED STIMULANTS' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  327='(327) Black Beauty, Black beauties'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  337='(337) White Molly' 341='(341) Pink roses'
                  347='(347) Phenylpropanolamine' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  328='(328) Pink hearts' 329='(329) Speckled Eggs, Robins Eggs'
                  342='(342) Purple hearts' 991='(991) NEVER USED STIMULANTS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  329='(329) Speckled Eggs, Robins Eggs'
                  991='(991) NEVER USED STIMULANTS' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnosp  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stalc     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stsed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sttran    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stanal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmj      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stcoc     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sthal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stopt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stnone    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANT IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stneedle  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stndlrec  1='(1) Within the past month(30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED STIMULANTS'
                  93='(93) NEVER USED AMPHETAMINES WITH A NEEDLE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as5read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wygesic   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phencod   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwinnx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talacen   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anilerid  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stadol    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  229='(229) Librax' 326='(326) White cross' 422='(422) Motrin' 423='(423) Percocet'
                  424='(424) Fioricet' 427='(427) Darvocet' 428='(428) Execl' 429='(429) Frost'
                  433='(433) Paregoric' 434='(434) Vicodin' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  424='(424) Fioricet' 991='(991) NEVER USED ANALGESICS'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE anlnosp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlalc    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlsed    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anltran   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlstm    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlmj     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlcoc    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlhal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESIC IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     91='(91) NEVER HAD CHANCE TO TRY MARIJUANA' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjage     91='(91) NEVER USED MARIJUANA' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED MARIJUANA'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  91='(91) NEVER USED MARIJUANA' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   91='(91) NEVER USED MARIJUANA' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) Less than 10 joints in the past 30 days'
                  2='(2) 10 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  7='(7) Unspecified but > 6 ounces in the past 30 days'
                  8='(8) 7 ounces' 10='(10) 10 ounces' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjalc30a  1='(1) Always drank alcohol when used marijuana'
                  2='(2) More than half the time' 3='(3) About half the time'
                  4='(4) Less than half the time' 5='(5) One or two times'
                  6='(6) NEVER DRANK ALCOHOL W/MARIJUANA IN PAST'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 30 DAYS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjyrfreq  1='(1) Several times a day' 2='(2) Daily'
                  3='(3) Almost daily (3 to 6 days a week)'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 days)'
                  6='(6) 1 to 2 times a month (12 to 24 days a year)'
                  7='(7) Every other month or so (6 to 11 days a year)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjalc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjsed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjtran    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjstm     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjanal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjcoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjhal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjopt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE mjnone    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN PAST 12 MONTHS' ;
  VALUE as7read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK' ;
  VALUE inhage    91='(91) NEVER USED INHALANTS' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE inhnewa   339='(339) Amphetamines (speed)' 511='(511) Markers, Felt-tip pens'
                  512='(512) Rush, Incense' 513='(513) Tulio' 515='(515) Vicks' 516='(516) Freon'
                  518='(518) Nail Polish' 519='(519) Helium' 805='(805) Cocaine, Coke'
                  991='(991) NEVER USED INHALANTS' 995='(995) BAD DATA' 998='(998) BLANK' ;
  VALUE inhnewb   511='(511) Markers, Felt-tip pens' 991='(991) NEVER USED INHALANTS'
                  995='(995) BAD DATA' 998='(998) BLANK' ;
  VALUE inhnosp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED INHALANTS'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE innew30a  511='(511) Markers, Felt-tip pens' 512='(512) Rush, Incense'
                  516='(516) Freon' 519='(519) Helium' 805='(805) Cocaine, Coke'
                  991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANT IN PAST 30 DAYS' 995='(995) BAD DATA'
                  998='(998) BLANK' ;
  VALUE innew30b  339='(339) Amphetamines (speed)' 991='(991) NEVER USED INHALANTS'
                  993='(993) DID NOT USE INHALANT IN PAST 30 DAYS' 995='(995) BAD DATA'
                  998='(998) BLANK' ;
  VALUE in30nosp  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANT IN PAST 30 DAYS' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE inhdy30a  91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inheff    1='(1) Enough to feel it a little' 2='(2) Enough to feel it a lot'
                  3='(3) Enough to get high'
                  4='(4) Enough so that you staggered or dropped'
                  5='(5) Enough to feel you were going to pass out'
                  6='(6) Something else - unspecified'
                  7='(7) Didnt feel it, didnt use much'
                  8='(8) Sniffed out of curiosity once'
                  9='(9) Enough to make eyes water' 10='(10) Enough for a headrush'
                  11='(11) Just enough to say I did it - no feeling'
                  12='(12) Didnt feel it just like the smell'
                  91='(91) NEVER USED INHALANTS' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 91='(91) NEVER USED INHALANTS' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc1f  1='(1) QUESTION 1 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc2f  2='(2) QUESTION 2 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc3f  3='(3) QUESTION 3 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc4f  4='(4) QUESTION 4 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc5f  5='(5) QUESTION 5 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc6f  6='(6) QUESTION 6 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc7f  7='(7) QUESTION 7 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc8f  8='(8) QUESTION 8 NOT CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc9f  9='(9) ALL QUESTIONS WERE CLEAR' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE cocopp    91='(91) NEVER HAD A CHANCE TO TRY COCAINE' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocage    91='(91) NEVER USED COCAINE' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED COCAINE' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  91='(91) NEVER USED COCAINE' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coc30alc  1='(1) Always drank alcohol when used cocaine'
                  2='(2) More than half the time' 3='(3) About half the time'
                  4='(4) Less than half the time' 5='(5) One or two times'
                  6='(6) Never drank alcohol w/cocaine in past 30 days'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 95='(95) BAD DATA' ;
  VALUE cocyrfrq  1='(1) Daily' 2='(2) Almost daily (3 to 6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocalc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coctran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Joint use of these two drugs LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cochal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsniff  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA' ;
  VALUE cocswal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA' ;
  VALUE cociv     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' ;
  VALUE freebase  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA' ;
  VALUE cocnewa   6='(6) Lasing joints and bongs' 7='(7) On my gums'
                  8='(8) Freeze, put on tongue, etc' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnosp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS' 95='(95) BAD DATA' ;
  VALUE condlrec  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED COCAINE'
                  93='(93) NEVER USED COCAINE WITH A NEEDLE'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkam30a  993='(993) DID NOT USE CRACK IN PAST 30 DAYS' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE crakbuck  9993='(9993) DID NOT USE CRACK IN PAST 30 DAYS' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE cocam30a  1='(1) Less than 1/4 gram (about 4 big lines) past 30 days'
                  2='(2) About 1/4 gram in the past 30 days'
                  3='(3) About 1/2 gram in the past 30 days'
                  4='(4) About 1 gram in the past 30 days'
                  5='(5) About 2 grams in the past 30 days'
                  6='(6) About 3 grams in the past 30 days'
                  7='(7) Unspecified but >3 grams in past 30 days'
                  8='(8) 4 grams in the past 30 days'
                  9='(9) 5 grams in the past 30 days'
                  10='(10) 7 grams in the past 30 days'
                  11='(11) 8 grams in the past 30 days'
                  12='(12) 14 grams in the past 30 days'
                  13='(13) 28 grams in the past 30 days' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocbuck   9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN PAST 30 DAYS' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE as9read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   609='(609) Jimson Weed' 610='(610) Crystal T'
                  612='(612) Happy Stick, Shermstick' 613='(613) Duckweed' 614='(614) MDA'
                  615='(615) Homemade drugs' 616='(616) DMT' 617='(617) Morning glory seeds'
                  703='(703) Opium' 802='(802) THC, Cannabinol'
                  991='(991) NEVER USED HALLUCINOGENS' 995='(995) BAD DATA' 998='(998) BLANK' ;
  VALUE halnosp   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   91='(91) NEVER HAD A CHANCE TO TRY HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallage   91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED HALLUCINOGENS'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  91='(91) NEVER USED HALLUCINOGENS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpflash  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction when used PCP'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpsense  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction when used PCP'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpfeelv  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction when used PCP'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpactv   1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction when used PCP'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnewa   6='(6) Never had any reaction when used PCP' 7='(7) Paranoid'
                  8='(8) Numbness' 9='(9) Like an acid high' 10='(10) Trouble walking'
                  11='(11) Felt weak, full of laughter'
                  12='(12) Sat in a chair and looked like a zombie'
                  13='(13) Knocked out, passed out' 14='(14) Energetic'
                  16='(16) Things were moving' 17='(17) Felt really funny, weird'
                  18='(18) Didnt want to drive' 19='(19) Talking and speeding'
                  20='(20) Hallucination' 21='(21) Felt sick - headache'
                  23='(23) Day after effects - lasted too long' 24='(24) Memory loss'
                  25='(25) Panic' 27='(27) Heightened awareness' 28='(28) In a dream world'
                  30='(30) Felt like you were dying' 31='(31) Enjoyed the trip'
                  32='(32) Got sick' 33='(33) A foot above the ground'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnewb   6='(6) Never had a reaction when used PCP'
                  21='(21) Felt sick - headache' 22='(22) Alive' 25='(25) Panic'
                  27='(27) Heightened awareness' 29='(29) Crying spells'
                  34='(34) High on life' 35='(35) Things slowed down'
                  36='(36) Relaxed and happy' 91='(91) NEVER USED PCP' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnewc   6='(6) Never had any reaction to PCP'
                  13='(13) Knocked out, passed out' 26='(26) Dizziness'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnosp   1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction when used PCP'
                  91='(91) NEVER USED PCP' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnorct  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED PCP' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallqcl   1='(1) Yes' 2='(2) No/Not Sure' 98='(98) BLANK' ;
  VALUE as10read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE heropp    91='(91) NEVER HAD A CHANCE TO TRY HEROIN' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    91='(91) NEVER USED HEROIN' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED HEROIN' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOCIGALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  91='(91) NEVER USED HEROIN' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes, have used heroin with a needle'
                  2='(2) No, have used heroin, but not with a needle'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hrndlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago' 91='(91) NEVER USED HEROIN'
                  93='(93) NEVER USED HEROIN WITH A NEEDLE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as11read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE nodrugs   1='(1) Response circled' 2='(2) Response not circled' 95='(95) BAD DATA' ;
  VALUE cdcig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdsed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdtran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdcoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdhall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not try to cut down on any drug in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdnone    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE efftran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effhall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not need more of any drug used for same effect'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE effnone   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaycig   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayalc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaysed   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaytran  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaystm   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayanal  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaymj    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayinh   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaycoc   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayhall  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayher   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udayoth   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not use any drug daily in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE udaynone  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depcig    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depalc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depsed    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE deptran   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depstm    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depanal   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depmj     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depinh    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depcoc    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dephall   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depher    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depothop  1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depnone   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wscig     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsalc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wssed     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wstran    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsstm     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsanal    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsmj      1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsinh     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wscoc     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wshall    1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsher     1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsothop   1='(1) Response circled' 2='(2) Response not circled'
                  13='(13) Did not have withdrawal symptoms in past year'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wsnone    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE shrndlmo  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE nrshrndl  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cleanndl  1='(1) Threw away needle and syringe after use'
                  2='(2) Boiled works after use'
                  3='(3) Disinfected works with bleach'
                  4='(4) Disinfected works with alcohol'
                  5='(5) Washed works with water(fresh from tap)'
                  6='(6) Rinsed works with water other users did not use'
                  7='(7) Rinsed works with water other users may have used'
                  8='(8) Some other method - NOT SPECIFIED'
                  9='(9) Did not clean works, but did reuse them'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE shrwmale  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE shrwsexp  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE shrwrace  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rsnnoshr  1='(1) Concern about hepatitis' 2='(2) Concern about AIDS'
                  3='(3) Concern about infections'
                  4='(4) Own needle works better or is in better condition'
                  5='(5) Nobody you use with shares'
                  6='(6) Somebody else would break or abuse your needle'
                  7='(7) Youve just never shared needles'
                  8='(8) Some other method - NOT SPECIFIED'
                  9='(9) Do not like needles, dont like to stick myself'
                  10='(10) Didnt want to'
                  11='(11) It is stupid, horrifying, screws up life'
                  12='(12) Reformed drug user' 13='(13) Alone'
                  14='(14) Know what needle can do, could never do that'
                  15='(15) Never had a needle'
                  91='(91) DID NOT USE DRUGS IN PAST 30 DAYS' 92='(92) ILLEGIBLE'
                  93='(93) DID NOT USE NEEDLES IN PAST 30 DAYS' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SHRNDLMO = 1, 99)' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled'
                  95='(95) BAD DATA (Past yr alcohol use recorded elsewhere)' ;
  VALUE alcaggr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcargum  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcabsnt  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alchigh   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcjob    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcmatcd  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrelcd  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcfrdcd  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alctoss   1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcholic  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcdrunk  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcintox  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcrem    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcquick  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcmorn   1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcshook  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcalone  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcbrkpm  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled' 95='(95) BAD DATA' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  209='(209) Xanax' 322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 401='(401) Darvon'
                  409='(409) Tylenol with Codeine'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE depdrg5a  702='(702) Heroin' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE argdrg1a  113='(113) Halcion' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg2a  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  702='(702) Heroin' 805='(805) Cocaine, Coke' 809='(809) Pills' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg4a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE argdrg5a  702='(702) Heroin' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alndrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg2a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg3a  702='(702) Heroin' 805='(805) Cocaine, Coke' 807='(807) Alcohol' 809='(809) Pills'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg4a  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE alndrg5a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 702='(702) Heroin'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE anxdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  208='(208) Centrax' 309='(309) Didrex' 313='(313) Fastin' 315='(315) Voranil'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  339='(339) Amphetamines (speed)' 401='(401) Darvon'
                  409='(409) Tylenol with Codeine' 415='(415) Codeine'
                  509='(509) Correction fluids, degreasers, cleaning'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 618='(618) Acid paper'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg2a  201='(201) Valium' 312='(312) Ionamin' 313='(313) Fastin'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 348='(348) Crystal' 418='(418) Methadone'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg3a  209='(209) Xanax' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)' 702='(702) Heroin' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 809='(809) Pills' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg4a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdrg5a  702='(702) Heroin' 803='(803) Marijuana' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamine (speed)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  811='(811) Muscle relaxers' 813='(813) Cigarettes, Tobacco'
                  814='(814) Caffeine' 995='(995) BAD DATA' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg2a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg4a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE hltdrg5a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ntkdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)' 409='(409) Tylenol with Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  509='(509) Correction fluids, degreasers, cleaning'
                  601='(601) LSD (acid, white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg2a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 348='(348) Crystal' 415='(415) Codeine'
                  418='(418) Methadone' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg4a  221='(221) OTHER Tranquilizer, NOT SPECIFID'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ntkdrg5a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE upsdrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg2a  201='(201) Valium' 312='(312) Ionamin'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 315='(315) Voranil'
                  339='(339) Amphetamines (speed)' 702='(702) Heroin' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg4a  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 702='(702) Heroin'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE upsdrg5a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lswdrg1a  201='(201) Valium' 322='(322) Methamphetamine (speed or crank)'
                  348='(348) Crystal' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  425='(425) Advil' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 613='(613) Duckweed'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 812='(812) Cigars' 813='(813) Cigarettes, Tobacco'
                  995='(995) BAD DATA' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg2a  418='(418) Methadone' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg3a  339='(339) Amphetamines (speed)' 805='(805) Cocaine, Coke' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg4a  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  807='(807) Alcohol' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE lswdrg5a  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE sspdrg1a  201='(201) Valium' 307='(307) Tenuate' 318='(318) Ritalin'
                  322='(322) Methamphetamine (speed or crank)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg2a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  418='(418) Methadone' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg3a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg4a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  803='(803) Marijuana' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE sspdrg5a  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cpedrg1a  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg2a  315='(315) Voranil' 348='(348) Crystal'
                  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg3a  339='(339) Amphetamines (speed)' 604='(604) Psilocybin (mushrooms)'
                  702='(702) Heroin' 805='(805) Cocaine, Coke' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg4a  702='(702) Heroin' 807='(807) Alcohol' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cpedrg5a  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE emdrg1a   120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 995='(995) BAD DATA'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg2a   803='(803) Marijuana' 805='(805) Cocaine, Coke' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg3a   702='(702) Heroin' 805='(805) Cocaine, Coke' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg4a   998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE emdrg5a   998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcrkocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  10='(10) Something else (NOT SPECIFIED)'
                  11='(11) Unable to work - taking care of ill relatives'
                  12='(12) About to start work'
                  13='(13) Contracts for work (eg.sician)' 14='(14) Welfare (AFDC)'
                  15='(15) Out of work - Termination - Injury'
                  16='(16) Just got out of school'
                  17='(17) Just returned to United States' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE paymo     91='(91) NEVER WORKED FOR PAY' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE payyr     91='(91) NEVER WORKED FOR PAY' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE no5job    92='(92) ILLEGIBLE' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (NOT SPECIFIED)' 3='(3) No one'
                  4='(4) Spouse' 5='(5) Live-in partner, fiance' 6='(6) Mother'
                  7='(7) Father' 8='(8) Daughter' 9='(9) Son' 10='(10) Sister' 11='(11) Brother'
                  12='(12) Grandmother' 13='(13) Grandfather'
                  14='(14) Other female blood relative'
                  15='(15) Other male blood relative' 16='(16) Mother-in-law'
                  17='(17) Father-in-law' 18='(18) Other female in-law'
                  19='(19) Other male in-law' 20='(20) Close female friend'
                  21='(21) Close male friend' 22='(22) Other female acquaintance'
                  23='(23) Other male acquaintance, ex-husband' 24='(24) Step-mother'
                  25='(25) Step-father' 28='(28) Friend (sex unspecified)'
                  29='(29) Foster son' 31='(31) Parents (unspecified)'
                  32='(32) Foster mother, female guardian'
                  33='(33) Foster father, male guardian'
                  34='(34) Guardian (sex unspecified)' 35='(35) Grandparents'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE schplans  1='(1) Has plans to enroll in a school in future'
                  2='(2) Has completed all schooling' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE schdays   95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skipped   95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE miles     99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE' 99994='(99994) DONT KNOW'
                  99995='(99995) BAD DATA' 99996='(99996) MULTIPLE RESPONSE' 99997='(99997) REFUSED'
                  99998='(99998) BLANK (NO ANSWER)' 99999='(99999) LEGITIMATE SKIP' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE nochild   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mother    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' ;
  VALUE stepmom   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' ;
  VALUE father    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' ;
  VALUE stepdad   0='(0) No' 1='(1) Yes' 97='(97) REFUSED' ;
  VALUE spouse    0='(0) No' 1='(1) Yes' 97='(97) REFUSED' ;
  VALUE inlaw     93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED' ;
  VALUE ownchild  93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED' ;
  VALUE stepchld  97='(97) REFUSED' ;
  VALUE brosis    93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED' ;
  VALUE othrel    93='(93) RELATION INDICATED, NO COUNT RECORDED' 97='(97) REFUSED' ;
  VALUE friends   97='(97) REFUSED' ;
  VALUE othernon  97='(97) REFUSED' ;
  VALUE service   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   1='(1) On extended active duty in the Armed Forces'
                  2='(2) In a Reserves component'
                  3='(3) Separated/retired from Reserves or active duty'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE movdaway  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE dorm      94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE milbase   94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hosp      94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE telno     95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE income    1='(1) No personal earnings' 2='(2) Yearly under $5,000'
                  3='(3) Yearly $5,000 to $6,999' 4='(4) Yearly $7,000 to $8,999'
                  5='(5) Yearly $9,000 to $11,999' 6='(6) Yearly $12,000 to $14,999'
                  7='(7) Yearly $15,000 to $19,999' 8='(8) Yearly $20,000 to $24,999'
                  9='(9) Yearly $25,000 to $29,999'
                  10='(10) Yearly $30,000 to $39,999'
                  11='(11) Yearly $40,000 to $50,000'
                  12='(12) Yearly more than $50,000' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE bap       1='(1) AM' 2='(2) PM' ;
  VALUE eap       1='(1) AM' 2='(2) PM' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' ;
  VALUE undint    1='(1) No difficulty-no language or reading problem'
                  2='(2) Just a little difficulty-almost no lang/readg prob'
                  3='(3) Fair amount of difficulty-some lang/readg prob'
                  4='(4) A lot of difficulty-considerable lang/readg prob'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able to overhear'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of the time'
                  7='(7) Serious interruptions more than half the time'
                  9='(9) Constant presence of other person(s)' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE spres     2='(2) Response Circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE parpres   3='(3) Response Circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oarpres   4='(4) Response Circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oapres    5='(5) Response Circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cpres     6='(6) Response Circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresspa  8='(8) Friend (unspecified sex or age)'
                  9='(9) Female friend (age unspecified)'
                  10='(10) Male friend (age unspecified)'
                  11='(11) Female relative (age unspecified)'
                  12='(12) Male relative (age unspecified)' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE opresspb  9='(9) Female friend (age unspecified)'
                  12='(12) Male relative (age unspecified)' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresnsp  7='(7) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE iiage     1='(1) Age calculated from questionnaire'
                  2='(2) Age taken from screener' 3='(3) Age imputed' ;
  VALUE agegr     1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE oragegr   1='(1) Age Group taken from questionnaire'
                  2='(2) Age Group taken from screener' ;
  VALUE sex       1='(1) Male' 2='(2) Female' ;
  VALUE orsex     1='(1) Sex taken from questionnaire'
                  2='(2) Sex taken from screener' ;
  VALUE irrace    1='(1) American Indian or Alaskan Native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race taken from questionnaire' 2='(2) Race imputed' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Not Hispanic' ;
  VALUE iihoind   1='(1) Hispanic Origin taken from questionnaire'
                  2='(2) Hispanic Origin imputed' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  9='(9) Non-Hispanic' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questionnaire'
                  2='(2) Hispanic-Origin Group imputed' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE ircocrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irotbrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 years ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE ircrkrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past year'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past year' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE race      1='(1) White' 2='(2) Black' 3='(3) Hispanic' 4='(4) Other' ;
  VALUE educcat   1='(1) Less than high school (EDUC = 0-11)'
                  2='(2) High school graduate (EDUC = 12)'
                  3='(3) Some college (EDUC = 13-15)'
                  4='(4) College graduate (EDUC = 16-17)' ;
  VALUE empstat   1='(1) Full-time' 2='(2) Part-time' 3='(3) Unemployed' 4='(4) Other' ;
  VALUE smokcok   0='(0) No' 1='(1) Yes' ;
  VALUE condlrcf  1='(1) Within past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  7='(7) Never used cocaine with a needle' ;
  VALUE halflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE halyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE halmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE pcpflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE pcpyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE pcpmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE stmflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE stmyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE stmmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE sedflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE sedyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE sedmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE trqflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE trqyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE trqmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE anlflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE anlyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE anlmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE alcflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE alcyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE alcmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE cigflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE cigyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE cigmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE smkflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE smkyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE smkmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE herflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE heryr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE hermon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE mrjflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE mrjyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE mrjmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE cocflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE cocyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE cocmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE crkflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE crkyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE crkmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE inhflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE inhyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE inhmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago but less than 10 years ago'
                  6='(6) 10 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK' ;
  VALUE nedflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE nedyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE cocyrf    0='(0) Never used or did not use in past year'
                  1='(1) Any use within the past year' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year'
                  1='(1) Used monthly or more often past year' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past year'
                  1='(1) Used weekly or more often past year' ;
  VALUE alcyrf    0='(0) Never used or not used in past year'
                  1='(1) Any use within the past year' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRALCFQ = 6-9)'
                  1='(1) Used monthly or more often past year (IRALCFQ = 1-5)' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past year'
                  1='(1) Used weekly or more in past year' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year'
                  1='(1) Any use within the past year' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year'
                  1='(1) Used monthly or more in past year' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year'
                  1='(1) Used weekly or more in past year' ;
  VALUE psyflagf  0='(0) Never used' 1='(1) Ever used' ;
  VALUE psyyr2ff  0='(0) Did not use within past year' 1='(1) Used in past year' ;
  VALUE psymon2f  0='(0) Did not use in past month' 1='(1) Used in past month' ;
  VALUE sumflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE sumyr     0='(0) Did not use in past year' 1='(1) Used in past year' ;
  VALUE summon    0='(0) Did not use in past month' 1='(1) Used in past month' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anoth illicit drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug pastyr'
                  1='(1) Marijuana is only (illicit) drug in pastyr' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past month'
                  1='(1) Marijuana only (illicit) drug in past mo' ;
  VALUE cweocc2f  990='(990) OCCUPATION NOT REPORTED' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  990='(990) OCCUPATION NOT REPORTED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  990='(990) INDUSTRY NOT REPORTED' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE cwebus2f  990='(990) INDUSTRY NOT REPORTED' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE popden    1='(1) 1,000,000 or more in metropolitan area'
                  2='(2) 50,000 to 999,999 in metropolitan area'
                  3='(3) Not a metropolitan area' ;
  VALUE mrjmon2f  1='(1) Did not use in past month'
                  2='(2) Used within the past month' ;
  VALUE alcmon2f  1='(1) Did not use in the past month'
                  2='(2) Used within the past month' ;
  VALUE cigmon2f  1='(1) Did not use in past month' 2='(2) Used within past month' ;
  VALUE lsd2ffff  0='(0) Never used hallucinogens' 1='(1) Ever used LSD' ;
  VALUE peyote2f  0='(0) Never used hallucinogens' 1='(1) Ever used Peyote' ;
  VALUE mesc2fff  0='(0) Never used hallucinogens' 1='(1) Ever used Mescaline' ;
  VALUE psilcy2f  0='(0) Never used hallucinogens' 1='(1) Ever used Psilocybin' ;
  VALUE gas2ffff  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE sppaintf  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE aeros2ff  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE glue2fff  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE solventf  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE amylnitf  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE ether2ff  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE nitoxidf  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE cleflu2f  0='(0) Never inhaled' 1='(1) Ever inhaled' ;
  VALUE cocsni0f  0='(0) Never/no use in past 12 months'
                  1='(1) Sniffed/snorted in past 12 months' ;
  VALUE freebasf  0='(0) Never/no use past 12 months (FREEBASE= 2, 91, 93)'
                  1='(1) Freebased in past 12 months (FREEBASE = 1)' ;
  VALUE cocswalf  0='(0) Never/no use in past 12 months (COCSWAL='
                  1='(1) Swallowed/drank in past 12 months' ;
  VALUE cociv2ff  0='(0) Never/no use in past 12 months'
                  1='(1) Injected in the past 12 months' ;
  VALUE cocnewaf  0='(0) Never/no use in past 12 months'
                  1='(1) Used other ways past 12 months' ;
  VALUE mjtot2ff  1='(1) Never used marijuana' 2='(2) 1-2 times' 3='(3) 3-10 times'
                  4='(4) 11-99 times' 5='(5) 100 or more times' 6='(6) Unknown' ;
  VALUE coctot2f  1='(1) Never used cocaine' 2='(2) 1-2 times' 3='(3) 3-10 times'
                  4='(4) 11-99 times' 5='(5) 100 or more times' 6='(6) Unknown' ;
  VALUE mjtot3ff  1='(1) 1-2 times' 2='(2) 3-10 times' 3='(3) 11-99 times'
                  4='(4) 100 or more times' 5='(5) Never used marijuana' ;
  VALUE coctot3f  1='(1) 1-2 times' 2='(2) 3-10 times' 3='(3) 11-99 times'
                  4='(4) 100 or more times' 5='(5) Never used cocaine' ;
  VALUE mjdy30af  1='(1) None or never used marijuana' 2='(2) 1-2 days' 3='(3) 3-4 days'
                  4='(4) 5-19 days' 5='(5) 20-30 days' 6='(6) Unknown' ;
  VALUE alcdaysf  1='(1) None or never used alcohol' 2='(2) 1-2 days' 3='(3) 3-4 days'
                  4='(4) 5-19 days' 5='(5) 20-30 days' ;
  VALUE racesex   1='(1) White male' 2='(2) Black male' 3='(3) Hispanic male'
                  4='(4) White female' 5='(5) Black female' 6='(6) Hispanic female' ;
  VALUE notmarj   0='(0) No' 1='(1) Yes' ;
  VALUE educcatf  1='(1) Less than high school (CATAGE > 1 and ED'
                  2='(2) High school graduate (CATAGE > 1 and EDU'
                  3='(3) Some college' 4='(4) College graduate' ;
  VALUE empstatf  1='(1) Full-time' 2='(2) Part-time' 3='(3) Unemployed' 4='(4) Other' ;
  VALUE mjdy300f  1='(1) 1-2 days' 2='(2) 3-4 days' 3='(3) 5-19 days' 4='(4) 20-30 days'
                  5='(5) None or never used marijuana' ;
  VALUE alcday0f  1='(1) None or never used alcohol' 2='(2) 1-4 days' 3='(3) 5-19 days'
                  4='(4) 20-30 days' ;
  VALUE drinker   0='(0) Never/no use alcohol in past 30 days'
                  1='(1) Used alcohol in past 30 days' ;
  VALUE hvydrk    0='(0) Never/no hvy use' 1='(1) Heavy alcohol use' ;
  VALUE avcig2ff  1='(1) None or never smoked cigarettes'
                  2='(2) Currently smoke < a pack per day'
                  3='(3) Currently smoke a pack or more per day' ;
  VALUE irdep     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irarg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iraln     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iranx     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irhlt     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irntk     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irups     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irlsw     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irssp     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE ircpe     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iremg     1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irdep1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  209='(209) Xanax' 322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 401='(401) Darvon'
                  409='(409) Tylenol with Codeine'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irdep3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep4ff  510='(510) OTHER Inhalant, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irdep5ff  702='(702) Heroin' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg1ff  113='(113) Halcion' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg2ff  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  702='(702) Heroin' 805='(805) Cocaine, Coke' 809='(809) Pills'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irarg4ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irarg5ff  702='(702) Heroin' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln2ff  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln3ff  702='(702) Heroin' 805='(805) Cocaine, Coke' 807='(807) Alcohol' 809='(809) Pills'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iraln4ff  510='(510) OTHER INHALANT, NOT SPECIFIED' 803='(803) MARIJUANA'
                  807='(807) ALCOHOL' 999='(999) LEGITIMATE SKIP' ;
  VALUE iraln5ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 702='(702) HEROIN'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  208='(208) Centrax' 309='(309) Didrex' 313='(313) Fastin' 315='(315) Voranil'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  339='(339) Amphetamines (speed)' 401='(401) Darvon'
                  409='(409) Tylenol with Codeine' 415='(415) Codeine'
                  509='(509) Correction fluids, degreasers, cleaning'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 618='(618) Acid paper'
                  702='(702) Heroin' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  806='(806) Crack' 807='(807) Alcohol' 812='(812) Cigars'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx2ff  201='(201) Valium' 312='(312) Ionamin' 313='(313) Fastin'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 348='(348) Crystal' 418='(418) Methadone'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx3ff  209='(209) Xanax' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)' 702='(702) Heroin' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 807='(807) Alcohol' 809='(809) Pills'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iranx4ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE iranx5ff  702='(702) Heroin' 803='(803) Marijuana' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamine (speed)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  811='(811) Muscle relaxers' 813='(813) Cigarettes, Tobacco'
                  814='(814) Caffeine' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt2ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  809='(809) Pills' 813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt4ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irhlt5ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)' 409='(409) Tylenol with Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  509='(509) Correction fluids, degreasers, cleaning'
                  601='(601) LSD (acid, white lightning)' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk2ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  339='(339) Amphetamines (speed)' 348='(348) Crystal' 415='(415) Codeine'
                  418='(418) Methadone' 607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  803='(803) Marijuana' 804='(804) Hashish' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irntk4ff  221='(221) OTHER Tranquilizer, NOT SPECIFID'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irntk5ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 208='(208) Centrax'
                  322='(322) Methamphetamine (speed or crank)'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  332='(332) Ephedrine, Caffeine, No-Doz, Vivarin'
                  339='(339) Amphetamines (speed)' 418='(418) Methadone'
                  601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 811='(811) Muscle relaxers'
                  813='(813) Cigarettes, Tobacco' 815='(815) Coffee' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irups2ff  201='(201) Valium' 312='(312) Ionamin'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 315='(315) Voranil'
                  339='(339) Amphetamines (speed)' 702='(702) Heroin' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups4ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 702='(702) Heroin'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irups5ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw1ff  201='(201) Valium' 322='(322) Methamphetamine (speed or crank)'
                  348='(348) Crystal' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  425='(425) Advil' 601='(601) LSD (acid, white lightning)'
                  605='(605) PCP (angel dust, phencyclidine)' 613='(613) Duckweed'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 812='(812) Cigars' 813='(813) Cigarettes, Tobacco'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw2ff  418='(418) Methadone' 803='(803) Marijuana' 805='(805) Cocaine, Coke'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw3ff  339='(339) Amphetamines (speed)' 805='(805) Cocaine, Coke'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw4ff  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irlsw5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp1ff  201='(201) Valium' 307='(307) Tenuate' 318='(318) Ritalin'
                  322='(322) Methamphetamine (speed or crank)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp2ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  418='(418) Methadone' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp3ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 807='(807) Alcohol'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE irssp4ff  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  803='(803) Marijuana' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE irssp5ff  324='(324) OTHER Stimulant, NOT SPECIFIED, Uppers'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers' 201='(201) Valium'
                  312='(312) Ionamin' 322='(322) Methamphetamine (speed or crank)'
                  339='(339) Amphetamines (speed)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) Marijuana' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 808='(808) All of the ones Ive tried'
                  813='(813) Cigarettes, Tobacco' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe2ff  315='(315) Voranil' 348='(348) Crystal'
                  601='(601) LSD (acid, white lightning)' 803='(803) Marijuana'
                  805='(805) Cocaine, Coke' 806='(806) Crack' 807='(807) Alcohol'
                  813='(813) Cigarettes, Tobacco' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe3ff  339='(339) Amphetamines (speed)' 604='(604) Psilocybin (mushrooms)'
                  702='(702) Heroin' 805='(805) Cocaine, Coke' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe4ff  702='(702) Heroin' 807='(807) Alcohol' 999='(999) LEGITIMATE SKIP' ;
  VALUE ircpe5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg1ff  120='(120) OTHER Sedative, NOT SPECIFIED,Downers'
                  339='(339) Amphetamines (speed)' 805='(805) Cocaine, Coke' 806='(806) Crack'
                  807='(807) Alcohol' 813='(813) Cigarettes, Tobacco' 998='(998) BLANK'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg2ff  803='(803) Marijuana' 805='(805) Cocaine, Coke' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg3ff  702='(702) Heroin' 805='(805) Cocaine, Coke' 999='(999) LEGITIMATE SKIP' ;
  VALUE iremg4ff  999='(999) LEGITIMATE SKIP' ;
  VALUE iremg5ff  999='(999) LEGITIMATE SKIP' ;
  VALUE anyprob   0='(0) No' 1='(1) Yes' ;
  VALUE twoprob   0='(0) No' 1='(1) Yes' ;
  VALUE threprob  0='(0) No' 1='(1) Yes' ;
  VALUE depcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE depalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE depmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE depcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE argalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE argmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE argcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncig2f  0='(0) No' 1='(1) Yes' ;
  VALUE alnalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE alnmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE alncoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE anxcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE hltcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE ntkcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscig2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE upsmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE upscoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE lswcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcig2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspalc2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspmrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE sspcoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecig2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpealc2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpemrj2f  0='(0) No' 1='(1) Yes' ;
  VALUE cpecoc2f  0='(0) No' 1='(1) Yes' ;
  VALUE emcig2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emalc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emmrj2ff  0='(0) No' 1='(1) Yes' ;
  VALUE emcoc2ff  0='(0) No' 1='(1) Yes' ;
  VALUE prb1cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb1alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb1mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb1coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb2alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb2mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb2coc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3cig   0='(0) No' 1='(1) Yes' ;
  VALUE prb3alc   0='(0) No' 1='(1) Yes' ;
  VALUE prb3mrj   0='(0) No' 1='(1) Yes' ;
  VALUE prb3coc   0='(0) No' 1='(1) Yes' ;
  VALUE ircdcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ircdcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not try to cut down on any drug in pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irefcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not need more of any drug used for same effect'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irudcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not use any drug daily in the past year'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irdpcoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not feel like had to have any drug used pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscig   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsalc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwsmj    1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE irwscoc   1='(1) Yes' 2='(2) No'
                  13='(13) Did not have withdrawal symptoms in the pastyr'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE iralcagg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcarg  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcabs  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralchig  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcjob  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcmat  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcrel  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcfrd  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralctos  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralchol  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcdru  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcint  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcrem  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcqui  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcmor  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcsho  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcalo  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE iralcbrk  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE irnobooz  1='(1) No use of alcohol in the past year'
                  2='(2) Used alcohol in the past year' ;
  VALUE anyalc    0='(0) No' 1='(1) Yes' ;
  VALUE threalc   0='(0) No' 1='(1) Yes' ;
  VALUE drunkyrf  0='(0) Unknown' 1='(1) Drunk more than twice a month'
                  2='(2) Drunk twice a month or less'
                  3='(3) Never drunk in past year' ;
  VALUE iras13ff  1='(1) Never used any of the substances listed'
                  2='(2) Used one or more of the listed substance' ;
  VALUE avcig3ff  0='(0) None, never, < pack a day'
                  1='(1) Currently smoke a pack or more per day' ;
  VALUE irnodrug  1='(1) No use of cig/alc/other drugs past year'
                  2='(2) Use of cig/alc/other drugs past year' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1800;
INPUT
        CASEID 1-4              RESPID 5-9              ENCPSU 10-12
        ENCSEG 13-16            ENCCASE 17-20           CIGTRY 21-22
        CIG5PK 23-24            CIGREC 25-26            AVCIG 27-28
        CIGTIME 29-30           CIGINT 31-32            CIGAGE 33-34
        CIGYRS 35-36            PACKS 37-38             SNUFREC 39-40
        SNUFFREQ 41-42          ALCTRY 43-44            ALCREC 45-46
        ALCPREF 47-48           ALCDAYS 49-50           NODR30A 51-52
        MODR30A 53-54           MODR30DY 55-56          DR5DAY 57-58
        ALCAGE 59-60            ALCPAT 61-62            DRUNKYR 63-64
        ALCSED 65-66            ALCTRAN 67-68           ALCSTM 69-70
        ALCANAL 71-72           ALCMJ 73-74             ALCINH 75-76
        ALCCOC 77-78            ALCHAL 79-80            ALCOPT 81-82
        ALCNONE 83-84           NOSEDAT 85-86           BUTISOL 87-88
        BUTICAPS 89-90          AMYTAL 91-92            MEBARAL 93-94
        PLACIDYL 95-96          DORIDEN 97-98           NOLUDAR 99-100
        NEMBUTAL 101-102        SECONAL 103-104         TUINAL 105-106
        DALMANE 107-108         RESTORIL 109-110        HALCION 111-112
        AMOBARB 113-114         PHENOBAR 115-116        METHAQ 117-118
        CHHYD 119-120           PENTOB 121-122          SECOB 123-124
        SEDNEWA 125-127         SEDNEWB 128-130         SEDNOSP 131-132
        SEDDKNAM 133-134        SEDAGE 135-136          SEDTOT 137-138
        SEDREC 139-140          SEDALC 141-142          SEDTR 143-144
        SEDST 145-146           SEDAN 147-148           SEDMJ 149-150
        SEDINH 151-152          SEDCOC 153-154          SEDHAL 155-156
        SEDOPT 157-158          SEDNONE 159-160         AS3READ 161-162
        NOTRANQ 163-164         VALIUM 165-166          LIBRIUM 167-168
        LIMBTROL 169-170        MENRIUM 171-172         SERAX 173-174
        TRANXENE 175-176        ATIVAN 177-178          CENTRAX 179-180
        XANAX 181-182           PAXIPAM 183-184         BUSPAR 185-186
        MILTOWN 187-188         EQUANIL 189-190         DEPROL 191-192
        VISTAR 193-194          ATARAX 195-196          DURRAX 197-198
        DIAZEPAM 199-200        SKLY 201-202            MEPROB 203-204
        TRNEWA 205-207          TRNOSP 208-209          TRDKNAM 210-211
        TRANAGE 212-213         TRANTOT 214-215         TRANREC 216-217
        TRALC 218-219           TRSED 220-221           TRSTM 222-223
        TRANAL 224-225          TRMJ 226-227            TRINH 228-229
        TRCOC 230-231           TRHAL 232-233           TROPT 234-235
        TRNONE 236-237          AS4READ 238-239         NOSTIMS 240-241
        DEXED 242-243           DEXAMYL 244-245         ESKAT 246-247
        BENZ 248-249            BIPHET 250-251          DESOXYN 252-253
        TENUATE 254-255         TEPANIL 256-257         DIDREX 258-259
        PLEGINE 260-261         PRELUDIN 262-263        IONAMIN 264-265
        FASTIN 266-267          PONDIMIN 268-269        VORANIL 270-271
        SANOREX 272-273         MAZANOR 274-275         RITALIN 276-277
        CYLERT 278-279          DETAMP 280-281          METHI 282-283
        METHAMP 284-285         OBLA 286-287            STIMNEWA 288-290
        STIMNEWB 291-293        STIMNEWC 294-296        STIMNEWD 297-299
        STIMNOSP 300-301        STMDKNAM 302-303        STIMAGE 304-305
        STIMTOT 306-307         STIMREC 308-309         STALC 310-311
        STSED 312-313           STTRAN 314-315          STANAL 316-317
        STMJ 318-319            STINH 320-321           STCOC 322-323
        STHAL 324-325           STOPT 326-327           STNONE 328-329
        STNEEDLE 330-331        STNDLREC 332-333        AS5READ 334-335
        ANALNONE 336-337        DARVON 338-339          DOLENE 340-341
        SK65A 342-343           WYGESIC 344-345         LEVODRO 346-347
        PERCODAN 348-349        DEMEROL 350-351         DILAUD 352-353
        TYLCOD 354-355          PHENCOD 356-357         TALWIN 358-359
        TALWINNX 360-361        TALACEN 362-363         PROPOXY 364-365
        CODEINE 366-367         ANILERID 368-369        MORPHINE 370-371
        METHDON 372-373         STADOL 374-375          ANALNEWA 376-378
        ANALNEWB 379-381        ANLNOSP 382-383         ANLDKNAM 384-385
        ANALAGE 386-387         ANALTOT 388-389         ANALREC 390-391
        ANLALC 392-393          ANLSED 394-395          ANLTRAN 396-397
        ANLSTM 398-399          ANLMJ 400-401           ANLINH 402-403
        ANLCOC 404-405          ANLHAL 406-407          ANLOPT 408-409
        ANLNONE 410-411         MJOPP 412-413           MJAGE 414-415
        MJTOT 416-417           MJREC 418-419           MJDAY30A 420-421
        MJAV30A 422-423         MJAMT30A 424-425        MJALC30A 426-427
        MJYRFREQ 428-429        MJALC 430-431           MJSED 432-433
        MJTRAN 434-435          MJSTM 436-437           MJANAL 438-439
        MJINH 440-441           MJCOC 442-443           MJHAL 444-445
        MJOPT 446-447           MJNONE 448-449          AS7READ 450-451
        INHAGE 452-453          GAS 454-455             SPPAINT 456-457
        AEROS 458-459           GLUE 460-461            SOLVENT 462-463
        AMYLNIT 464-465         ETHER 466-467           NITOXID 468-469
        CLEFLU 470-471          INHNEWA 472-474         INHNEWB 475-477
        INHNOSP 478-479         INHTOT 480-481          GAS30A 482-483
        SPPAN30A 484-485        AEROS30A 486-487        GLUE30A 488-489
        SOLVN30A 490-491        AMLNT30A 492-493        ETHER30A 494-495
        NOX30A 496-497          CLFL30A 498-499         INNEW30A 500-502
        INNEW30B 503-505        IN30NOSP 506-507        INH30NO 508-509
        INHDY30A 510-511        INHREC 512-513          INHEFF 514-515
        INHPO 516-517           INHQNC1 518-519         INHQNC2 520-521
        INHQNC3 522-523         INHQNC4 524-525         INHQNC5 526-527
        INHQNC6 528-529         INHQNC7 530-531         INHQNC8 532-533
        INHQNC9 534-535         INHANSY 536-537         COCOPP 538-539
        COCAGE 540-541          COCTOT 542-543          COCREC 544-545
        COCUS30A 546-547        COC30ALC 548-549        COCYRFRQ 550-551
        COCALC 552-553          COCSED 554-555          COCTRAN 556-557
        COCSTM 558-559          COCANAL 560-561         COCINH 562-563
        COCMJ 564-565           COCHAL 566-567          COCOPT 568-569
        COCNONE 570-571         COCSNIFF 572-573        COCSWAL 574-575
        COCIV 576-577           FREEBASE 578-579        COCNEWA 580-581
        COCNOSP 582-583         CONDLREC 584-585        CRAKREC 586-587
        CRKAM30A 588-590        CRAKBUCK 591-594        COCAM30A 595-596
        COCBUCK 597-600         AS9READ 601-602         LSD 603-604
        PEYOTE 605-606          MESC 607-608            PSILCY 609-610
        PCP 611-612             ECSTASY 613-614         HALNEWA 615-617
        HALNOSP 618-619         HALLOPP 620-621         HALLAGE 622-623
        HALLTOT 624-625         HALLREC 626-627         HAL30USE 628-629
        PCPREC 630-631          PCPFLASH 632-633        PCPSENSE 634-635
        PCPFEELV 636-637        PCPACTV 638-639         PCPNEWA 640-641
        PCPNEWB 642-643         PCPNEWC 644-645         PCPNOSP 646-647
        PCPNORCT 648-649        HALLQCL 650-651         AS10READ 652-653
        HEROPP 654-655          HERAGE 656-657          HERTOT 658-659
        HERREC 660-661          HER30USE 662-663        HERNEEDL 664-665
        HRNDLREC 666-667        AS11READ 668-669        NODRUGS 670-671
        CDCIG 672-673           CDALC 674-675           CDSED 676-677
        CDTRAN 678-679          CDSTM 680-681           CDANAL 682-683
        CDMJ 684-685            CDINH 686-687           CDCOC 688-689
        CDHALL 690-691          CDHER 692-693           CDOTHOP 694-695
        CDNONE 696-697          EFFCIG 698-699          EFFALC 700-701
        EFFSED 702-703          EFFTRAN 704-705         EFFSTM 706-707
        EFFANAL 708-709         EFFMJ 710-711           EFFINH 712-713
        EFFCOC 714-715          EFFHALL 716-717         EFFHER 718-719
        EFFOTHOP 720-721        EFFNONE 722-723         UDAYCIG 724-725
        UDAYALC 726-727         UDAYSED 728-729         UDAYTRAN 730-731
        UDAYSTM 732-733         UDAYANAL 734-735        UDAYMJ 736-737
        UDAYINH 738-739         UDAYCOC 740-741         UDAYHALL 742-743
        UDAYHER 744-745         UDAYOTH 746-747         UDAYNONE 748-749
        DEPCIG 750-751          DEPALC 752-753          DEPSED 754-755
        DEPTRAN 756-757         DEPSTM 758-759          DEPANAL 760-761
        DEPMJ 762-763           DEPINH 764-765          DEPCOC 766-767
        DEPHALL 768-769         DEPHER 770-771          DEPOTHOP 772-773
        DEPNONE 774-775         WSCIG 776-777           WSALC 778-779
        WSSED 780-781           WSTRAN 782-783          WSSTM 784-785
        WSANAL 786-787          WSMJ 788-789            WSINH 790-791
        WSCOC 792-793           WSHALL 794-795          WSHER 796-797
        WSOTHOP 798-799         WSNONE 800-801          SHRNDLMO 802-803
        NRSHRNDL 804-805        CLEANNDL 806-807        SHRWMALE 808-809
        SHRWSEXP 810-811        SHRWRACE 812-813        RSNNOSHR 814-815
        NOBOOZYR 816-817        ALCAGGR 818-819         ALCARGUM 820-821
        ALCABSNT 822-823        ALCHIGH 824-825         ALCJOB 826-827
        ALCMATCD 828-829        ALCRELCD 830-831        ALCFRDCD 832-833
        ALCTOSS 834-835         ALCHOLIC 836-837        ALCDRUNK 838-839
        ALCINTOX 840-841        ALCREM 842-843          ALCQUICK 844-845
        ALCMORN 846-847         ALCSHOOK 848-849        ALCALONE 850-851
        ALCBRKPM 852-853        AS13NONE 854-855        DRDEPRSS 856-857
        DEPDRG1A 858-860        DEPDRG2A 861-863        DEPDRG3A 864-866
        DEPDRG4A 867-869        DEPDRG5A 870-872        DRARGUM 873-874
        ARGDRG1A 875-877        ARGDRG2A 878-880        ARGDRG3A 881-883
        ARGDRG4A 884-886        ARGDRG5A 887-889        DRALONE 890-891
        ALNDRG1A 892-894        ALNDRG2A 895-897        ALNDRG3A 898-900
        ALNDRG4A 901-903        ALNDRG5A 904-906        DRANX 907-908
        ANXDRG1A 909-911        ANXDRG2A 912-914        ANXDRG3A 915-917
        ANXDRG4A 918-920        ANXDRG5A 921-923        DRHEALTH 924-925
        HLTDRG1A 926-928        HLTDRG2A 929-931        HLTDRG3A 932-934
        HLTDRG4A 935-937        HLTDRG5A 938-940        DRNTHINK 941-942
        NTKDRG1A 943-945        NTKDRG2A 946-948        NTKDRG3A 949-951
        NTKDRG4A 952-954        NTKDRG5A 955-957        DRUPSET 958-959
        UPSDRG1A 960-962        UPSDRG2A 963-965        UPSDRG3A 966-968
        UPSDRG4A 969-971        UPSDRG5A 972-974        DRLSWORK 975-976
        LSWDRG1A 977-979        LSWDRG2A 980-982        LSWDRG3A 983-985
        LSWDRG4A 986-988        LSWDRG5A 989-991        DRSUSPIC 992-993
        SSPDRG1A 994-996        SSPDRG2A 997-999        SSPDRG3A 1000-1002
        SSPDRG4A 1003-1005      SSPDRG5A 1006-1008      DRCOPE 1009-1010
        CPEDRG1A 1011-1013      CPEDRG2A 1014-1016      CPEDRG3A 1017-1019
        CPEDRG4A 1020-1022      CPEDRG5A 1023-1025      DREMGMED 1026-1027
        EMDRG1A 1028-1030       EMDRG2A 1031-1033       EMDRG3A 1034-1036
        EMDRG4A 1037-1039       EMDRG5A 1040-1042       RSKPKCIG 1043-1044
        RSKMJOCC 1045-1046      RSKMJREG 1047-1048      RKTRYPCP 1049-1050
        RKPCPREG 1051-1052      RKTRYHER 1053-1054      RKHERREG 1055-1056
        RKTRYCOC 1057-1058      RKCOCOCC 1059-1060      RKCOCREG 1061-1062
        RKCRKOCC 1063-1064      RK2DRINK 1065-1066      RK5DRINK 1067-1068
        RSKBINGE 1069-1070      HIGHBP 1071-1072        BPMED 1073-1074
        WALKPAIN 1075-1076      TIMEPAIN 1077-1078      UPSHOR 1079-1080
        ASTHMA 1081-1082        TRPSYCH 1083-1084       HEART 1085-1086
        FLU 1087-1088           ALLERG 1089-1090        HOSPYR 1091-1092
        SOREYR 1093-1094        RUNNYYR 1095-1096       COUGHYR 1097-1098
        PHLEGMYR 1099-1100      HEALTHYR 1101-1102      MARITAL 1103-1104
        NOMARR 1105-1106        WORKSTAT 1107-1108      PAYMO 1109-1110
        PAYYR 1111-1112         NO5JOB 1113-1114        WORKDAYS 1115-1116
        WORKBLAH 1117-1118      CWE 1119-1120           FULLPART 1121-1122
        EDUC 1123-1124          ENROLLD 1125-1126       SCHPLANS 1127-1128
        STUDENT 1129-1130       SCHDAYS 1131-1132       SKIPPED 1133-1134
        MILES 1135-1139         ACCID 1140-1141         NOCHILD 1142-1143
        TOTPEOP 1144-1145       MOTHER 1146-1147        STEPMOM 1148-1149
        FATHER 1150-1151        STEPDAD 1152-1153       SPOUSE 1154-1155
        INLAW 1156-1157         OWNCHILD 1158-1159      STEPCHLD 1160-1161
        BROSIS 1162-1163        OTHREL 1164-1165        FRIENDS 1166-1167
        OTHERNON 1168-1169      SERVICE 1170-1171       MILSTAT 1172-1173
        MOVDAWAY 1174-1175      DORM 1176-1177          MILBASE 1178-1179
        HOSP 1180-1181          TELNO 1182-1183         MOVES 1184-1185
        INCOME 1186-1187        BTIME 1188-1191         BAP 1192
        ETIME 1193-1196         EAP 1197                LANGVER 1198
        UNDINT 1199-1200        COOPINT 1201-1202       PRIVACY 1203-1204
        PPRES 1205-1206         SPRES 1207-1208         PARPRES 1209-1210
        OARPRES 1211-1212       OAPRES 1213-1214        CPRES 1215-1216
        OPRESSPA 1217-1218      OPRESSPB 1219-1220      OPRESNSP 1221-1222
        REGION 1223             DIVISION 1224           IRAGE 1225-1226
        IIAGE 1227              AGEGR 1228              ORAGEGR 1229
        SEX 1230                ORSEX 1231              IRRACE 1232
        IIRACE 1233             IRHOIND 1234            IIHOIND 1235
        IRHOGRP 1236            IIHOGRP 1237            IRALCRC 1238
        IIALCRC 1239            IRMJRC 1240             IIMJRC 1241
        IRCOCRC 1242            IICOCRC 1243            IRSEDRC 1244
        IISEDRC 1245            IRTRNRC 1246            IITRNRC 1247
        IRSTMRC 1248            IISTMRC 1249            IRANLRC 1250
        IIANLRC 1251            IRCIGRC 1252            IICIGRC 1253
        IROTBRC 1254            IIOTBRC 1255            IRINHRC 1256
        IIINHRC 1257            IRCRKRC 1258            IICRKRC 1259
        IRHALRC 1260            IIHALRC 1261            IRHERRC 1262
        IIHERRC 1263            IRPCPRC 1264            IIPCPRC 1265
        IRALCFQ 1266            IIALCFQ 1267            IRMJFQ 1268-1269
        IIMJFQ 1270             IRCOCFQ 1271            IICOCFQ 1272
        CATAGE 1273             CATAG2 1274             RACE 1275
        EDUCCAT 1276            EMPSTAT 1277            SMOKCOK 1278
        CONDLRC2 1279           HALFLAG 1280            HALYR 1281
        HALMON 1282             PCPFLAG 1283            PCPYR 1284
        PCPMON 1285             STMFLAG 1286            STMYR 1287
        STMMON 1288             SEDFLAG 1289            SEDYR 1290
        SEDMON 1291             TRQFLAG 1292            TRQYR 1293
        TRQMON 1294             ANLFLAG 1295            ANLYR 1296
        ANLMON 1297             ALCFLAG 1298            ALCYR 1299
        ALCMON 1300             CIGFLAG 1301            CIGYR 1302
        CIGMON 1303             SMKFLAG 1304            SMKYR 1305
        SMKMON 1306             HERFLAG 1307            HERYR 1308
        HERMON 1309             MRJFLAG 1310            MRJYR 1311
        MRJMON 1312             COCFLAG 1313            COCYR 1314
        COCMON 1315             CRKFLAG 1316            CRKYR 1317
        CRKMON 1318             INHFLAG 1319            INHYR 1320
        INHMON 1321             NEEDLREC 1322-1323      NEDFLAG 1324
        NEDYR 1325              COCYRF 1326             COCMONF 1327
        COCWKF 1328             ALCYRF 1329             ALCMONF 1330
        ALCWKF 1331             MRJYRF 1332             MRJMONF 1333
        MRJWKF 1334             PSYFLAG2 1335           PSYYR2 1336
        PSYMON2 1337            SUMFLAG 1338            SUMYR 1339
        SUMMON 1340             MJOFLAG 1341            MJOYR2 1342
        MJOMON2 1343            VESTR 1344-1345         VEREP 1346
        ANALWT 1347-1358 .8     ANALWT2 1359-1370 .10   CHAGE1 1371
        CHAGE2 1372             CHAGE3 1373             CHAGE4 1374
        CHAGE5 1375             CHAGE6 1376             CHAGE7 1377
        CHAGE8 1378             CHAGE9 1379-1380        CHAGE10 1381-1382
        CWEOCC2 1383-1385       ROCCUP2 1386-1388       BUSINES2 1389-1391
        CWEBUS2 1392-1394       POPDEN 1395             MRJMON2 1396
        ALCMON2 1397            CIGMON2 1398            LSD2 1399
        PEYOTE2 1400            MESC2 1401              PSILCY2 1402
        GAS2 1403               SPPAINT2 1404           AEROS2 1405
        GLUE2 1406              SOLVENT2 1407           AMYLNIT2 1408
        ETHER2 1409             NITOXID2 1410           CLEFLU2 1411
        COCSNIF2 1412           FREEBAS2 1413           COCSWAL2 1414
        COCIV2 1415             COCNEWA2 1416           MJTOT2 1417
        COCTOT2 1418            MJTOT3 1419             COCTOT3 1420
        MJDY30A2 1421           ALCDAYS2 1422           RACESEX 1423
        NOTMARJ 1424            EDUCCAT2 1425           EMPSTAT2 1426
        MJDY30A3 1427           ALCDAYS3 1428           DRINKER 1429
        HVYDRK 1430             AVCIG2 1431             IRDEP 1432-1433
        IRARG 1434-1435         IRALN 1436-1437         IRANX 1438-1439
        IRHLT 1440-1441         IRNTK 1442-1443         IRUPS 1444-1445
        IRLSW 1446-1447         IRSSP 1448-1449         IRCPE 1450-1451
        IREMG 1452-1453         IRDEP1 1454-1456        IRDEP2 1457-1459
        IRDEP3 1460-1462        IRDEP4 1463-1465        IRDEP5 1466-1468
        IRARG1 1469-1471        IRARG2 1472-1474        IRARG3 1475-1477
        IRARG4 1478-1480        IRARG5 1481-1483        IRALN1 1484-1486
        IRALN2 1487-1489        IRALN3 1490-1492        IRALN4 1493-1495
        IRALN5 1496-1498        IRANX1 1499-1501        IRANX2 1502-1504
        IRANX3 1505-1507        IRANX4 1508-1510        IRANX5 1511-1513
        IRHLT1 1514-1516        IRHLT2 1517-1519        IRHLT3 1520-1522
        IRHLT4 1523-1525        IRHLT5 1526-1528        IRNTK1 1529-1531
        IRNTK2 1532-1534        IRNTK3 1535-1537        IRNTK4 1538-1540
        IRNTK5 1541-1543        IRUPS1 1544-1546        IRUPS2 1547-1549
        IRUPS3 1550-1552        IRUPS4 1553-1555        IRUPS5 1556-1558
        IRLSW1 1559-1561        IRLSW2 1562-1564        IRLSW3 1565-1567
        IRLSW4 1568-1570        IRLSW5 1571-1573        IRSSP1 1574-1576
        IRSSP2 1577-1579        IRSSP3 1580-1582        IRSSP4 1583-1585
        IRSSP5 1586-1588        IRCPE1 1589-1591        IRCPE2 1592-1594
        IRCPE3 1595-1597        IRCPE4 1598-1600        IRCPE5 1601-1603
        IREMG1 1604-1606        IREMG2 1607-1609        IREMG3 1610-1612
        IREMG4 1613-1615        IREMG5 1616-1618        ANYPROB 1619
        TWOPROB 1620            THREPROB 1621           DEPCIG2 1622
        DEPALC2 1623            DEPMRJ2 1624            DEPCOC2 1625
        ARGCIG2 1626            ARGALC2 1627            ARGMRJ2 1628
        ARGCOC2 1629            ALNCIG2 1630            ALNALC2 1631
        ALNMRJ2 1632            ALNCOC2 1633            ANXCIG2 1634
        ANXALC2 1635            ANXMRJ2 1636            ANXCOC2 1637
        HLTCIG2 1638            HLTALC2 1639            HLTMRJ2 1640
        HLTCOC2 1641            NTKCIG2 1642            NTKALC2 1643
        NTKMRJ2 1644            NTKCOC2 1645            UPSCIG2 1646
        UPSALC2 1647            UPSMRJ2 1648            UPSCOC2 1649
        LSWCIG2 1650            LSWALC2 1651            LSWMRJ2 1652
        LSWCOC2 1653            SSPCIG2 1654            SSPALC2 1655
        SSPMRJ2 1656            SSPCOC2 1657            CPECIG2 1658
        CPEALC2 1659            CPEMRJ2 1660            CPECOC2 1661
        EMCIG2 1662             EMALC2 1663             EMMRJ2 1664
        EMCOC2 1665             PRB1CIG 1666            PRB1ALC 1667
        PRB1MRJ 1668            PRB1COC 1669            PRB2CIG 1670
        PRB2ALC 1671            PRB2MRJ 1672            PRB2COC 1673
        PRB3CIG 1674            PRB3ALC 1675            PRB3MRJ 1676
        PRB3COC 1677            IRCDCIG 1678-1679       IRCDALC 1680-1681
        IRCDMJ 1682-1683        IRCDCOC 1684-1685       IREFCIG 1686-1687
        IREFALC 1688-1689       IREFMJ 1690-1691        IREFCOC 1692-1693
        IRUDCIG 1694-1695       IRUDALC 1696-1697       IRUDMJ 1698-1699
        IRUDCOC 1700-1701       IRDPCIG 1702-1703       IRDPALC 1704-1705
        IRDPMJ 1706-1707        IRDPCOC 1708-1709       IRWSCIG 1710-1711
        IRWSALC 1712-1713       IRWSMJ 1714-1715        IRWSCOC 1716-1717
        ALCPROBS 1718           MJPROBS 1719            COCPROBS 1720
        CIGPROBS 1721           IRALCAGG 1722-1723      IRALCARG 1724-1725
        IRALCABS 1726-1727      IRALCHIG 1728-1729      IRALCJOB 1730-1731
        IRALCMAT 1732-1733      IRALCREL 1734-1735      IRALCFRD 1736-1737
        IRALCTOS 1738-1739      IRALCHOL 1740-1741      IRALCDRU 1742-1743
        IRALCINT 1744-1745      IRALCREM 1746-1747      IRALCQUI 1748-1749
        IRALCMOR 1750-1751      IRALCSHO 1752-1753      IRALCALO 1754-1755
        IRALCBRK 1756-1757      IRNOBOOZ 1758           ANYALC 1759
        THREALC 1760            DRUNKYR2 1761           IRAS13 1762
        AVCIG3 1763             IRNODRUG 1764           ALCONLYL 1765
        ALCONLYY 1766           ALCONLYM 1767           ILLONLYL 1768
        ILLONLYY 1769           ILLONLYM 1770           MRJONLYL 1771
        MRJONLYY 1772           MRJONLYM 1773           PSYONLYL 1774
        PSYONLYY 1775           PSYONLYM 1776           OTHONLYL 1777
        OTHONLYY 1778           OTHONLYM 1779           ALCILLL 1780
        ALCILLY 1781            ALCILLM 1782            ALCMRJL 1783
        ALCMRJY 1784            ALCMRJM 1785            ALCPSYL 1786
        ALCPSYY 1787            ALCPSYM 1788            ALCOTHL 1789
        ALCOTHY 1790            ALCOTHM 1791            SUB1LIF 1792
        SUB2LIF 1793            SUB3LIF 1794            SUB1YR 1795
        SUB2YR 1796             SUB3YR 1797             SUB1MON 1798
        SUB2MON 1799            SUB3MON 1800            ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   RESPID  = 'RESPONDENT IDENTIFICATION NUMBER'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (ENCRYPTED)'
   ENCSEG  = 'SEGMENT IDENTIFICATION NUMBER (ENCRYPTED)'
   ENCCASE = 'HOUSEHOLD LEVEL IDENTIFICATION NUMBER (ENCRYPTED)'
   CIGTRY  = 'AGE WHEN FIRST TRIED A CIGARETTE'
   CIG5PK  = 'SMOKED 5 OR MORE PACKS OF CIGARETTES IN LIFETIME'
   CIGREC  = 'MOST RECENT TIME SMOKED A CIGARETTE'
   AVCIG   = '# CIGARETTES SMOKED PER DAY LAST 30 DAYS'
   CIGTIME = 'LENGTH OF TIME SMOKED # CIGARETTES/DAY IN AVCIG'
   CIGINT  = 'UNIT FOR LENGTH OF TIME'
   CIGAGE  = 'AGE WHEN FIRST STARTED SMOKING DAILY'
   CIGYRS  = '# YEARS SMOKED DAILY'
   PACKS   = '# CIGARETTES SMOKED DAILY'
   SNUFREC = 'MOST RECENT TIME USED SMOKELESS TOBACCO'
   SNUFFREQ= '# TIMES USED SMOKELESS TOBACCO PAST 12 MONTHS'
   ALCTRY  = 'AGE WHEN HAD FIRST DRINK OF ALCOHOL'
   ALCREC  = 'MOST RECENT ALCOHOL DRINK'
   ALCPREF = 'USUAL ALCOHOL BEVERAGE'
   ALCDAYS = '# OF DAYS DRANK ALCOHOL PAST 30 DAYS'
   NODR30A = 'USUAL # DRINKS PER DAY PAST 30 DAYS'
   MODR30A = 'MOST # DRINKS ON ONE DAY IN PAST 30 DAYS'
   MODR30DY= '# DAYS DRANK AMOUNT IN A-6 PAST 30 DAYS'
   DR5DAY  = '# DAYS DRANK 5 OR MORE DRINKS PAST 30 DAYS'
   ALCAGE  = 'AGE BEGAN DRINKING ALCOHOL MONTHLY OR MORE OFTEN'
   ALCPAT  = 'FREQUENCY ALCOHOL CONSUMPTION PAST 12 MONTHS'
   DRUNKYR = '# TIMES DRUNK ON ALCOHOL PAST 12 MONTHS'
   ALCSED  = 'SEDATIVES USED W/ALCOHOL PAST 12 MONTHS'
   ALCTRAN = 'TRANQUILIZERS USED W/ALCOHOL PAST 12 MONTHS'
   ALCSTM  = 'STIMULANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCANAL = 'ANALGESICS USED W/ALCOHOL PAST 12 MONTHS'
   ALCMJ   = 'MARIJUANA USED W/ALCOHOL PAST 12 MONTHS'
   ALCINH  = 'INHALANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCCOC  = 'COCAINE USED W/ALCOHOL PAST 12 MONTHS'
   ALCHAL  = 'HALLUCINOGENS USED W/ALCOHOL PAST 12 MONTHS'
   ALCOPT  = 'HEROIN USED W/ALCOHOL PAST 12 MONTHS'
   ALCNONE = 'NONE OF LISTED DRUGS USED W/ALCOHOL IN PAST 12 MOS'
   NOSEDAT = 'HAS NEVER TAKEN SEDATIVES FOR NONMEDICAL REASONS'
   BUTISOL = 'BUTISOL EVER TAKEN FOR NONMEDICAL REASONS'
   BUTICAPS= 'BUTICAPS EVER TAKEN FOR NONMEDICAL REASONS'
   AMYTAL  = 'AMYTAL EVER TAKEN FOR NONMEDICAL REASONS'
   MEBARAL = 'MEBARAL EVER TAKEN FOR NONMEDICAL REASONS'
   PLACIDYL= 'PLACIDYL EVER TAKEN FOR NONMEDICAL REASONS'
   DORIDEN = 'DORIDEN EVER TAKEN FOR NONMEDICAL REASONS'
   NOLUDAR = 'NOLUDAR EVER TAKEN FOR NONMEDICAL REASONS'
   NEMBUTAL= 'NEMBUTAL EVER TAKEN FOR NONMEDICAL REASONS'
   SECONAL = 'SECONAL EVER TAKEN FOR NONMEDICAL REASONS'
   TUINAL  = 'TUINAL EVER TAKEN FOR NONMEDICAL REASONS'
   DALMANE = 'DALMANE EVER TAKEN FOR NONMEDICAL REASONS'
   RESTORIL= 'RESTORIL EVER TAKEN FOR NONMEDICAL REASONS'
   HALCION = 'HALCION EVER TAKEN FOR NONMEDICAL REASONS'
   AMOBARB = 'AMOBARBITAL EVER TAKEN FOR NONMEDICAL REASONS'
   PHENOBAR= 'PHENOBARBITAL EVER TAKEN FOR NONMEDICAL REASONS'
   METHAQ  = 'METHAQUALONE EVER TAKEN FOR NONMEDICAL REASONS'
   CHHYD   = 'CHLORAL HYDRATE EVER TAKEN FOR NONMEDICAL REASONS'
   PENTOB  = 'PENTOBARBITAL EVER TAKEN FOR NONMEDICAL REASONS'
   SECOB   = 'SECOBARBITAL EVER TAKEN FOR NONMEDICAL REASONS'
   SEDNEWA = 'OTHER SEDATIVE EVER USED (FIRST MENTION)'
   SEDNEWB = 'OTHER SEDATIVE EVER USED (SECOND MENTION)'
   SEDNOSP = 'OTHER SEDATIVE EVER USED (NOT SPECIFIED)'
   SEDDKNAM= 'USED SEDATIVE, DON''T KNOW NAME'
   SEDAGE  = 'AGE FIRST TOOK SEDATIVE FOR NONMEDICAL REASONS'
   SEDTOT  = '# TIMES EVER TOOK SEDATIVE FOR NONMEDICAL REASONS'
   SEDREC  = 'MOST RECENT TIME USED SEDATIVE FOR NONMEDICAL REAS'
   SEDALC  = 'ALCOHOL USED W/SEDATIVE PAST 12 MONTHS'
   SEDTR   = 'TRANQUILIZERS USED W/SEDATIVE PAST 12 MONTHS'
   SEDST   = 'STIMULANTS USED W/SEDATIVE PAST 12 MONTHS'
   SEDAN   = 'ANALGESICS USED W/SEDATIVE PAST 12 MONTHS'
   SEDMJ   = 'MARIJUANA USED W/SEDATIVE PAST 12 MONTHS'
   SEDINH  = 'INHALANTS USED W/SEDATIVE PAST 12 MONTHS'
   SEDCOC  = 'COCAINE USED W/SEDATIVE PAST 12 MONTHS'
   SEDHAL  = 'HALLUCINOGENS USED W/SEDATIVE PAST 12 MONTHS'
   SEDOPT  = 'HEROIN USED W/SEDATIVE PAST 12 MONTHS'
   SEDNONE = 'NONE OF LISTED DRUGS USED W/SEDATIVE PAST 12 MOS'
   AS3READ = 'TRANQUILIZERS - READING PREFERENCE'
   NOTRANQ = 'HAS NEVER TAKEN TRANQUILIZER FOR NONMED REASONS'
   VALIUM  = 'VALIUM EVER TAKEN FOR NONMEDICAL REASONS'
   LIBRIUM = 'LIBRIUM EVER TAKEN FOR NONMEDICAL REASONS'
   LIMBTROL= 'LIMBITROL EVER TAKEN FOR NONMEDICAL REASONS'
   MENRIUM = 'MENRIUM EVER TAKEN FOR NONMEDICAL REASONS'
   SERAX   = 'SERAX EVER TAKEN FOR NONMEDICAL REASONS'
   TRANXENE= 'TRANXENE EVER TAKEN FOR NONMEDICAL REASONS'
   ATIVAN  = 'ATIVAN EVER TAKEN FOR NONMEDICAL REASONS'
   CENTRAX = 'CENTRAX EVER TAKEN FOR NONMEDICAL REASONS'
   XANAX   = 'XANAX EVER TAKEN FOR NONMEDICAL REASONS'
   PAXIPAM = 'PAXIPAM EVER TAKEN FOR NONMEDICAL REASONS'
   BUSPAR  = 'BUSPAR EVER TAKEN FOR NONMEDICAL REASONS'
   MILTOWN = 'MILTOWN EVER TAKEN FOR NONMEDICAL REASONS'
   EQUANIL = 'EQUANIL EVER TAKEN FOR NONMEDICAL REASONS'
   DEPROL  = 'DEPROL EVER TAKEN FOR NONMEDICAL REASONS'
   VISTAR  = 'VISTARIL EVER TAKEN FOR NONMEDICAL REASONS'
   ATARAX  = 'ATARAX EVER TAKEN FOR NONMEDICAL REASONS'
   DURRAX  = 'DURRAX EVER TAKEN FOR NONMEDICAL REASONS'
   DIAZEPAM= 'DIAZEPAM EVER TAKEN FOR NONMEDICAL REASONS'
   SKLY    = 'SK-LYGEN EVER TAKEN FOR NONMEDICAL REASONS'
   MEPROB  = 'MEPROBAMATE EVER TAKEN FOR NONMEDICAL REASONS'
   TRNEWA  = 'OTHER TRANQUILIZER EVER USED (ONLY MENTION)'
   TRNOSP  = 'OTHER TRANQUILIZER EVER USED (NOT SPECIFIED)'
   TRDKNAM = 'USED TRANQUILIZER, DON''T KNOW NAME'
   TRANAGE = 'AGE FIRST TOOK TRANQUILIZER FOR NONMEDICAL REASONS'
   TRANTOT = '# TIMES EVER TOOK TRANQUILIZER NONMEDICAL REASONS'
   TRANREC = 'MOST RECENT TIME USED TRANQUILIZER NONMEDICAL REAS'
   TRALC   = 'ALCOHOL USED W/TRANQUILIZER PAST 12 MONTHS'
   TRSED   = 'SEDATIVES USED W/TRANQUILIZER PAST 12 MONTHS'
   TRSTM   = 'STIMULANTS USED W/TRANQUILIZER PAST 12 MONTHS'
   TRANAL  = 'ANALGESICS USED W/TRANQUILIZER PAST 12 MONTHS'
   TRMJ    = 'MARIJUANA USED W/TRANQUILIZER PAST 12 MONTHS'
   TRINH   = 'INHALANTS USED W/TRANQUILIZER PAST 12 MONTHS'
   TRCOC   = 'COCAINE USED W/TRANQUILIZER PAST 12 MONTHS'
   TRHAL   = 'HALLUCINOGENS USED W/TRANQUILIZER PAST 12 MONTHS'
   TROPT   = 'HEROIN USED W/TRANQUILIZER PAST 12 MONTHS'
   TRNONE  = 'NONE OF LISTED DRUGS USED W/TRANQUILIZER PAST 12 M'
   AS4READ = 'STIMULANTS - READING PREFERENCE'
   NOSTIMS = 'HAS NEVER TAKEN STIMULANT FOR NONMEDICAL REASONS'
   DEXED   = 'DEXEDRINE EVER TAKEN FOR NONMEDICAL REASONS'
   DEXAMYL = 'DEXAMYL EVER TAKEN FOR NONMEDICAL REASONS'
   ESKAT   = 'ESKATROL EVER TAKEN FOR NONMEDICAL REASONS'
   BENZ    = 'BENZEDRINE EVER TAKEN FOR NONMEDICAL REASONS'
   BIPHET  = 'BIPHETAMINE EVER TAKEN FOR NONMEDICAL REASONS'
   DESOXYN = 'DESOXYN EVER TAKEN FOR NONMEDICAL REASONS'
   TENUATE = 'TENUATE EVER TAKEN FOR NONMEDICAL REASONS'
   TEPANIL = 'TEPANIL EVER TAKEN FOR NONMEDICAL REASONS'
   DIDREX  = 'DIDREX EVER TAKEN FOR NONMEDICAL REASONS'
   PLEGINE = 'PLEGINE EVER TAKEN FOR NONMEDICAL REASONS'
   PRELUDIN= 'PRELUDIN EVER TAKEN FOR NONMEDICAL REASONS'
   IONAMIN = 'IONAMIN EVER TAKEN FOR NONMEDICAL REASONS'
   FASTIN  = 'FASTIN EVER TAKEN FOR NONMEDICAL REASONS'
   PONDIMIN= 'PONDIMIN EVER TAKEN FOR NONMEDICAL REASONS'
   VORANIL = 'VORANIL EVER TAKEN FOR NONMEDICAL REASONS'
   SANOREX = 'SANOREX EVER TAKEN FOR NONMEDICAL REASONS'
   MAZANOR = 'MAZANOR EVER TAKEN FOR NONMEDICAL REASONS'
   RITALIN = 'RITALIN EVER TAKEN FOR NONMEDICAL REASONS'
   CYLERT  = 'CYLERT EVER TAKEN FOR NONMEDICAL REASONS'
   DETAMP  = 'DEXTROAMPHETAMINE EVER TAKEN FOR NONMEDICAL REASON'
   METHI   = 'METHEDRINE EVER TAKEN FOR NONMEDICAL REASONS'
   METHAMP = 'METHAMPHETAMINE EVER TAKEN FOR NONMEDICAL REASONS'
   OBLA    = 'OBEDRIN-LA EVER TAKEN FOR NONMEDICAL REASONS'
   STIMNEWA= 'OTHER STIMULANT EVER USED (FIRST MENTION)'
   STIMNEWB= 'OTHER STIMULANT EVER USED (SECOND MENTION)'
   STIMNEWC= 'OTHER STIMULANT EVER USED (THIRD MENTION)'
   STIMNEWD= 'OTHER STIMULANT EVER USED (FOURTH MENTION)'
   STIMNOSP= 'OTHER STIMULANT EVER USED (NOT SPECIFIED)'
   STMDKNAM= 'USED STIMULANT, DON''T KNOW NAME'
   STIMAGE = 'AGE FIRST TOOK STIMULANT FOR NONMEDICAL REASONS'
   STIMTOT = '# TIMES EVER TOOK STIMULANT FOR NONMEDICAL REASONS'
   STIMREC = 'MOST RECENT TIME USED STIMULANT FOR NONMEDICAL REA'
   STALC   = 'ALCOHOL USED W/STIMULANT PAST 12 MONTHS'
   STSED   = 'SEDATIVES USED W/STIMULANT PAST 12 MONTHS'
   STTRAN  = 'TRANQUILIZERS USED W/STIMULANT PAST 12 MONTHS'
   STANAL  = 'ANALGESICS USED W/STIMULANT PAST 12 MONTHS'
   STMJ    = 'MARIJUANA USED W/STIMULANT PAST 12 MONTHS'
   STINH   = 'INHALANTS USED W/STIMULANT PAST 12 MONTHS'
   STCOC   = 'COCAINE USED W/STIMULANT PAST 12 MONTHS'
   STHAL   = 'HALLUCINOGENS USED W/STIMULANT PAST 12 MONTHS'
   STOPT   = 'HEROIN USED W/STIMULANT PAST 12 MONTHS'
   STNONE  = 'NONE OF LISTED DRUGS USED W/STIMULANT PAST 12 MOS'
   STNEEDLE= 'EVER USED AMPHETAMINES WITH A NEEDLE'
   STNDLREC= 'MOST RECENT TIME USED AMPHETAMINES WITH A NEEDLE'
   AS5READ = 'ANALGESICS - READING PREFERENCE'
   ANALNONE= 'HAS NEVER TAKEN ANALGESICS FOR NONMEDICAL REASONS'
   DARVON  = 'DARVON EVER TAKEN FOR NONMEDICAL REASONS'
   DOLENE  = 'DOLENE EVER TAKEN FOR NONMEDICAL REASONS'
   SK65A   = 'SK-65 EVER TAKEN FOR NONMEDICAL REASONS'
   WYGESIC = 'WYGESIC EVER TAKEN FOR NONMEDICAL REASONS'
   LEVODRO = 'LEVO-DROMORAN EVER TAKEN FOR NONMEDICAL REASONS'
   PERCODAN= 'PERCODAN EVER TAKEN FOR NONMEDICAL REASONS'
   DEMEROL = 'DEMEROL EVER TAKEN FOR NONMEDICAL REASONS'
   DILAUD  = 'DILAUDID EVER TAKEN FOR NONMEDICAL REASONS'
   TYLCOD  = 'TYLENOL W/CODEINE EVER TAKEN FOR NONMEDICAL REASON'
   PHENCOD = 'PHENAPHEN W/CODEINE EVER TAKEN FOR NONMEDICAL REAS'
   TALWIN  = 'TALWIN EVER TAKEN FOR NONMEDICAL REASONS'
   TALWINNX= 'TALWIN NX EVER TAKEN FOR NONMEDICAL REASONS'
   TALACEN = 'TALACEN EVER TAKEN FOR NONMEDICAL REASONS'
   PROPOXY = 'PROPOXYPHENE EVER TAKEN FOR NONMEDICAL REASONS'
   CODEINE = 'CODEINE EVER TAKEN FOR NONMEDICAL REASONS'
   ANILERID= 'ANILERIDINE EVER TAKEN FOR NONMEDICAL REASONS'
   MORPHINE= 'MORPHINE EVER TAKEN FOR NONMEDICAL REASONS'
   METHDON = 'METHADONE EVER TAKEN FOR NONMEDICAL REASONS'
   STADOL  = 'STADOL EVER TAKEN FOR NONMEDICAL REASONS'
   ANALNEWA= 'OTHER ANALGESIC EVER USED (FIRST MENTION)'
   ANALNEWB= 'OTHER ANALGESIC EVER USED (SECOND MENTION)'
   ANLNOSP = 'OTHER ANALGESIC EVER USED (NOT SPECIFIED)'
   ANLDKNAM= 'USED ANALGESIC, DON''T KNOW NAME'
   ANALAGE = 'AGE FIRST TOOK ANALGESIC FOR NONMEDICAL REASONS'
   ANALTOT = '# TIMES EVER TOOK ANALGESIC FOR NONMEDICAL REASONS'
   ANALREC = 'MOST RECENT TIME USED ANALGESIC NONMEDICAL REASON'
   ANLALC  = 'ALCOHOL USED W/ANALGESIC PAST 12 MONTHS'
   ANLSED  = 'SEDATIVES USED W/ANALGESIC PAST 12 MONTHS'
   ANLTRAN = 'TRANQUILIZERS USED W/ANALGESIC PAST 12 MONTHS'
   ANLSTM  = 'STIMULANTS USED W/ANALGESIC PAST 12 MONTHS'
   ANLMJ   = 'MARIJUANA USED W/ANALGESIC PAST 12 MONTHS'
   ANLINH  = 'INHALANTS USED W/ANALGESIC PAST 12 MONTHS'
   ANLCOC  = 'COCAINE USED W/ANALGESIC PAST 12 MONTHS'
   ANLHAL  = 'HALLUCINOGENS USED W/ANALGESIC PAST 12 MONTHS'
   ANLOPT  = 'HEROIN USED W/ANALGESIC PAST 12 MONTHS'
   ANLNONE = 'NONE OF LISTED DRUGS USED W/ANALGESIC PAST 12 MOS'
   MJOPP   = 'AGE AT FIRST CHANCE TO TRY MARIJUANA/HASH'
   MJAGE   = 'AGE WHEN FIRST USED MARIJUANA/HASH'
   MJTOT   = '# TIMES USED MARIJUANA/HASH IN LIFE'
   MJREC   = 'MOST RECENT TIME USED MARIJUANA/HASH'
   MJDAY30A= '# DAYS USED MARIJUANA/HASH IN PAST 30 DAYS'
   MJAV30A = '# JOINTS SMOKED PER DAY IN PAST 30 DAYS'
   MJAMT30A= 'TOTAL AMOUNT MARIJUANA USED PAST 30 DAYS'
   MJALC30A= 'FREQ USED MARIJUANA/ALCOHOL TOGETHER PAST 30 DAYS'
   MJYRFREQ= 'FREQUENCY USED MARIJUANA PAST 12 MONTHS'
   MJALC   = 'ALCOHOL USED W/MARIJUANA PAST 12 MONTHS'
   MJSED   = 'SEDATIVES USED W/MARIJUANA PAST 12 MONTHS'
   MJTRAN  = 'TRANQUILIZERS USED W/MARIJUANA PAST 12 MONTHS'
   MJSTM   = 'STIMULANTS USED W/MARIJUANA PAST 12 MONTHS'
   MJANAL  = 'ANALGESICS USED W/MARIJUANA PAST 12 MONTHS'
   MJINH   = 'INHALANTS USED W/MARIJUANA PAST 12 MONTHS'
   MJCOC   = 'COCAINE USED W/MARIJUANA PAST 12 MONTHS'
   MJHAL   = 'HALLUCINOGENS USED W/MARIJUANA PAST 12 MONTHS'
   MJOPT   = 'HEROIN USED W/MARIJUANA PAST 12 MONTHS'
   MJNONE  = 'NONE OF LISTED DRUGS USED W/MARIJUANA PAST 12 MOS'
   AS7READ = 'INHALANTS - READING PREFERENCE'
   INHAGE  = 'AGE WHEN FIRST SNIFFED ONE OF THESE INHALANTS'
   GAS     = 'EVER INHALED GASOLINE OR LIGHTER FLUIDS'
   SPPAINT = 'EVER INHALED SPRAY PAINTS'
   AEROS   = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE    = 'EVER INHALED SHOESHINE LIQUID/GLUE/TOLUENE'
   SOLVENT = 'EVER INHALED LACQUER THINNER/PAINT SOLVENTS'
   AMYLNIT = 'EVER INHALED AMYL NITRITE/LOCKER RM ODORIZER/RUSH'
   ETHER   = 'EVER INHALED HALOTHANE/ETHER/OTHER ANESTHETICS'
   NITOXID = 'EVER INHALED NITROUS OXIDE/WHIPPETS'
   CLEFLU  = 'EVER INHALED CORRECTION FLD/DEGREASER/CLEANING FLD'
   INHNEWA = 'OTHER SUBSTANCE EVER INHALED (FIRST MENTION)'
   INHNEWB = 'OTHER SUBSTANCE EVER INHALED (SECOND MENTION)'
   INHNOSP = 'EVER INHALED OTHER SUBSTANCES (NOT SPCEIFIED)'
   INHTOT  = '# TIMES USED INHALANT IN LIFETIME'
   GAS30A  = 'INHALED GASOLINE OR LIGHTER FLUID PAST 30 DAYS'
   SPPAN30A= 'INHALED SPRAY PAINTS PAST 30 DAYS'
   AEROS30A= 'INHALED OTHER AEROSOL SPRAYS PAST 30 DAYS'
   GLUE30A = 'INHALED SHOESHINE LIQUID/GLUE/TOLUENE PAST 30 DAYS'
   SOLVN30A= 'INHALED LACQUER THINNER/PAINT SOLVENTS PAST 30 DAY'
   AMLNT30A= 'INHALED AMYL NITRITE/LOCKER RM ODORIZER PST 30 DYS'
   ETHER30A= 'INHALED HALOTHANE/ETHER/OTH ANESTHETICS PST 30 DYS'
   NOX30A  = 'INHALED NITROUS OXIDE PAST 30 DAYS'
   CLFL30A = 'INHALED CORRECTION FLD/DEGREASER/CLN FLD PST 30 DY'
   INNEW30A= 'OTHER INHALANT USED PAST 30 DAYS (FIRST MENTION)'
   INNEW30B= 'OTHER INHALANT USED PAST 30 DAYS (SECOND MENTION)'
   IN30NOSP= 'OTHER INHALANT USED PAST 30 DAYS (NOT SPECIFIED)'
   INH30NO = 'DID NOT USE ANY INHALANT PAST 30 DAYS'
   INHDY30A= '# DAYS USED AN INHALANT IN PAST 30 DAYS'
   INHREC  = 'MOST RECENT TIME USED INHALANT'
   INHEFF  = 'USUAL AMOUNT (EFFECTS) OF INHALANTS USED'
   INHPO   = 'EVER PASSED OUT FROM USING INHALANTS'
   INHQNC1 = 'QUESTION 1 NOT CLEAR'
   INHQNC2 = 'QUESTION 2 NOT CLEAR'
   INHQNC3 = 'QUESTION 3 NOT CLEAR'
   INHQNC4 = 'QUESTION 4 NOT CLEAR'
   INHQNC5 = 'QUESTION 5 NOT CLEAR'
   INHQNC6 = 'QUESTION 6 NOT CLEAR'
   INHQNC7 = 'QUESTION 7 NOT CLEAR'
   INHQNC8 = 'QUESTION 8 NOT CLEAR'
   INHQNC9 = 'ALL QUESTIONS CLEAR'
   INHANSY = 'ANSWER MARKED FOR EACH QUESTION'
   COCOPP  = 'AGE AT FIRST CHANCE TO TRY COCAINE'
   COCAGE  = 'AGE WHEN FIRST USED COCAINE'
   COCTOT  = '# TIMES USED COCAINE IN LIFE'
   COCREC  = 'MOST RECENT TIME USED COCAINE (IN ANY FORM)'
   COCUS30A= '# DAYS USED COCAINE PAST 30 DAYS'
   COC30ALC= 'FREQ. USED COCAINE/ALCOHOL TOGETHER PAST 30 DAYS'
   COCYRFRQ= 'FREQUENCY USED COCAINE PAST 12 MONTHS'
   COCALC  = 'ALCOHOL USED W/COCAINE PAST 12 MONTHS'
   COCSED  = 'SEDATIVES USED W/COCAINE PAST 12 MONTHS'
   COCTRAN = 'TRANQUILIZERS USED W/COCAINE PAST 12 MONTHS'
   COCSTM  = 'STIMULANTS USED W/COCAINE PAST 12 MONTHS'
   COCANAL = 'ANALGESICS USED W/COCAINE PAST 12 MONTHS'
   COCINH  = 'INHALANTS USED W/COCAINE PAST 12 MONTHS'
   COCMJ   = 'MARIJUANA USED W/COCAINE PAST 12 MONTHS'
   COCHAL  = 'HALLUCINOGENS USED W/COCAINE PAST 12 MONTHS'
   COCOPT  = 'HEROIN USED W/COCAINE PAST 12 MONTHS'
   COCNONE = 'NONE OF LISTED DRUGS USED W/COCAINE PAST 12 MONTHS'
   COCSNIFF= 'SNIFFED/SNORTED COCAINE THRU NOSE IN PAST 12 MOS.'
   COCSWAL = 'SWALLOWED/DRANK COCAINE IN PAST 12 MONTHS'
   COCIV   = 'INJECTED COCAINE WITH A NEEDLE IN PAST 12 MONTHS'
   FREEBASE= 'SMOKED/FREE-BASED COCAINE IN PAST 12 MONTHS'
   COCNEWA = 'OTHER WAY COCAINE USED PAST 12 MOS. (ONLY MENTION)'
   COCNOSP = 'OTHER WAY COCAINE USED PAST 12 MOS (NOT SPECIFIED)'
   CONDLREC= 'MOST RECENT TIME USED COCAINE WITH A NEEDLE'
   CRAKREC = 'MOST RECENT TIME USED CRACK'
   CRKAM30A= '# OF VIALS OF ''CRACK'' USED IN PAST 30 DAYS'
   CRAKBUCK= '$ AMOUNT SPENT ON ''CRACK'' USED IN PAST 30 DAYS'
   COCAM30A= '# OF GRAMS OF COCAINE USED IN PAST 30 DAYS'
   COCBUCK = '$ AMOUNT SPENT ON COCAINE USED IN PAST 30 DAYS'
   AS9READ = 'HALLUCINOGENS - READING PREFERENCE'
   LSD     = 'EVER USED LSD (''ACID'', ''WHITE LIGHTNING'')'
   PEYOTE  = 'EVER USED PEYOTE'
   MESC    = 'EVER USED MESCALINE'
   PSILCY  = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   PCP     = 'EVER USED PCP (''ANGEL DUST'', PHENCYCLIDINE)'
   ECSTASY = '(MDMA)'
   HALNEWA = 'OTHER HALLUCINOGEN EVER USED (ONLY MENTION)'
   HALNOSP = 'OTHER HALLUCINOGEN EVER USED (NOT SPECIFIED)'
   HALLOPP = 'AGE AT FIRST CHANCE TO TRY HALLUCINOGEN'
   HALLAGE = 'AGE WHEN FIRST USED LSD/PCP/OTHER HALLUCINOGEN'
   HALLTOT = '# TIMES USED LSD/PCP/OTHER HALLUCINOGEN IN LIFE'
   HALLREC = 'MOST RECENT TIME USED HALLUCINOGEN'
   HAL30USE= '# DAYS USED HALLUCINOGEN PAST 30 DAYS'
   PCPREC  = 'MOST RECENT TIME USED PCP'
   PCPFLASH= 'EVER HAD FLASHBACKS WHEN USED PCP'
   PCPSENSE= 'EVER HAD TROUBLE SEEING/HEARING WHEN USED PCP'
   PCPFEELV= 'EVER FELT VIOLENT WHEN USED PCP'
   PCPACTV = 'EVER ACTED VIOLENT OR AGGRESSIVE WHEN USED PCP'
   PCPNEWA = 'OTHER REACTION EVER HAD TO PCP (FIRST MENTION)'
   PCPNEWB = 'OTHER REACTION EVER HAD TO PCP (SECOND MENTION)'
   PCPNEWC = 'OTHER REACTION EVER HAD TO PCP (THIRD MENTION)'
   PCPNOSP = 'OTHER REACTIONS EVER HAD TO PCP (NOT SPECIFIED)'
   PCPNORCT= 'NEVER HAD ANY REACTION WHEN USED PCP'
   HALLQCL = 'UNDERSTOOD THE LAST 3 QUESTIONS'
   AS10READ= 'HEROIN - READING PREFERENCE'
   HEROPP  = 'AGE AT FIRST CHANCE TO TRY HEROIN'
   HERAGE  = 'AGE WHEN FIRST USED HEROIN'
   HERTOT  = '# TIMES USED HEROIN IN LIFE'
   HERREC  = 'MOST RECENT TIME USED HEROIN'
   HER30USE= '# DAYS USED HEROIN PAST 30 DAYS'
   HERNEEDL= 'EVER USED HEROIN WITH A NEEDLE'
   HRNDLREC= 'MOST RECENT TIME USED HEROIN WITH A NEEDLE'
   AS11READ= 'DRUGS - READING PREFERENCE'
   NODRUGS = 'DID NOT USE CIGARETTES/ALCOHOL/OTHR DRUGS PAST YR'
   CDCIG   = 'TRIED TO CUT DOWN ON USE OF CIGARETTES PAST YEAR'
   CDALC   = 'TRIED TO CUT DOWN ON USE OF ALCOHOL PAST YEAR'
   CDSED   = 'TRIED TO CUT DOWN ON USE OF SEDATIVES PAST YEAR'
   CDTRAN  = 'TRIED TO CUT DOWN ON USE OF TRANQUILIZERS PAST YR'
   CDSTM   = 'TRIED TO CUT DOWN ON USE OF STIMULANTS PAST YEAR'
   CDANAL  = 'TRIED TO CUT DOWN ON USE OF ANALGESICS PAST YEAR'
   CDMJ    = 'TRIED TO CUT DOWN ON USE OF MARIJUANA PAST YEAR'
   CDINH   = 'TRIED TO CUT DOWN ON USE OF INHALANTS PAST YEAR'
   CDCOC   = 'TRIED TO CUT DOWN ON USE OF COCAINE PAST YEAR'
   CDHALL  = 'TRIED TO CUT DOWN ON USE OF HALLUCINOGENS PAST YR'
   CDHER   = 'TRIED TO CUT DOWN ON USE OF HEROIN PAST YEAR'
   CDOTHOP = 'TRIED TO CUT DOWN ON USE OF OTHER OPIATES PAST YR'
   CDNONE  = 'DID NOT TRY TO CUT DOWN ON ANY DRUG USED PAST YR'
   EFFCIG  = 'NEEDED MORE CIGARETTES TO GET SAME EFFECT PAST YR'
   EFFALC  = 'NEEDED MORE ALCOHOL TO GET SAME EFFECT PAST YEAR'
   EFFSED  = 'NEEDED MORE SEDATIVES TO GET SAME EFFECT PAST YEAR'
   EFFTRAN = 'NEEDED MORE TRANQ. TO GET SAME EFFECT PAST YEAR'
   EFFSTM  = 'NEEDED MORE STIMULANTS TO GET SAME EFFECT PAST YR'
   EFFANAL = 'NEEDED MORE ANALGESICS TO GET SAME EFFECT PAST YR'
   EFFMJ   = 'NEEDED MORE MARIJUANA TO GET SAME EFFECT PAST YEAR'
   EFFINH  = 'NEEDED MORE INHALANTS TO GET SAME EFFECT PAST YEAR'
   EFFCOC  = 'NEEDED MORE COCAINE TO GET SAME EFFECT PAST YEAR'
   EFFHALL = 'NEEDED MORE HALLUCIN. TO GET SAME EFFECT PAST YEAR'
   EFFHER  = 'NEEDED MORE HEROIN TO GET SAME EFFECT PAST YEAR'
   EFFOTHOP= 'NEEDED MORE OTHER OPIATES TO GET SAME EFF PAST YR'
   EFFNONE = 'DID NOT NEED MORE OF ANY DRUG FOR SAME EFF PAST YR'
   UDAYCIG = 'USED CIGARETTES DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYALC = 'USED ALCOHOL DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYSED = 'USED SEDATIVES DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYTRAN= 'USED TRANQUILIZERS DAILY FOR 2+ WKS IN PAST YEAR'
   UDAYSTM = 'USED STIMULANTS DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYANAL= 'USED ANALGESICS DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYMJ  = 'USED MARIJUANA DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYINH = 'USED INHALANTS DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYCOC = 'USED COCAINE DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYHALL= 'USED HALLUCINOGENS DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYHER = 'USED HEROIN DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYOTH = 'USED OTHER OPIATES DAILY FOR 2+ WEEKS IN PAST YEAR'
   UDAYNONE= 'DID NOT USE ANY DRUG DAILY FOR 2+ WEEKS IN PAST YR'
   DEPCIG  = 'FELT DEPENDENT ON CIGARETTES PAST YEAR'
   DEPALC  = 'FELT DEPENDENT ON ALCOHOL PAST YEAR'
   DEPSED  = 'FELT DEPENDENT ON SEDATIVES PAST YEAR'
   DEPTRAN = 'FELT DEPENDENT ON TRANQUILIZERS PAST YEAR'
   DEPSTM  = 'FELT DEPENDENT ON STIMULANTS PAST YEAR'
   DEPANAL = 'FELT DEPENDENT ON ANALGESICS PAST YEAR'
   DEPMJ   = 'FELT DEPENDENT ON MARIJUANA PAST YEAR'
   DEPINH  = 'FELT DEPENDENT ON INHALANTS PAST YEAR'
   DEPCOC  = 'FELT DEPENDENT ON COCAINE PAST YEAR'
   DEPHALL = 'FELT DEPENDENT ON HALLUCINOGENS PAST YEAR'
   DEPHER  = 'FELT DEPENDENT ON HEROIN PAST YEAR'
   DEPOTHOP= 'FELT DEPENDENT ON OTHER OPIATES PAST YEAR'
   DEPNONE = 'DID NOT FEEL DEPENDENT ON ANY DRUG USED PAST YEAR'
   WSCIG   = 'FELT SICK WHEN CUT DOWN ON CIGARETTES PAST YEAR'
   WSALC   = 'FELT SICK WHEN CUT DOWN ON ALCOHOL PAST YEAR'
   WSSED   = 'FELT SICK WHEN CUT DOWN ON SEDATIVES PAST YEAR'
   WSTRAN  = 'FELT SICK WHEN CUT DOWN ON TRANQUILIZERS PAST YEAR'
   WSSTM   = 'FELT SICK WHEN CUT DOWN ON STIMULANTS PAST YEAR'
   WSANAL  = 'FELT SICK WHEN CUT DOWN ON ANALGESICS PAST YEAR'
   WSMJ    = 'FELT SICK WHEN CUT DOWN ON MARIJUANA PAST YEAR'
   WSINH   = 'FELT SICK WHEN CUT DOWN ON INHALANTS PAST YEAR'
   WSCOC   = 'FELT SICK WHEN CUT DOWN ON COCAINE PAST YEAR'
   WSHALL  = 'FELT SICK WHEN CUT DOWN ON HALLUCINOGENS PAST YEAR'
   WSHER   = 'FELT SICK WHEN CUT DOWN ON HEROIN PAST YEAR'
   WSOTHOP = 'FELT SICK WHEN CUT DOWN ON OTHER OPIATES PAST YEAR'
   WSNONE  = 'DID NOT HAVE WITHDRAWAL SYMPTOMS PAST YEAR'
   SHRNDLMO= 'EVER SHARE A NEEDLE DURING PAST 30 DAYS'
   NRSHRNDL= '# PERSONS SHARED NEEDLE WITH IN PAST 30 DAYS'
   CLEANNDL= 'USUAL WAY CLEANED WORKS PAST 30 DAYS'
   SHRWMALE= 'LAST PERSON SHARED NEEDLE WITH WAS MALE'
   SHRWSEXP= 'LAST PERSON SHARED NEEDLE WITH WAS SEX PARTNER'
   SHRWRACE= 'LAST PERSON SHARED NEEDLE WITH WAS SAME RACE'
   RSNNOSHR= 'MAIN REASON DID NOT SHARE NEEDLE IN PAST 30 DAYS'
   NOBOOZYR= 'DID NOT DRINK ANY BEER/WINE/LIQUOR PAST 12 MONTHS'
   ALCAGGR = 'FELT AGRESSIVE OR CROSS WHILE DRINKING PAST YEAR'
   ALCARGUM= 'GOT INTO HEATED ARGUMENT WHILE DRINKING PAST YEAR'
   ALCABSNT= 'STAYED OUT OF WORK/SCHOOL DUE TO HANGOVER PAST YR'
   ALCHIGH = 'HIGH OR LITTLE DRUNK ON JOB OR AT SCHOOL PAST YEAR'
   ALCJOB  = 'LOST/NEARLY LOST JOB DUE TO DRINKING PAST YEAR'
   ALCMATCD= 'TOLD BY SPOUSE/DATE TO CUT DOWN DRINKING PAST YEAR'
   ALCRELCD= 'TOLD BY RELATIVE TO CUT DOWN DRINKING PAST YEAR'
   ALCFRDCD= 'TOLD BY FRIENDS TO CUT DOWN DRINKING PAST YEAR'
   ALCTOSS = 'TOSSED DOWN DRINKS FAST TO GET QUICKER EFF PAST YR'
   ALCHOLIC= 'WAS AFRAID MIGHT BE/BECOME AN ALCOHOLIC PAST YEAR'
   ALCDRUNK= 'STAYED DRUNK MORE THAN 1 DAY AT A TIME PAST YEAR'
   ALCINTOX= 'COULDN''T STOP DRINKING TILL COMPLETELY INTOXICATED'
   ALCREM  = 'COULDN''T REMEM. THINGS DONE WHILE DRINKING PAST YR'
   ALCQUICK= 'HAD QUICK DRINK WHEN NO ONE WAS LOOKING PAST YEAR'
   ALCMORN = 'OFTEN HAD A DRINK FIRST THING IN MORNING PAST YEAR'
   ALCSHOOK= 'HANDS SHOOK AFTER DRINKING DAY BEFORE IN PAST YEAR'
   ALCALONE= 'SOMETIMES GOT HIGH/DRUNK WHILE DRINKING ALONE'
   ALCBRKPM= 'KEPT ON DRINKING AFTER PROMISING MYSELF TO STOP'
   AS13NONE= 'NEVER USED ANY OF THE SUBSTANCES LISTED'
   DRDEPRSS= 'BECAME DEPRESSED/LOST INTEREST DUE TO DRUG USE'
   DEPDRG1A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-1ST MENTION'
   DEPDRG2A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-2ND MENTION'
   DEPDRG3A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-3RD MENTION'
   DEPDRG4A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-4TH MENTION'
   DEPDRG5A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-5TH MENTION'
   DRARGUM = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE TO DRUG USE'
   ARGDRG1A= 'DRUG CAUSING ARGUMENTS/FIGHTS-1ST MENTION'
   ARGDRG2A= 'DRUG CAUSING ARGUMENTS/FIGHTS-2ND MENTION'
   ARGDRG3A= 'DRUG CAUSING ARGUMENTS/FIGHTS-3RD MENTION'
   ARGDRG4A= 'DRUG CAUSING ARGUMENTS/FIGHTS-4TH MENTION'
   ARGDRG5A= 'DRUG CAUSING ARGUMENTS/FIGHTS-5TH MENTION'
   DRALONE = 'FELT ALONE/ISOLATED PAST YEAR DUE TO DRUG USE'
   ALNDRG1A= 'DRUG CAUSING FEELING ALONE/ISOLATED-1ST MENTION'
   ALNDRG2A= 'DRUG CAUSING FEELING ALONE/ISOLATED-2ND MENTION'
   ALNDRG3A= 'DRUG CAUSING FEELING ALONE/ISOLATED-3RD MENTION'
   ALNDRG4A= 'DRUG CAUSING FEELING ALONE/ISOLATED-4TH MENTION'
   ALNDRG5A= 'DRUG CAUSING FEELING ALONE/ISOLATED-5TH MENTION'
   DRANX   = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO DRUG USE'
   ANXDRG1A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-1ST MENTION'
   ANXDRG2A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-2ND MENTION'
   ANXDRG3A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-3RD MENTION'
   ANXDRG4A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-4TH MENTION'
   ANXDRG5A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-5TH MENTION'
   DRHEALTH= 'HAD HEALTH PROBLEMS PAST YEAR DUE TO DRUG USE'
   HLTDRG1A= 'DRUG CAUSING HEALTH PROBLEMS-1ST MENTION'
   HLTDRG2A= 'DRUG CAUSING HEALTH PROBLEMS-2ND MENTION'
   HLTDRG3A= 'DRUG CAUSING HEALTH PROBLEMS-3RD MENTION'
   HLTDRG4A= 'DRUG CAUSING HEALTH PROBLEMS-4TH MENTION'
   HLTDRG5A= 'DRUG CAUSING HEALTH PROBLEMS-5TH MENTION'
   DRNTHINK= 'HAD DIFFCLTY THNKNG CLEARLY PST YR DUE TO DRUG USE'
   NTKDRG1A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-1ST MENTION'
   NTKDRG2A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-2ND MENTION'
   NTKDRG3A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-3RD MENTION'
   NTKDRG4A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-4TH MENTION'
   NTKDRG5A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-5TH MENTION'
   DRUPSET = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO DRUG USE'
   UPSDRG1A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-1ST MENTION'
   UPSDRG2A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-2ND MENTION'
   UPSDRG3A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-3RD MENTION'
   UPSDRG4A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-4TH MENTION'
   UPSDRG5A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-5TH MENTION'
   DRLSWORK= 'GOT LESS WRK DONE @ SCH/JOB PST YR DUE TO DRUG USE'
   LSWDRG1A= 'DRUG CAUSING LESS WORK GETTING DONE-1ST MENTION'
   LSWDRG2A= 'DRUG CAUSING LESS WORK GETTING DONE-2ND MENTION'
   LSWDRG3A= 'DRUG CAUSING LESS WORK GETTING DONE-3RD MENTION'
   LSWDRG4A= 'DRUG CAUSING LESS WORK GETTING DONE-4TH MENTION'
   LSWDRG5A= 'DRUG CAUSING LESS WORK GETTING DONE-5TH MENTION'
   DRSUSPIC= 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE TO DRUG USE'
   SSPDRG1A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-1ST MENTION'
   SSPDRG2A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-2ND MENTION'
   SSPDRG3A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-3RD MENTION'
   SSPDRG4A= 'DRUG CAUSING FEELING SUSPIC.STRUST-4TH MENTION'
   SSPDRG5A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-5TH MENTION'
   DRCOPE  = 'PROBLEMS HARDER TO HANDLE PAST YR DUE TO DRUG USE'
   CPEDRG1A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-1ST MENTION'
   CPEDRG2A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-2ND MENTION'
   CPEDRG3A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-3RD MENTION'
   CPEDRG4A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-4TH MENTION'
   CPEDRG5A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-5TH MENTION'
   DREMGMED= 'HAD TO GET EMERG MED HELP PST YR DUE TO DRUG USE'
   EMDRG1A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-1ST MENTION'
   EMDRG2A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-2ND MENTION'
   EMDRG3A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-3RD MENTION'
   EMDRG4A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-4TH MENTION'
   EMDRG5A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-5TH MENTION'
   RSKPKCIG= 'RISK IF SMOKE 1 OR MORE PACKS CIGARETTES PER DAY'
   RSKMJOCC= 'RISK IF SMOKE MARIJUANA OCCASIONALLY'
   RSKMJREG= 'RISK IF SMOKE MARIJUANA REGULARLY'
   RKTRYPCP= 'RISK IF TRY PCP ONCE OR TWICE'
   RKPCPREG= 'RISK IF USE PCP REGULARLY'
   RKTRYHER= 'RISK IF TRY HEROIN ONCE OR TWICE'
   RKHERREG= 'RISK IF USE HEROIN REGULARLY'
   RKTRYCOC= 'RISK IF TRY COCAINE ONCE OR TWICE'
   RKCOCOCC= 'RISK IF USE COCAINE OCCASIONALLY'
   RKCOCREG= 'RISK IF USE COCAINE REGULARLY'
   RKCRKOCC= 'RISK IF USE ''CRACK'' OCCASIONALLY'
   RK2DRINK= 'RISK IF TAKE 1 OR 2 DRINKS NEARLY EVERY DAY'
   RK5DRINK= 'RISK IF TAKE 4 OR 5 DRINKS NEARLY EVERY DAY'
   RSKBINGE= 'RISK IF HAVE 5 OR MORE DRINKS ONCE OR TWICE A WEEK'
   HIGHBP  = 'EVER DIAGNOSED AS HAVING HIGH BLOOD PRESSURE'
   BPMED   = 'MEDICATION EVER PRESCRIBED FOR HIGH BLOOD PRESSURE'
   WALKPAIN= 'EVER HAD PAIN IN CHEST FROM EXERTION'
   TIMEPAIN= 'EVER HAD SEVERE CHEST PAIN LASTING 1/2 HR OR MORE'
   UPSHOR  = 'EVER HAD SHORTNESS OF BREATH FROM EXERTION'
   ASTHMA  = 'EVER DIAGNOSED AS HAVING LUNG/CHEST CONDITION'
   TRPSYCH = 'EVER TREATED FOR PSYCHOLOGICAL/EMOTIONAL CONDITION'
   HEART   = 'EVER DIAGNOSED AS HAVING HEART CONDITION/PROBLEM'
   FLU     = 'GET BAD COLD OR FLU EVERY YEAR'
   ALLERG  = 'HAS HAY FEVER'
   HOSPYR  = 'HOSPITALIZED OVERNIGHT FOR INJURY/ILLNESS PAST YR'
   SOREYR  = 'HAD SORE THROAT LASTING 3 OR MORE DAYS IN PAST YR'
   RUNNYYR = 'HAD RUNNY NOSE LASTING 3 OR MORE DAYS IN PAST YEAR'
   COUGHYR = 'HAD COUGH LASTING ABOUT A WK 3/MORE TIMES PAST YR'
   PHLEGMYR= 'HAD COUGH W/PHLEGM LASTING 3 OR MORE WEEKS PAST YR'
   HEALTHYR= 'HEALTH FOR PAST 12 MONTHS'
   MARITAL = 'MARITAL STATUS'
   NOMARR  = '# TIMES MARRIED'
   WORKSTAT= 'PRESENT WORK SITUATION'
   PAYMO   = 'MONTH LAST WORKED FOR PAY'
   PAYYR   = 'YEAR (19__) LAST WORKED FOR PAY'
   NO5JOB  = '# OF JOBS LAST 5 YEARS'
   WORKDAYS= '# DAYS MISSED WORK DUE TO ILL/INJURY LAST 30 DAYS'
   WORKBLAH= '# DAYS SKIPPED WORK LAST 30 DAYS'
   CWE     = 'CHIEF WAGE EARNER IN HOUSEHOLD (RELATION TO RESP)'
   FULLPART= 'WORK STATUS OF CHIEF WAGE EARNER'
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL'
   ENROLLD = 'NOW ENROLLED IN ANY SCHOOL'
   SCHPLANS= 'PLANS FOR FUTURE SCHOOLING'
   STUDENT = 'STUDENT STATUS NOW'
   SCHDAYS = '# OF DAYS MISSED SCHOOL DUE TO ILL/INJURY LAST MO.'
   SKIPPED = '# DAYS SKIPPED SCHOOL LAST MONTH'
   MILES   = '# MILES RESPONDENT DRIVES IN A TYPICAL WEEK'
   ACCID   = 'HAD MOTOR VEHICLE ACCIDENT IN PAST 12 MONTHS'
   NOCHILD = '# OF BIOLOGICAL CHILDREN'
   TOTPEOP = '# OF RESIDENTS IN HOUSEHOLD'
   MOTHER  = 'MOTHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   STEPMOM = 'STEPMOTHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   FATHER  = 'FATHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   STEPDAD = 'STEPFATHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   SPOUSE  = 'SPOUSE/LIVE-IN PARTNER OF RESP MEMBER OF HOUSEHOLD'
   INLAW   = '# PARENT(S)-IN-LAW OF RESP LIVING IN HOUSEHOLD'
   OWNCHILD= '# BIOLOGICAL CHILDREN OF RESP LIVING IN HOUSEHOLD'
   STEPCHLD= '# ADOPTED/STEPCHILDREN OF RESP LIVING IN HOUSEHOLD'
   BROSIS  = '# BROTHERS/SISTERS OF RESP LIVING IN HOUSEHOLD'
   OTHREL  = '# OTHER RELATIVES OF RESP LIVING IN HOUSEHOLD'
   FRIENDS = '# FRIENDS/ROOMMATES OF RESP LIVING IN HOUSEHOLD'
   OTHERNON= '# OTHER PEOPLE UNRELATD TO RESP LIVING IN HOUSEHLD'
   SERVICE = 'EVER SERVED IN ARMED FORCES'
   MILSTAT = 'CURRENT MILITARY STATUS'
   MOVDAWAY= 'ANY RESIDENT FOR 6 MONTHS IN PAST YEAR NOW MOVED'
   DORM    = '# OF FORMER RESIDENTS NOW LIVING AT COLLEGE'
   MILBASE = '# OF FORMER RESIDENTS NOW LIVING ON MILITARY BASE'
   HOSP    = '# OF FORMR RESDNTS NOW LVNG IN JAIL,HOSP,OTHR INST'
   TELNO   = '# OF NON-BUSINESS PHONE NUMBERS IN HOUSEHOLD'
   MOVES   = '# OF TIMES MOVED PAST 5 YEARS'
   INCOME  = 'PERSONAL EARNINGS FROM EMPLOYMENT FOR PAST YEAR'
   BTIME   = 'BEGINNING TIME OF INTERVIEW'
   BAP     = 'BEGINNING TIME OF INTERVIEW - AM/PM INDICATOR'
   ETIME   = 'ENDING TIME OF INTERVIEW'
   EAP     = 'ENDING TIME OF INTERVIEW - AM/PM INDICATOR'
   LANGVER = 'LANGUAGE VERSION'
   UNDINT  = 'ESTIMATE RESPONDENT''S UNDERSTANDING OF INTERVIEW'
   COOPINT = 'COOPERATION OF RESPONDENT'
   PRIVACY = 'SCALE FOR PRIVACY DURING INTERVIEW'
   PPRES   = 'PARENT(S) PRESENT OR LISTENING TO INTERVIEW'
   SPRES   = 'SPOUSE PRESENT OR LISTENING TO INTERVIEW'
   PARPRES = 'LIVE-IN PARTNR/DATE PRSNT OR LISTENNG TO INTERVIEW'
   OARPRES = 'ADULT RELATIVE(S) PRESENT/LISTENING TO INTERVIEW'
   OAPRES  = 'OTHER ADULT(S) PRESENT OR LISTENING TO INTERVIEW'
   CPRES   = 'CHILD(REN) UNDER 15 PRESENT/LISTENING TO INTERVIEW'
   OPRESSPA= 'OTHER PERSON(S) PRESENT/LISTENING (FIRST MENTION)'
   OPRESSPB= 'OTHER PERSON(S) PRESENT/LISTENING (SECOND MENTION)'
   OPRESNSP= 'OTHER PERSON(S) PRESENT/LISTENING (NOT SPECIFIED)'
   REGION  = 'CENSUS REGION'
   DIVISION= 'CENSUS DIVISION CODE'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IIAGE   = 'IMPUTATION INDICATOR FOR AGE'
   AGEGR   = 'AGE GROUP'
   ORAGEGR = 'ORIGIN OF AGE GROUP VARIABLE'
   SEX     = 'SEX OF RESPONDENT'
   ORSEX   = 'ORIGIN OF SEX VARIABLE'
   IRRACE  = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACE  = 'IMPUTATION INDICATOR FOR RACE'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IMPUTATION INDICATOR FOR HISPANIC ORIGIN'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC-ORIGIN GROUP'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRSEDRC = 'SEDATIVES RECENCY - IMPUTATION REVISED'
   IISEDRC = 'SEDATIVES RECENCY - IMPUTATION INDICATOR'
   IRTRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION REVISED'
   IITRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION INDICATOR'
   IRSTMRC = 'STIMULANTS RECENCY - IMPUTATION REVISED'
   IISTMRC = 'STIMULANTS RECENCY - IMPUTATION INDICATOR'
   IRANLRC = 'ANALGESICS RECENCY - IMPUTATION REVISED'
   IIANLRC = 'ANALGESICS RECENCY - IMPUTATION INDICATOR'
   IRCIGRC = 'CIGARETTES RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTES RECENCY - IMPUTATION INDICATOR'
   IROTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION REVISED'
   IIOTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION INDICATOR'
   IRINHRC = 'INHALANTS RECENCY - IMPUTATION REVISED'
   IIINHRC = 'INHALANTS RECENCY - IMPUTATION INDICATOR'
   IRCRKRC = 'CRACK RECENCY - IMPUTATION REVISED'
   IICRKRC = 'CRACK RECENCY - IMPUTATION INDICATOR'
   IRHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION REVISED'
   IIHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION INDICATOR'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   IRALCFQ = 'ALCOHOL FREQUENCY PAST  YEAR - IMPUTATION REVISED'
   IIALCFQ = 'ALCOHOL FREQUENCY - IMPUTATION INDICATOR'
   IRMJFQ  = 'MARIJUANA FREQUENCY PAST YEAR - IMPUTATION REVISED'
   IIMJFQ  = 'MARIJUANA FREQUENCY - IMPUTATION INDICATOR'
   IRCOCFQ = 'COCAINE FREQUENCY PAST YEAR - IMPUTATION REVISED'
   IICOCFQ = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   CATAGE  = 'AGE CATEGORY'
   CATAG2  = 'AGE CATEGORY RECODE'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   EDUCCAT = 'EDUCATION RECODE'
   EMPSTAT = 'EMPLOYMENT STATUS RECODE'
   SMOKCOK = 'SMOKED COCAINE IN PAST YEAR'
   CONDLRC2= 'RECENCY OF COCAINE USE W/NEEDLE (CONDLREC Recode)'
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYR   = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   SMKFLAG = 'SMOKELESS TOBACCO - EVER USED'
   SMKYR   = 'SMOKELESS TOBACCO - PAST YEAR USE'
   SMKMON  = 'SMOKELESS TOBACCO - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   CRKFLAG = 'CRACK - EVER USED'
   CRKYR   = 'CRACK - PAST YEAR USE'
   CRKMON  = 'CRACK - PAST MONTH USE'
   INHFLAG = 'INHALANTS - EVER USED'
   INHYR   = 'INHALANTS - PAST YEAR USE'
   INHMON  = 'INHALANTS - PAST MONTH USE'
   NEEDLREC= 'MOST RECENT TIME USED A NEEDLE TO INJECT ANY DRUG'
   NEDFLAG = 'NEEDLE USE (ANY DRUG) - EVER'
   NEDYR   = 'NEEDLE USE (ANY DRUG) - PAST YEAR'
   COCYRF  = 'COCAINE - ANY USE PAST YEAR'
   COCMONF = 'COCAINE - MONTHLY OR MORE FREQUENT USE PAST YEAR'
   COCWKF  = 'COCAINE - WEEKLY OR MORE FREQUENT USE PAST YEAR'
   ALCYRF  = 'ALCOHOL - ANY USE PAST YEAR'
   ALCMONF = 'ALCOHOL - MONTHLY OR MORE FREQUENT USE PAST YEAR'
   ALCWKF  = 'ALCOHOL - WEEKLY OR MORE FREQUENT USE PAST YEAR'
   MRJYRF  = 'MARIJUANA - ANY USE PAST YEAR'
   MRJMONF = 'MARIJUANA - MONTHLY OR MORE FREQUENT USE PAST YEAR'
   MRJWKF  = 'MARIJUANA - WEEKLY OR MORE FREQUENT USE PAST YEAR'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAG = 'ANY ILLICIT DRUG - EVER USED'
   SUMYR   = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMON  = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAG = 'MARIJUANA ONLY - EVER USED'
   MJOYR2  = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2 = 'MARIJUANA ONLY - PAST MONTH USE'
   VESTR   = 'STRATUM TO BE USED IN ANALYSIS'
   VEREP   = 'REPLICATE WITHIN ANALYSIS STRATUM'
   ANALWT  = 'ANALYSIS WEIGHT'
   ANALWT2 = 'ANALYSIS WEIGHT IN THOUSANDS OF PERSONS'
   CHAGE1  = 'NUMBER OF CHILDREN AGES 0 TO 2'
   CHAGE2  = 'NUMBER OF CHILDREN AGES 3 TO 5'
   CHAGE3  = 'NUMBER OF CHILDREN AGES 6 TO 8'
   CHAGE4  = 'NUMBER OF CHILDREN AGES 9 TO 11'
   CHAGE5  = 'NUMBER OF CHILDREN AGES 12 TO 14'
   CHAGE6  = 'NUMBER OF CHILDREN AGES 15 TO 17'
   CHAGE7  = 'NUMBER OF CHILDREN AGES 18 TO 24'
   CHAGE8  = 'NUMBER OF CHILDREN AGES 25 TO 34'
   CHAGE9  = 'NUMBER OF CHILDREN AGES 35+'
   CHAGE10 = 'NUMBER OF CHILDREN WITH AGES UNKNOWN OR UNSPECIFIED'
   CWEOCC2 = 'KIND OF WORK OF CHIEF WAGE EARNER'
   ROCCUP2 = 'KIND OF WORK OF RESPONDENT'
   BUSINES2= 'BUSINESS OR INDUSTRY OF RESPONDENT'
   CWEBUS2 = 'BUSINESS OR INDUSTRY OF CHIEF WAGE EARNER'
   POPDEN  = 'POPULATION DENSITY'
   MRJMON2 = 'MARIJUANA - PAST MONTH USE'
   ALCMON2 = 'ALCOHOL - PAST MONTH USE'
   CIGMON2 = 'CIGARETTES - PAST MONTH USE'
   LSD2    = 'EVER USED LSD'
   PEYOTE2 = 'EVER USED PEYOTE'
   MESC2   = 'EVER USED MESCALINE'
   PSILCY2 = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   GAS2    = 'EVER INHALED GASOLINE OR LIGHTER FLUID'
   SPPAINT2= 'EVER INHALED SPRAY PAINTS'
   AEROS2  = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE2   = 'EVER INHALED SHOESHINE LIQUID/GLUE/TOLUENE'
   SOLVENT2= 'EVER INHALED SOLVENTS'
   AMYLNIT2= 'EVER INHALED AMYL NITRITE/LOCKER RM ODORIZER/RUSH'
   ETHER2  = 'EVER INHALED HALOTHANE/ETHER/OTHER ANESTHETICS'
   NITOXID2= 'EVER INHALED NITROUS OXIDE/WHIPPETS RECODE'
   CLEFLU2 = 'EVER INHALED CORR. FLD/DEGREASER/CLEAN. FLD'
   COCSNIF2= 'SNIFFED/SNORTED COC. THRU NOSE PAST 12 MONTH'
   FREEBAS2= 'SMOKED/FREE-BASED COCAINE PAST 12 MONTHS'
   COCSWAL2= 'SWALLOWED/DRANK COCAINE PAST 12 MONTHS'
   COCIV2  = 'INJECTED COCAINE WITH NEEDLE PAST 12 MONTHS'
   COCNEWA2= 'OTHER WAY COCAINE USED PAST 12 MONTHS'
   MJTOT2  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT2 = '# TIMES USED COCAINE IN LIFE'
   MJTOT3  = '# TIMES USED MARIJUANA IN LIFE'
   COCTOT3 = '# TIMES USED COCAINE IN LIFE'
   MJDY30A2= '# DAYS USED MARIJUANA IN PAST 30 DAYS'
   ALCDAYS2= '# DAYS DRANK ALCOHOL IN PAST 30 DAYS'
   RACESEX = 'RACE AND SEX COMBINED'
   NOTMARJ = 'DRUG USE OTHER THAN MARIJUANA - PAST MONTH'
   EDUCCAT2= 'EDUCATION'
   EMPSTAT2= 'EMPLOYMENT STATUS'
   MJDY30A3= '# DAYS USED MARIJUANA IN PAST 30'
   ALCDAYS3= '# DAYS DRANK ALCOHOL IN PAST 30 DAYS'
   DRINKER = 'DRANK ALCOHOL - PAST 30 DAYS'
   HVYDRK  = 'DRANK ALCOHOL HEAVILY - PAST 30 DAYS'
   AVCIG2  = '# CIG. SMOKED PER DAY LAST 30'
   IRDEP   = 'DEPRESSION PST YR DUE TO DRUGS (L.I. DRDEPRSS)'
   IRARG   = 'ARGUMENTS PST YR DUE TO DRUGS (L.I. DRARGUM)'
   IRALN   = 'FELT ALONE PST YR DUE TO DRUGS (L.I. DRALONE)'
   IRANX   = 'FELT ANXIOUS PST YR DUE TO DRUGS (L.I. DRANX)'
   IRHLT   = 'HEALTH PROBS PST YR DUE TO DRUGS (L.I. DRHEALTH)'
   IRNTK   = 'DFF THNKNG CLR PST YR DUE TO DRUGS (L.I. DRNTHINK)'
   IRUPS   = 'FELT UPSET PST YR DUE TO DRUGS (L.I. DRUPSET)'
   IRLSW   = 'DID LESS WORK PST YR DUE TO DRUGS (L.I. DRLSWORK)'
   IRSSP   = 'FLT SUSPICIOUS PST YR DUE TO DRUGS (L.I. DRSUSPIC)'
   IRCPE   = 'PRB HARD TO HNDL PST YR DUE TO DRUGS (L.I. DRCOPE)'
   IREMG   = 'EMERG MED HELP PST YR DUE TO DRUGS (L.I. DREMGMED)'
   IRDEP1  = '1ST DRUG CAUSING DEPRESSION (L.I. DEPDRG1A)'
   IRDEP2  = '2ND DRUG CAUSING DEPRESSION (L.I. DEPDRG2A)'
   IRDEP3  = '3RD DRUG CAUSING DEPRESSION (L.I. DEPDRG3A)'
   IRDEP4  = '4TH DRUG CAUSING DEPRESSION (L.I. DEPDRG4A)'
   IRDEP5  = '5TH DRUG CAUSING DEPRESSION (L.I. DEPDRG5A)'
   IRARG1  = '1ST DRUG CAUSING ARGUMENTS (L.I. ARGDRG1A)'
   IRARG2  = '2ND DRUG CAUSING ARGUMENTS (L.I. ARGDRG2A)'
   IRARG3  = '3RD DRUG CAUSING ARGUMENTS (L.I. ARGDRG3A)'
   IRARG4  = '4TH DRUG CAUSING ARGUMENTS (L.I. ARGDRG4A)'
   IRARG5  = '5TH DRUG CAUSING ARGUMENTS (L.I. ARGDRG5A)'
   IRALN1  = 'LOGICALLY IMPUTED ALNDRG1A'
   IRALN2  = '2ND DRUG CAUSING FEELING ALONE (L.I. ALNDRG2A)'
   IRALN3  = '3RD DRUG CAUSING FEELING ALONE (L.I. ALNDRG3A)'
   IRALN4  = '4TH DRUG CAUSING FEELING ALONE (L.I. ALNDRG4A)'
   IRALN5  = '5TH DRUG CAUSING FEELING ALONE (L.I. ALNDRG5A)'
   IRANX1  = '1ST DRUG CAUSING FEELING ANXIOUS (L.I. ANXDRG1A)'
   IRANX2  = '2ND DRUG CAUSING FEELING ANXIOUS (L.I. ANXDRG2A)'
   IRANX3  = '3RD DRUG CAUSING FEELING ANXIOUS (L.I. ANXDRG3A)'
   IRANX4  = '4TH DRUG CAUSING FEELING ANXIOUS (L.I. ANXDRG4A)'
   IRANX5  = '5TH DRUG CAUSING FEELING ANXIOUS (L.I. ANXDRG5A)'
   IRHLT1  = '1ST DRUG CAUSING HEALTH PROBLEMS (L.I. HLTDRG1A)'
   IRHLT2  = '2ND DRUG CAUSING HEALTH PROBLEMS (L.I. HLTDRG2A)'
   IRHLT3  = '3RD DRUG CAUSING HEALTH PROBLEMS (L.I. HLTDRG3A)'
   IRHLT4  = '4TH DRUG CAUSING HEALTH PROBLEMS (L.I. HLTDRG4A)'
   IRHLT5  = '5TH DRUG CAUSING HEALTH PROBLEMS (L.I. HLTDRG5A)'
   IRNTK1  = '1ST DRUG CAUSNG DFFCLTY THNKNG CLR (L.I. NTKDRG1A)'
   IRNTK2  = '2ND DRUG CAUSNG DFFCLTY THNKNG CLR (L.I. NTKDRG2A)'
   IRNTK3  = '3RD DRUG CAUSNG DFFCLTY THNKNG CLR (L.I. NTKDRG3A)'
   IRNTK4  = '4TH DRUG CAUSNG DFFCLTY THNKNG CLR (L.I. NTKDRG4A)'
   IRNTK5  = '5TH DRUG CAUSNG DFFCLTY THNKNG CLR (L.I. NTKDRG5A)'
   IRUPS1  = '1ST DRUG CAUSING FEELING UPSET (L.I. UPSDRG1A)'
   IRUPS2  = '2ND DRUG CAUSING FEELING UPSET (L.I. UPSDRG2A)'
   IRUPS3  = '3RD DRUG CAUSING FEELING UPSET (L.I. UPSDRG3A)'
   IRUPS4  = '4TH DRUG CAUSING FEELING UPSET (L.I. UPSDRG4A)'
   IRUPS5  = '5TH DRUG CAUSING FEELING UPSET (L.I. UPSDRG5A)'
   IRLSW1  = '1ST DRUG CAUSING LESS WORK DONE (L.I. LSWDRG1A)'
   IRLSW2  = '2ND DRUG CAUSING LESS WORK DONE (L.I. LSWDRG2A)'
   IRLSW3  = '3RD DRUG CAUSING LESS WORK DONE (L.I. LSWDRG3A)'
   IRLSW4  = '4TH DRUG CAUSING LESS WORK DONE (L.I. LSWDRG4A)'
   IRLSW5  = '5TH DRUG CAUSING LESS WORK DONE (L.I. LSWDRG5A)'
   IRSSP1  = '1ST DRUG CAUSING FEELNG SUSPICIOUS (L.I. SSPDRG1A)'
   IRSSP2  = '2ND DRUG CAUSING FEELNG SUSPICIOUS (L.I. SSPDRG2A)'
   IRSSP3  = '3RD DRUG CAUSING FEELNG SUSPICIOUS (L.I. SSPDRG3A)'
   IRSSP4  = '4TH DRUG CAUSING FEELNG SUSPICIOUS (L.I. SSPDRG4A)'
   IRSSP5  = '5TH DRUG CAUSING FEELNG SUSPICIOUS (L.I. SSPDRG5A)'
   IRCPE1  = '1ST DRUG CAUSING PRB HARDER HANDLE (L.I. CPEDRG1A)'
   IRCPE2  = '2ND DRUG CAUSING PRB HARDER HANDLE (L.I. CPEDRG2A)'
   IRCPE3  = '3RD DRUG CAUSING PRB HARDER HANDLE (L.I. CPEDRG3A)'
   IRCPE4  = '4TH DRUG CAUSING PRB HARDER HANDLE (L.I. CPEDRG4A)'
   IRCPE5  = '5TH DRUG CAUSING PRB HARDER HANDLE (L.I. CPEDRG5A)'
   IREMG1  = '1ST DRUG CAUSING NEED OF EMG MD HLP (L.I. EMDRG1A)'
   IREMG2  = '2ND DRUG CAUSING NEED OF EMG MD HLP (L.I. EMDRG2A)'
   IREMG3  = '3RD DRUG CAUSING NEED OF EMG MD HLP (L.I. EMDRG3A)'
   IREMG4  = '4TH DRUG CAUSING NEED OF EMG MD HLP (L.I. EMDRG4A)'
   IREMG5  = '5TH DRUG CAUSING NEED OF EMG MD HLP (L.I. EMDRG5A)'
   ANYPROB = 'ANY OF THE 11 PROBS ON DRUG SHEET #13'
   TWOPROB = 'TWO OR MORE OF THE 11 PROBS ON DRUG SHEET #13'
   THREPROB= 'THREE OR MORE OF THE 11 PROBS ON DRUG SHEET #13'
   DEPCIG2 = 'BECAME DEPRESSED PAST YEAR DUE TO CIG USE'
   DEPALC2 = 'BECAME DEPRESSED PAST YEAR DUE TO ALC USE'
   DEPMRJ2 = 'BECAME DEPRESSED PAST YEAR DUE TO MRJ USE'
   DEPCOC2 = 'BECAME DEPRESSED PAST YEAR DUE TO COC USE'
   ARGCIG2 = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE TO CIG USE'
   ARGALC2 = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE TO ALC USE'
   ARGMRJ2 = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE TO MRJ USE'
   ARGCOC2 = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE TO COC USE'
   ALNCIG2 = 'FELT ALONE/ISOLATED PAST YEAR DUE TO CIG USE'
   ALNALC2 = 'FELT ALONE/ISOLATED PAST YEAR DUE TO ALC USE'
   ALNMRJ2 = 'FELT ALONE/ISOLATED PAST YEAR DUE TO MRJ USE'
   ALNCOC2 = 'FELT ALONE/ISOLATED PAST YEAR DUE TO COC USE'
   ANXCIG2 = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO CIG USE'
   ANXALC2 = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO ALC USE'
   ANXMRJ2 = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO MRJ USE'
   ANXCOC2 = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO COC USE'
   HLTCIG2 = 'HAD HEALTH PROBS PAST YEAR DUE TO CIG USE'
   HLTALC2 = 'HAD HEALTH PROBS PAST YEAR DUE TO ALC USE'
   HLTMRJ2 = 'HAD HEALTH PROBS PAST YEAR DUE TO MRJ USE'
   HLTCOC2 = 'HAD HEALTH PROBS PAST YEAR DUE TO COC USE'
   NTKCIG2 = 'HAD DIFFCULTY THNKNG CLEARLY PST YR DUE TO CIG USE'
   NTKALC2 = 'HAD DIFFCULTY THNKNG CLEARLY PST YR DUE TO ALC USE'
   NTKMRJ2 = 'HAD DIFFCULTY THNKNG CLEARLY PST YR DUE TO MRJ USE'
   NTKCOC2 = 'HAD DIFFCULTY THNKNG CLEARLY PST YR DUE TO COC USE'
   UPSCIG2 = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO CIG USE'
   UPSALC2 = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO ALC USE'
   UPSMRJ2 = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO MRJ USE'
   UPSCOC2 = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO COC USE'
   LSWCIG2 = 'GOT LESS WRK DONE AT SCH/JOB PST YR DUE TO CIG USE'
   LSWALC2 = 'GOT LESS WRK DONE AT SCH/JOB PST YR DUE TO ALC USE'
   LSWMRJ2 = 'GOT LESS WRK DONE AT SCH/JOB PST YR DUE TO MRJ USE'
   LSWCOC2 = 'GOT LESS WRK DONE AT SCH/JOB PST YR DUE TO COC USE'
   SSPCIG2 = 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE TO CIG USE'
   SSPALC2 = 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE TO ALC USE'
   SSPMRJ2 = 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE TO MRJ USE'
   SSPCOC2 = 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE TO COC USE'
   CPECIG2 = 'PROBLEMS HARDER TO HANDLE PAST YEAR DUE TO CIG USE'
   CPEALC2 = 'PROBLEMS HARDER TO HANDLE PAST YEAR DUE TO ALC USE'
   CPEMRJ2 = 'PROBLEMS HARDER TO HANDLE PAST YEAR DUE TO MRJ USE'
   CPECOC2 = 'PROBLEMS HARDER TO HANDLE PAST YEAR DUE TO COC USE'
   EMCIG2  = 'HAD TO GET EMERG MED HELP PST YR DUE TO CIG USE'
   EMALC2  = 'HAD TO GET EMERG MED HELP PST YR DUE TO ALC USE'
   EMMRJ2  = 'HAD TO GET EMERG MED HELP PST YR DUE TO MRJ USE'
   EMCOC2  = 'HAD TO GET EMERG MED HELP PST YR DUE TO COC USE'
   PRB1CIG = 'CIG USER WITH 1 OR MORE PROBS DUE TO CIG'
   PRB1ALC = 'ALC USER WITH 1 OR MORE PROBS DUE TO ALC'
   PRB1MRJ = 'MRJ USER WITH 1 OR MORE PROBS DUE TO MRJ'
   PRB1COC = 'COC USER WITH 1 OR MORE PROBS DUE TO COC'
   PRB2CIG = 'CIG USER WITH 2 OR MORE PROBS DUE TO CIG'
   PRB2ALC = 'ALC USER WITH 2 OR MORE PROBS DUE TO ALC'
   PRB2MRJ = 'MRJ USER WITH 2 OR MORE PROBS DUE TO MRJ'
   PRB2COC = 'COC USER WITH 2 OR MORE PROBS DUE TO COC'
   PRB3CIG = 'CIG USER WITH 3 OR MORE PROBS DUE TO CIG'
   PRB3ALC = 'ALC USER WITH 3 OR MORE PROBS DUE TO ALC'
   PRB3MRJ = 'MRJ USER WITH 3 OR MORE PROBS DUE TO MRJ'
   PRB3COC = 'COC USER WITH 3 OR MORE PROBS DUE TO COC'
   IRCDCIG = 'TRIED TO CUT DOWN CIG USE PT YR (L.I. CDCIG)'
   IRCDALC = 'TRIED TO CUT DOWN ALC USE PT YR (L.I. CDALC)'
   IRCDMJ  = 'TRIED TO CUT DOWN MRJ USE PT YR (L.I. CDMJ)'
   IRCDCOC = 'TRIED TO CUT DOWN COC USE PT YR (L.I. CDCOC)'
   IREFCIG = 'NEEDED MORE CIG FOR SAME EFFCT PST YR (L.I. EFCIG)'
   IREFALC = 'NEEDED MORE ALC FOR SAME EFFCT PST YR (L.I. EFALC)'
   IREFMJ  = 'NEEDED MORE MRJ FOR SAME EFFCT PST YR (L.I. EFMJ)'
   IREFCOC = 'NEEDED MORE COC FOR SAME EFFCT PST YR (L.I. EFCOC)'
   IRUDCIG = 'USED CIG DAILY 2+ WEEKS PST YR (L.I. UDCIG)'
   IRUDALC = 'USED ALC DAILY 2+ WEEKS PST YR (L.I. UDALC)'
   IRUDMJ  = 'USED MRJ DAILY 2+ WEEKS PST YR (L.I. UDMJ)'
   IRUDCOC = 'USED COC DAILY 2+ WEEKS PST YR (L.I. UDCOC)'
   IRDPCIG = 'FELT DEPENDENT ON CIG PST YR (L.I. DPCIG)'
   IRDPALC = 'FELT DEPENDENT ON ALC PST YR (L.I. DPALC)'
   IRDPMJ  = 'FELT DEPENDENT ON MRJ PST YR (L.I. DPMJ)'
   IRDPCOC = 'FELT DEPENDENT ON COC PST YR (L.I. DPCOC)'
   IRWSCIG = 'FELT SICK WHEN CUT DOWN ON CIG PST YR (L.I. WSCIG)'
   IRWSALC = 'FELT SICK WHEN CUT DOWN ON ALC PST YR (L.I. WSALC)'
   IRWSMJ  = 'FELT SICK WHEN CUT DOWN ON MRJ PST YR (L.I. WSMJ)'
   IRWSCOC = 'FELT SICK WHEN CUT DOWN ON COC PST YR (L.I. WSCOC)'
   ALCPROBS= 'ANY PROBS DUE TO ALCOHOL'
   MJPROBS = 'ANY PROBS DUE TO MARIJUANA'
   COCPROBS= 'ANY PROBS DUE TO COCAINE'
   CIGPROBS= 'ANY PROBS DUE TO CIGARETTES'
   IRALCAGG= 'FELT AGGRESSIVE WHILE DRNKNG PST YR (L.I. ALCAGGR)'
   IRALCARG= 'HEATED ARGUMNTS WHLE DRNKNG PST YR (L.I. ALCARGUM)'
   IRALCABS= 'ABSNT WRK/SCH FROM HANGOVER PST YR (L.I. ALCABSNT)'
   IRALCHIG= 'HIGH/LITTLE DRUNK AT WRK/SCH PST YR (L.I. ALCHIGH)'
   IRALCJOB= 'LOST/NRLY LOST JOB FRM DRNKNG PST YR (L.I. ALCJOB)'
   IRALCMAT= 'SPOUS/DATE SAY CUT DWN DRNK PST YR (L.I. ALCMATCD)'
   IRALCREL= 'RELATIVE SAY CUT DWN DRNKNG PST YR (L.I. ALCRELCD)'
   IRALCFRD= 'FRNDS SAID CUT DOWN DRINKNG PST YR (L.I. ALCFRDCD)'
   IRALCTOS= 'DRNK FAST FOR QUICKER EFFECT PST YR (L.I. ALCTOSS)'
   IRALCHOL= 'AFRAID MGHT BE/BECME ALCHLC PST YR (L.I. ALCHOLIC)'
   IRALCDRU= 'STAYD DRUNK >1DAY AT A TIME PST YR (L.I. ALCDRUNK)'
   IRALCINT= 'NOT STP DRNKNG TILL INTXCTD PST YR (L.I. ALCINTOX)'
   IRALCREM= 'NOT REMEMBR THNGS WHLE DRNKNG PST YR (L.I. ALCREM)'
   IRALCQUI= 'QUICK DRINKS NO ONE LOOKING PST YR (L.I. ALCQUICK)'
   IRALCMOR= 'OFTEN DRINK 1ST THNG MORNING PST YR (L.I. ALCMORN)'
   IRALCSHO= 'HNDS SHK AFT DRNK DAY BEFOR PST YR (L.I. ALCSHOOK)'
   IRALCALO= 'GOT DRUNK WHLE DRNKNG ALONE PST YR (L.I. ALCALONE)'
   IRALCBRK= 'KPT DRNKNG AFT PROMISNG STP PST YR (L.I. ALCBRKPM)'
   IRNOBOOZ= 'NO USE OF BEER/WINE/LIQUOR PST YR (L.I. NOBOOZYR)'
   ANYALC  = 'ANY PROBS W/ALCOHOL PAST YR'
   THREALC = 'GE 3 PROBS W/ALCOHOL PAST YR'
   DRUNKYR2= '# TIMES DRUNK ON ALC PAST 12 MONTH'
   IRAS13  = 'NEVER USED ANY LISTED SUBSTANCES (L.I. AS13NONE)'
   AVCIG3  = '# CIG.OKED PER DAY LAST 30'
   IRNODRUG= 'NO USE OF CIG/ALC/OTHR DRUGS PST YR (L.I. NODRUGS)'
   ALCONLYL= 'ONLY ALCOHOL - EVER USED'
   ALCONLYY= 'ONLY ALCOHOL - PAST YEAR USE'
   ALCONLYM= 'ONLY ALCOHOL - PAST MONTH USE'
   ILLONLYL= 'ONLY ILLICIT DRUGS - EVER USED'
   ILLONLYY= 'ONLY ILLICIT DRUGS - PAST YEAR USE'
   ILLONLYM= 'ONLY ILLICIT DRUGS - PAST MONTH USE'
   MRJONLYL= 'ONLY MARIJUANA - EVER USED'
   MRJONLYY= 'ONLY MARIJUANA - PAST YEAR USE'
   MRJONLYM= 'ONLY MARIJUANA - PAST MONTH USE'
   PSYONLYL= 'ONLY PSYCHOTHERAPEUTICS - EVER USED'
   PSYONLYY= 'ONLY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYONLYM= 'ONLY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   OTHONLYL= 'ONLY OTHER DRUGS AND DRUG COMB. - EVER USED'
   OTHONLYY= 'ONLY OTHER DRUGS AND DRUG COMB. - PAST YEAR USE'
   OTHONLYM= 'ONLY OTHER DRUGS AND DRUG COMB. - PAST MONTH USE'
   ALCILLL = 'ALCOHOL & ILLICIT DRUGS - EVER USED'
   ALCILLY = 'ALCOHOL & ILLICIT DRUGS - PAST YEAR USE'
   ALCILLM = 'ALCOHOL & ILLICIT DRUGS - PAST MONTH USE'
   ALCMRJL = 'ALCOHOL & MARIJUANA - EVER USED'
   ALCMRJY = 'ALCOHOL & MARIJUANA - PAST YEAR USE'
   ALCMRJM = 'ALCOHOL & MARIJUANA - PAST MONTH USE'
   ALCPSYL = 'ALCOHOL & PSYCHOTHERAPEUTICS - EVER USED'
   ALCPSYY = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST YEAR USE'
   ALCPSYM = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST MONTH USE'
   ALCOTHL = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- EVER USED'
   ALCOTHY = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- PAST YEAR USE'
   ALCOTHM = 'ALCOHOL & OTHER DRUGS & DRUG COMB.- PAST MONTH USE'
   SUB1LIF = 'USED ONLY 1 SUBSTANCE - EVER'
   SUB2LIF = 'USED ONLY 2 SUBSTANCES - EVER'
   SUB3LIF = 'USED 3 OR MORE SUBSTANCES - EVER'
   SUB1YR  = 'USED ONLY 1 SUBSTANCE - PAST YEAR'
   SUB2YR  = 'USED ONLY 2 SUBSTANCES - PAST YEAR'
   SUB3YR  = 'USED 3 OR MORE SUBSTANCES - PAST YEAR'
   SUB1MON = 'USED ONLY 1 SUBSTANCE - PAST MONTH'
   SUB2MON = 'USED ONLY 2 SUBSTANCES - PAST MONTH'
   SUB3MON = 'USED 3 OR MORE SUBSTANCES - PAST MONTH'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGTRY >= 91) THEN CIGTRY = .;
   IF (CIG5PK >= 91) THEN CIG5PK = .;
   IF (CIGREC >= 91) THEN CIGREC = .;
   IF (AVCIG >= 91) THEN AVCIG = .;
   IF (CIGTIME >= 91) THEN CIGTIME = .;
   IF (CIGINT >= 91) THEN CIGINT = .;
   IF (CIGAGE >= 91) THEN CIGAGE = .;
   IF (CIGYRS >= 91) THEN CIGYRS = .;
   IF (PACKS >= 91) THEN PACKS = .;
   IF (SNUFREC >= 91) THEN SNUFREC = .;
   IF (SNUFFREQ >= 91) THEN SNUFFREQ = .;
   IF (ALCTRY >= 91) THEN ALCTRY = .;
   IF (ALCREC >= 91) THEN ALCREC = .;
   IF (ALCPREF >= 91) THEN ALCPREF = .;
   IF (ALCDAYS >= 91) THEN ALCDAYS = .;
   IF (NODR30A >= 91) THEN NODR30A = .;
   IF (MODR30A >= 91) THEN MODR30A = .;
   IF (MODR30DY >= 91) THEN MODR30DY = .;
   IF (DR5DAY >= 91) THEN DR5DAY = .;
   IF (ALCAGE >= 91) THEN ALCAGE = .;
   IF (ALCPAT >= 91) THEN ALCPAT = .;
   IF (DRUNKYR >= 91) THEN DRUNKYR = .;
   IF (ALCSED >= 91) THEN ALCSED = .;
   IF (ALCTRAN >= 91) THEN ALCTRAN = .;
   IF (ALCSTM >= 91) THEN ALCSTM = .;
   IF (ALCANAL >= 91) THEN ALCANAL = .;
   IF (ALCMJ >= 91) THEN ALCMJ = .;
   IF (ALCINH >= 91) THEN ALCINH = .;
   IF (ALCCOC >= 91) THEN ALCCOC = .;
   IF (ALCHAL >= 91) THEN ALCHAL = .;
   IF (ALCOPT >= 91) THEN ALCOPT = .;
   IF (ALCNONE >= 91) THEN ALCNONE = .;
   IF (NOSEDAT >= 91) THEN NOSEDAT = .;
   IF (BUTISOL >= 91) THEN BUTISOL = .;
   IF (BUTICAPS >= 91) THEN BUTICAPS = .;
   IF (AMYTAL >= 91) THEN AMYTAL = .;
   IF (MEBARAL >= 91) THEN MEBARAL = .;
   IF (PLACIDYL >= 91) THEN PLACIDYL = .;
   IF (DORIDEN >= 91) THEN DORIDEN = .;
   IF (NOLUDAR >= 91) THEN NOLUDAR = .;
   IF (NEMBUTAL >= 91) THEN NEMBUTAL = .;
   IF (SECONAL >= 91) THEN SECONAL = .;
   IF (TUINAL >= 91) THEN TUINAL = .;
   IF (DALMANE >= 91) THEN DALMANE = .;
   IF (RESTORIL >= 91) THEN RESTORIL = .;
   IF (HALCION >= 91) THEN HALCION = .;
   IF (AMOBARB >= 91) THEN AMOBARB = .;
   IF (PHENOBAR >= 91) THEN PHENOBAR = .;
   IF (METHAQ >= 91) THEN METHAQ = .;
   IF (CHHYD >= 91) THEN CHHYD = .;
   IF (PENTOB >= 91) THEN PENTOB = .;
   IF (SECOB >= 91) THEN SECOB = .;
   IF (SEDNEWA >= 991) THEN SEDNEWA = .;
   IF (SEDNEWB >= 991) THEN SEDNEWB = .;
   IF (SEDNOSP >= 91) THEN SEDNOSP = .;
   IF (SEDDKNAM >= 91) THEN SEDDKNAM = .;
   IF (SEDAGE >= 91) THEN SEDAGE = .;
   IF (SEDTOT >= 91) THEN SEDTOT = .;
   IF (SEDREC >= 91) THEN SEDREC = .;
   IF (SEDALC >= 91) THEN SEDALC = .;
   IF (SEDTR >= 91) THEN SEDTR = .;
   IF (SEDST >= 91) THEN SEDST = .;
   IF (SEDAN >= 91) THEN SEDAN = .;
   IF (SEDMJ >= 91) THEN SEDMJ = .;
   IF (SEDINH >= 91) THEN SEDINH = .;
   IF (SEDCOC >= 91) THEN SEDCOC = .;
   IF (SEDHAL >= 91) THEN SEDHAL = .;
   IF (SEDOPT >= 91) THEN SEDOPT = .;
   IF (SEDNONE >= 91) THEN SEDNONE = .;
   IF (AS3READ >= 91) THEN AS3READ = .;
   IF (NOTRANQ >= 91) THEN NOTRANQ = .;
   IF (VALIUM >= 91) THEN VALIUM = .;
   IF (LIBRIUM >= 91) THEN LIBRIUM = .;
   IF (LIMBTROL >= 91) THEN LIMBTROL = .;
   IF (MENRIUM >= 91) THEN MENRIUM = .;
   IF (SERAX >= 91) THEN SERAX = .;
   IF (TRANXENE >= 91) THEN TRANXENE = .;
   IF (ATIVAN >= 91) THEN ATIVAN = .;
   IF (CENTRAX >= 91) THEN CENTRAX = .;
   IF (XANAX >= 91) THEN XANAX = .;
   IF (PAXIPAM >= 91) THEN PAXIPAM = .;
   IF (BUSPAR >= 91) THEN BUSPAR = .;
   IF (MILTOWN >= 91) THEN MILTOWN = .;
   IF (EQUANIL >= 91) THEN EQUANIL = .;
   IF (DEPROL >= 91) THEN DEPROL = .;
   IF (VISTAR >= 91) THEN VISTAR = .;
   IF (ATARAX >= 91) THEN ATARAX = .;
   IF (DURRAX >= 91) THEN DURRAX = .;
   IF (DIAZEPAM >= 91) THEN DIAZEPAM = .;
   IF (SKLY >= 91) THEN SKLY = .;
   IF (MEPROB >= 91) THEN MEPROB = .;
   IF (TRNEWA >= 991) THEN TRNEWA = .;
   IF (TRNOSP >= 91) THEN TRNOSP = .;
   IF (TRDKNAM >= 91) THEN TRDKNAM = .;
   IF (TRANAGE >= 91) THEN TRANAGE = .;
   IF (TRANTOT >= 91) THEN TRANTOT = .;
   IF (TRANREC >= 91) THEN TRANREC = .;
   IF (TRALC >= 91) THEN TRALC = .;
   IF (TRSED >= 91) THEN TRSED = .;
   IF (TRSTM >= 91) THEN TRSTM = .;
   IF (TRANAL >= 91) THEN TRANAL = .;
   IF (TRMJ >= 91) THEN TRMJ = .;
   IF (TRINH >= 91) THEN TRINH = .;
   IF (TRCOC >= 91) THEN TRCOC = .;
   IF (TRHAL >= 91) THEN TRHAL = .;
   IF (TROPT >= 91) THEN TROPT = .;
   IF (TRNONE >= 91) THEN TRNONE = .;
   IF (AS4READ >= 91) THEN AS4READ = .;
   IF (NOSTIMS >= 91) THEN NOSTIMS = .;
   IF (DEXED >= 91) THEN DEXED = .;
   IF (DEXAMYL >= 91) THEN DEXAMYL = .;
   IF (ESKAT >= 91) THEN ESKAT = .;
   IF (BENZ >= 91) THEN BENZ = .;
   IF (BIPHET >= 91) THEN BIPHET = .;
   IF (DESOXYN >= 91) THEN DESOXYN = .;
   IF (TENUATE >= 91) THEN TENUATE = .;
   IF (TEPANIL >= 91) THEN TEPANIL = .;
   IF (DIDREX >= 91) THEN DIDREX = .;
   IF (PLEGINE >= 91) THEN PLEGINE = .;
   IF (PRELUDIN >= 91) THEN PRELUDIN = .;
   IF (IONAMIN >= 91) THEN IONAMIN = .;
   IF (FASTIN >= 91) THEN FASTIN = .;
   IF (PONDIMIN >= 91) THEN PONDIMIN = .;
   IF (VORANIL >= 91) THEN VORANIL = .;
   IF (SANOREX >= 91) THEN SANOREX = .;
   IF (MAZANOR >= 91) THEN MAZANOR = .;
   IF (RITALIN >= 91) THEN RITALIN = .;
   IF (CYLERT >= 91) THEN CYLERT = .;
   IF (DETAMP >= 91) THEN DETAMP = .;
   IF (METHI >= 91) THEN METHI = .;
   IF (METHAMP >= 91) THEN METHAMP = .;
   IF (OBLA >= 91) THEN OBLA = .;
   IF (STIMNEWA >= 991) THEN STIMNEWA = .;
   IF (STIMNEWB >= 991) THEN STIMNEWB = .;
   IF (STIMNEWC >= 991) THEN STIMNEWC = .;
   IF (STIMNEWD >= 991) THEN STIMNEWD = .;
   IF (STIMNOSP >= 91) THEN STIMNOSP = .;
   IF (STMDKNAM >= 91) THEN STMDKNAM = .;
   IF (STIMAGE >= 91) THEN STIMAGE = .;
   IF (STIMTOT >= 91) THEN STIMTOT = .;
   IF (STIMREC >= 91) THEN STIMREC = .;
   IF (STALC >= 91) THEN STALC = .;
   IF (STSED >= 91) THEN STSED = .;
   IF (STTRAN >= 91) THEN STTRAN = .;
   IF (STANAL >= 91) THEN STANAL = .;
   IF (STMJ >= 91) THEN STMJ = .;
   IF (STINH >= 91) THEN STINH = .;
   IF (STCOC >= 91) THEN STCOC = .;
   IF (STHAL >= 91) THEN STHAL = .;
   IF (STOPT >= 91) THEN STOPT = .;
   IF (STNONE >= 91) THEN STNONE = .;
   IF (STNEEDLE >= 91) THEN STNEEDLE = .;
   IF (STNDLREC >= 91) THEN STNDLREC = .;
   IF (AS5READ >= 91) THEN AS5READ = .;
   IF (ANALNONE >= 91) THEN ANALNONE = .;
   IF (DARVON >= 91) THEN DARVON = .;
   IF (DOLENE >= 91) THEN DOLENE = .;
   IF (SK65A >= 91) THEN SK65A = .;
   IF (WYGESIC >= 91) THEN WYGESIC = .;
   IF (LEVODRO >= 91) THEN LEVODRO = .;
   IF (PERCODAN >= 91) THEN PERCODAN = .;
   IF (DEMEROL >= 91) THEN DEMEROL = .;
   IF (DILAUD >= 91) THEN DILAUD = .;
   IF (TYLCOD >= 91) THEN TYLCOD = .;
   IF (PHENCOD >= 91) THEN PHENCOD = .;
   IF (TALWIN >= 91) THEN TALWIN = .;
   IF (TALWINNX >= 91) THEN TALWINNX = .;
   IF (TALACEN >= 91) THEN TALACEN = .;
   IF (PROPOXY >= 91) THEN PROPOXY = .;
   IF (CODEINE >= 91) THEN CODEINE = .;
   IF (ANILERID >= 91) THEN ANILERID = .;
   IF (MORPHINE >= 91) THEN MORPHINE = .;
   IF (METHDON >= 91) THEN METHDON = .;
   IF (STADOL >= 91) THEN STADOL = .;
   IF (ANALNEWA >= 991) THEN ANALNEWA = .;
   IF (ANALNEWB >= 991) THEN ANALNEWB = .;
   IF (ANLNOSP >= 91) THEN ANLNOSP = .;
   IF (ANLDKNAM >= 91) THEN ANLDKNAM = .;
   IF (ANALAGE >= 91) THEN ANALAGE = .;
   IF (ANALTOT >= 91) THEN ANALTOT = .;
   IF (ANALREC >= 91) THEN ANALREC = .;
   IF (ANLALC >= 91) THEN ANLALC = .;
   IF (ANLSED >= 91) THEN ANLSED = .;
   IF (ANLTRAN >= 91) THEN ANLTRAN = .;
   IF (ANLSTM >= 91) THEN ANLSTM = .;
   IF (ANLMJ >= 91) THEN ANLMJ = .;
   IF (ANLINH >= 91) THEN ANLINH = .;
   IF (ANLCOC >= 91) THEN ANLCOC = .;
   IF (ANLHAL >= 91) THEN ANLHAL = .;
   IF (ANLOPT >= 91) THEN ANLOPT = .;
   IF (ANLNONE >= 91) THEN ANLNONE = .;
   IF (MJOPP >= 91) THEN MJOPP = .;
   IF (MJAGE >= 91) THEN MJAGE = .;
   IF (MJTOT >= 91) THEN MJTOT = .;
   IF (MJREC >= 91) THEN MJREC = .;
   IF (MJDAY30A >= 91) THEN MJDAY30A = .;
   IF (MJAV30A >= 91) THEN MJAV30A = .;
   IF (MJAMT30A >= 91) THEN MJAMT30A = .;
   IF (MJALC30A >= 6) THEN MJALC30A = .;
   IF (MJYRFREQ >= 91) THEN MJYRFREQ = .;
   IF (MJALC >= 91) THEN MJALC = .;
   IF (MJSED >= 91) THEN MJSED = .;
   IF (MJTRAN >= 91) THEN MJTRAN = .;
   IF (MJSTM >= 91) THEN MJSTM = .;
   IF (MJANAL >= 91) THEN MJANAL = .;
   IF (MJINH >= 91) THEN MJINH = .;
   IF (MJCOC >= 91) THEN MJCOC = .;
   IF (MJHAL >= 91) THEN MJHAL = .;
   IF (MJOPT >= 91) THEN MJOPT = .;
   IF (MJNONE >= 91) THEN MJNONE = .;
   IF (AS7READ >= 91) THEN AS7READ = .;
   IF (INHAGE >= 91) THEN INHAGE = .;
   IF (GAS >= 91) THEN GAS = .;
   IF (SPPAINT >= 91) THEN SPPAINT = .;
   IF (AEROS >= 91) THEN AEROS = .;
   IF (GLUE >= 91) THEN GLUE = .;
   IF (SOLVENT >= 91) THEN SOLVENT = .;
   IF (AMYLNIT >= 91) THEN AMYLNIT = .;
   IF (ETHER >= 91) THEN ETHER = .;
   IF (NITOXID >= 91) THEN NITOXID = .;
   IF (CLEFLU >= 91) THEN CLEFLU = .;
   IF (INHNEWA >= 991) THEN INHNEWA = .;
   IF (INHNEWB >= 991) THEN INHNEWB = .;
   IF (INHNOSP >= 91) THEN INHNOSP = .;
   IF (INHTOT >= 91) THEN INHTOT = .;
   IF (GAS30A >= 91) THEN GAS30A = .;
   IF (SPPAN30A >= 91) THEN SPPAN30A = .;
   IF (AEROS30A >= 91) THEN AEROS30A = .;
   IF (GLUE30A >= 91) THEN GLUE30A = .;
   IF (SOLVN30A >= 91) THEN SOLVN30A = .;
   IF (AMLNT30A >= 91) THEN AMLNT30A = .;
   IF (ETHER30A >= 91) THEN ETHER30A = .;
   IF (NOX30A >= 91) THEN NOX30A = .;
   IF (CLFL30A >= 91) THEN CLFL30A = .;
   IF (INNEW30A >= 991) THEN INNEW30A = .;
   IF (INNEW30B >= 991) THEN INNEW30B = .;
   IF (IN30NOSP >= 91) THEN IN30NOSP = .;
   IF (INH30NO >= 91) THEN INH30NO = .;
   IF (INHDY30A >= 91) THEN INHDY30A = .;
   IF (INHREC >= 91) THEN INHREC = .;
   IF (INHEFF >= 91) THEN INHEFF = .;
   IF (INHPO >= 91) THEN INHPO = .;
   IF (INHQNC1 >= 91) THEN INHQNC1 = .;
   IF (INHQNC2 >= 91) THEN INHQNC2 = .;
   IF (INHQNC3 >= 91) THEN INHQNC3 = .;
   IF (INHQNC4 >= 91) THEN INHQNC4 = .;
   IF (INHQNC5 >= 91) THEN INHQNC5 = .;
   IF (INHQNC6 >= 91) THEN INHQNC6 = .;
   IF (INHQNC7 >= 91) THEN INHQNC7 = .;
   IF (INHQNC8 >= 91) THEN INHQNC8 = .;
   IF (INHQNC9 >= 91) THEN INHQNC9 = .;
   IF (INHANSY >= 91) THEN INHANSY = .;
   IF (COCOPP >= 91) THEN COCOPP = .;
   IF (COCAGE >= 91) THEN COCAGE = .;
   IF (COCTOT >= 91) THEN COCTOT = .;
   IF (COCREC >= 91) THEN COCREC = .;
   IF (COCUS30A >= 91) THEN COCUS30A = .;
   IF (COC30ALC >= 91) THEN COC30ALC = .;
   IF (COCYRFRQ >= 91) THEN COCYRFRQ = .;
   IF (COCALC >= 91) THEN COCALC = .;
   IF (COCSED >= 91) THEN COCSED = .;
   IF (COCTRAN >= 91) THEN COCTRAN = .;
   IF (COCSTM >= 91) THEN COCSTM = .;
   IF (COCANAL >= 91) THEN COCANAL = .;
   IF (COCINH >= 91) THEN COCINH = .;
   IF (COCMJ >= 91) THEN COCMJ = .;
   IF (COCHAL >= 91) THEN COCHAL = .;
   IF (COCOPT >= 91) THEN COCOPT = .;
   IF (COCNONE >= 91) THEN COCNONE = .;
   IF (COCSNIFF >= 91) THEN COCSNIFF = .;
   IF (COCSWAL >= 91) THEN COCSWAL = .;
   IF (COCIV >= 91) THEN COCIV = .;
   IF (FREEBASE >= 91) THEN FREEBASE = .;
   IF (COCNEWA >= 91) THEN COCNEWA = .;
   IF (COCNOSP >= 91) THEN COCNOSP = .;
   IF (CONDLREC >= 91) THEN CONDLREC = .;
   IF (CRAKREC >= 91) THEN CRAKREC = .;
   IF (CRKAM30A >= 991) THEN CRKAM30A = .;
   IF (CRAKBUCK >= 9993) THEN CRAKBUCK = .;
   IF (COCAM30A >= 91) THEN COCAM30A = .;
   IF (COCBUCK >= 9991) THEN COCBUCK = .;
   IF (AS9READ >= 91) THEN AS9READ = .;
   IF (LSD >= 91) THEN LSD = .;
   IF (PEYOTE >= 91) THEN PEYOTE = .;
   IF (MESC >= 91) THEN MESC = .;
   IF (PSILCY >= 91) THEN PSILCY = .;
   IF (PCP >= 91) THEN PCP = .;
   IF (ECSTASY >= 91) THEN ECSTASY = .;
   IF (HALNEWA >= 991) THEN HALNEWA = .;
   IF (HALNOSP >= 91) THEN HALNOSP = .;
   IF (HALLOPP >= 91) THEN HALLOPP = .;
   IF (HALLAGE >= 91) THEN HALLAGE = .;
   IF (HALLTOT >= 91) THEN HALLTOT = .;
   IF (HALLREC >= 91) THEN HALLREC = .;
   IF (HAL30USE >= 91) THEN HAL30USE = .;
   IF (PCPREC >= 91) THEN PCPREC = .;
   IF (PCPFLASH >= 91) THEN PCPFLASH = .;
   IF (PCPSENSE >= 91) THEN PCPSENSE = .;
   IF (PCPFEELV >= 91) THEN PCPFEELV = .;
   IF (PCPACTV >= 91) THEN PCPACTV = .;
   IF (PCPNEWA >= 91) THEN PCPNEWA = .;
   IF (PCPNEWB >= 91) THEN PCPNEWB = .;
   IF (PCPNEWC >= 91) THEN PCPNEWC = .;
   IF (PCPNOSP >= 91) THEN PCPNOSP = .;
   IF (PCPNORCT >= 91) THEN PCPNORCT = .;
   IF (HALLQCL >= 91) THEN HALLQCL = .;
   IF (AS10READ >= 91) THEN AS10READ = .;
   IF (HEROPP >= 91) THEN HEROPP = .;
   IF (HERAGE >= 91) THEN HERAGE = .;
   IF (HERTOT >= 91) THEN HERTOT = .;
   IF (HERREC >= 91) THEN HERREC = .;
   IF (HER30USE >= 91) THEN HER30USE = .;
   IF (HERNEEDL >= 91) THEN HERNEEDL = .;
   IF (HRNDLREC >= 91) THEN HRNDLREC = .;
   IF (AS11READ >= 91) THEN AS11READ = .;
   IF (NODRUGS >= 91) THEN NODRUGS = .;
   IF (CDCIG >= 13) THEN CDCIG = .;
   IF (CDALC >= 13) THEN CDALC = .;
   IF (CDSED >= 13) THEN CDSED = .;
   IF (CDTRAN >= 13) THEN CDTRAN = .;
   IF (CDSTM >= 13) THEN CDSTM = .;
   IF (CDANAL >= 13) THEN CDANAL = .;
   IF (CDMJ >= 13) THEN CDMJ = .;
   IF (CDINH >= 13) THEN CDINH = .;
   IF (CDCOC >= 13) THEN CDCOC = .;
   IF (CDHALL >= 13) THEN CDHALL = .;
   IF (CDHER >= 13) THEN CDHER = .;
   IF (CDOTHOP >= 13) THEN CDOTHOP = .;
   IF (CDNONE >= 91) THEN CDNONE = .;
   IF (EFFCIG >= 13) THEN EFFCIG = .;
   IF (EFFALC >= 13) THEN EFFALC = .;
   IF (EFFSED >= 13) THEN EFFSED = .;
   IF (EFFTRAN >= 13) THEN EFFTRAN = .;
   IF (EFFSTM >= 13) THEN EFFSTM = .;
   IF (EFFANAL >= 13) THEN EFFANAL = .;
   IF (EFFMJ >= 13) THEN EFFMJ = .;
   IF (EFFINH >= 13) THEN EFFINH = .;
   IF (EFFCOC >= 13) THEN EFFCOC = .;
   IF (EFFHALL >= 13) THEN EFFHALL = .;
   IF (EFFHER >= 13) THEN EFFHER = .;
   IF (EFFOTHOP >= 13) THEN EFFOTHOP = .;
   IF (EFFNONE >= 91) THEN EFFNONE = .;
   IF (UDAYCIG >= 13) THEN UDAYCIG = .;
   IF (UDAYALC >= 13) THEN UDAYALC = .;
   IF (UDAYSED >= 13) THEN UDAYSED = .;
   IF (UDAYTRAN >= 13) THEN UDAYTRAN = .;
   IF (UDAYSTM >= 13) THEN UDAYSTM = .;
   IF (UDAYANAL >= 13) THEN UDAYANAL = .;
   IF (UDAYMJ >= 13) THEN UDAYMJ = .;
   IF (UDAYINH >= 13) THEN UDAYINH = .;
   IF (UDAYCOC >= 13) THEN UDAYCOC = .;
   IF (UDAYHALL >= 13) THEN UDAYHALL = .;
   IF (UDAYHER >= 13) THEN UDAYHER = .;
   IF (UDAYOTH >= 13) THEN UDAYOTH = .;
   IF (UDAYNONE >= 91) THEN UDAYNONE = .;
   IF (DEPCIG >= 13) THEN DEPCIG = .;
   IF (DEPALC >= 13) THEN DEPALC = .;
   IF (DEPSED >= 13) THEN DEPSED = .;
   IF (DEPTRAN >= 13) THEN DEPTRAN = .;
   IF (DEPSTM >= 13) THEN DEPSTM = .;
   IF (DEPANAL >= 13) THEN DEPANAL = .;
   IF (DEPMJ >= 13) THEN DEPMJ = .;
   IF (DEPINH >= 13) THEN DEPINH = .;
   IF (DEPCOC >= 13) THEN DEPCOC = .;
   IF (DEPHALL >= 13) THEN DEPHALL = .;
   IF (DEPHER >= 13) THEN DEPHER = .;
   IF (DEPOTHOP >= 13) THEN DEPOTHOP = .;
   IF (DEPNONE >= 91) THEN DEPNONE = .;
   IF (WSCIG >= 13) THEN WSCIG = .;
   IF (WSALC >= 13) THEN WSALC = .;
   IF (WSSED >= 13) THEN WSSED = .;
   IF (WSTRAN >= 13) THEN WSTRAN = .;
   IF (WSSTM >= 13) THEN WSSTM = .;
   IF (WSANAL >= 13) THEN WSANAL = .;
   IF (WSMJ >= 13) THEN WSMJ = .;
   IF (WSINH >= 13) THEN WSINH = .;
   IF (WSCOC >= 13) THEN WSCOC = .;
   IF (WSHALL >= 13) THEN WSHALL = .;
   IF (WSHER >= 13) THEN WSHER = .;
   IF (WSOTHOP >= 13) THEN WSOTHOP = .;
   IF (WSNONE >= 91) THEN WSNONE = .;
   IF (SHRNDLMO >= 91) THEN SHRNDLMO = .;
   IF (NRSHRNDL >= 91) THEN NRSHRNDL = .;
   IF (CLEANNDL >= 91) THEN CLEANNDL = .;
   IF (SHRWMALE >= 91) THEN SHRWMALE = .;
   IF (SHRWSEXP >= 91) THEN SHRWSEXP = .;
   IF (SHRWRACE >= 91) THEN SHRWRACE = .;
   IF (RSNNOSHR >= 91) THEN RSNNOSHR = .;
   IF (NOBOOZYR >= 91) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 91) THEN ALCAGGR = .;
   IF (ALCARGUM >= 91) THEN ALCARGUM = .;
   IF (ALCABSNT >= 91) THEN ALCABSNT = .;
   IF (ALCHIGH >= 91) THEN ALCHIGH = .;
   IF (ALCJOB >= 91) THEN ALCJOB = .;
   IF (ALCMATCD >= 91) THEN ALCMATCD = .;
   IF (ALCRELCD >= 91) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 91) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 91) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 91) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 91) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 91) THEN ALCINTOX = .;
   IF (ALCREM >= 91) THEN ALCREM = .;
   IF (ALCQUICK >= 91) THEN ALCQUICK = .;
   IF (ALCMORN >= 91) THEN ALCMORN = .;
   IF (ALCSHOOK >= 91) THEN ALCSHOOK = .;
   IF (ALCALONE >= 91) THEN ALCALONE = .;
   IF (ALCBRKPM >= 91) THEN ALCBRKPM = .;
   IF (AS13NONE >= 91) THEN AS13NONE = .;
   IF (DRDEPRSS >= 91) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 991) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 991) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 991) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 991) THEN DEPDRG4A = .;
   IF (DEPDRG5A >= 991) THEN DEPDRG5A = .;
   IF (DRARGUM >= 91) THEN DRARGUM = .;
   IF (ARGDRG1A >= 991) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 991) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 991) THEN ARGDRG3A = .;
   IF (ARGDRG4A >= 991) THEN ARGDRG4A = .;
   IF (ARGDRG5A >= 991) THEN ARGDRG5A = .;
   IF (DRALONE >= 91) THEN DRALONE = .;
   IF (ALNDRG1A >= 991) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 991) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 991) THEN ALNDRG3A = .;
   IF (ALNDRG4A >= 991) THEN ALNDRG4A = .;
   IF (ALNDRG5A >= 991) THEN ALNDRG5A = .;
   IF (DRANX >= 91) THEN DRANX = .;
   IF (ANXDRG1A >= 991) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 991) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 991) THEN ANXDRG3A = .;
   IF (ANXDRG4A >= 991) THEN ANXDRG4A = .;
   IF (ANXDRG5A >= 991) THEN ANXDRG5A = .;
   IF (DRHEALTH >= 91) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 991) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 991) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 991) THEN HLTDRG3A = .;
   IF (HLTDRG4A >= 991) THEN HLTDRG4A = .;
   IF (HLTDRG5A >= 991) THEN HLTDRG5A = .;
   IF (DRNTHINK >= 91) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 991) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 991) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 991) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 991) THEN NTKDRG4A = .;
   IF (NTKDRG5A >= 991) THEN NTKDRG5A = .;
   IF (DRUPSET >= 91) THEN DRUPSET = .;
   IF (UPSDRG1A >= 991) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 991) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 991) THEN UPSDRG3A = .;
   IF (UPSDRG4A >= 991) THEN UPSDRG4A = .;
   IF (UPSDRG5A >= 991) THEN UPSDRG5A = .;
   IF (DRLSWORK >= 91) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 991) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 991) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 991) THEN LSWDRG3A = .;
   IF (LSWDRG4A >= 991) THEN LSWDRG4A = .;
   IF (LSWDRG5A >= 991) THEN LSWDRG5A = .;
   IF (DRSUSPIC >= 91) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 991) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 991) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 991) THEN SSPDRG3A = .;
   IF (SSPDRG4A >= 991) THEN SSPDRG4A = .;
   IF (SSPDRG5A >= 991) THEN SSPDRG5A = .;
   IF (DRCOPE >= 91) THEN DRCOPE = .;
   IF (CPEDRG1A >= 991) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 991) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 991) THEN CPEDRG3A = .;
   IF (CPEDRG4A >= 991) THEN CPEDRG4A = .;
   IF (CPEDRG5A >= 991) THEN CPEDRG5A = .;
   IF (DREMGMED >= 91) THEN DREMGMED = .;
   IF (EMDRG1A >= 991) THEN EMDRG1A = .;
   IF (EMDRG2A >= 991) THEN EMDRG2A = .;
   IF (EMDRG3A >= 991) THEN EMDRG3A = .;
   IF (EMDRG4A >= 991) THEN EMDRG4A = .;
   IF (EMDRG5A >= 991) THEN EMDRG5A = .;
   IF (RSKPKCIG >= 91) THEN RSKPKCIG = .;
   IF (RSKMJOCC >= 91) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 91) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 91) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 91) THEN RKPCPREG = .;
   IF (RKTRYHER >= 91) THEN RKTRYHER = .;
   IF (RKHERREG >= 91) THEN RKHERREG = .;
   IF (RKTRYCOC >= 91) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 91) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 91) THEN RKCOCREG = .;
   IF (RKCRKOCC >= 91) THEN RKCRKOCC = .;
   IF (RK2DRINK >= 91) THEN RK2DRINK = .;
   IF (RK5DRINK >= 91) THEN RK5DRINK = .;
   IF (RSKBINGE >= 91) THEN RSKBINGE = .;
   IF (HIGHBP >= 91) THEN HIGHBP = .;
   IF (BPMED >= 91) THEN BPMED = .;
   IF (WALKPAIN >= 91) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 91) THEN TIMEPAIN = .;
   IF (UPSHOR >= 91) THEN UPSHOR = .;
   IF (ASTHMA >= 91) THEN ASTHMA = .;
   IF (TRPSYCH >= 91) THEN TRPSYCH = .;
   IF (HEART >= 91) THEN HEART = .;
   IF (FLU >= 91) THEN FLU = .;
   IF (ALLERG >= 91) THEN ALLERG = .;
   IF (HOSPYR >= 91) THEN HOSPYR = .;
   IF (SOREYR >= 91) THEN SOREYR = .;
   IF (RUNNYYR >= 91) THEN RUNNYYR = .;
   IF (COUGHYR >= 91) THEN COUGHYR = .;
   IF (PHLEGMYR >= 91) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 91) THEN HEALTHYR = .;
   IF (MARITAL >= 91) THEN MARITAL = .;
   IF (NOMARR >= 91) THEN NOMARR = .;
   IF (WORKSTAT >= 91) THEN WORKSTAT = .;
   IF (PAYMO >= 91) THEN PAYMO = .;
   IF (PAYYR >= 91) THEN PAYYR = .;
   IF (NO5JOB >= 91) THEN NO5JOB = .;
   IF (WORKDAYS >= 91) THEN WORKDAYS = .;
   IF (WORKBLAH >= 91) THEN WORKBLAH = .;
   IF (CWE >= 91) THEN CWE = .;
   IF (FULLPART >= 91) THEN FULLPART = .;
   IF (EDUC >= 91) THEN EDUC = .;
   IF (ENROLLD >= 91) THEN ENROLLD = .;
   IF (SCHPLANS >= 91) THEN SCHPLANS = .;
   IF (STUDENT >= 91) THEN STUDENT = .;
   IF (SCHDAYS >= 91) THEN SCHDAYS = .;
   IF (SKIPPED >= 91) THEN SKIPPED = .;
   IF (MILES >= 99991) THEN MILES = .;
   IF (ACCID >= 91) THEN ACCID = .;
   IF (NOCHILD >= 91) THEN NOCHILD = .;
   IF (TOTPEOP >= 91) THEN TOTPEOP = .;
   IF (MOTHER >= 91) THEN MOTHER = .;
   IF (STEPMOM >= 91) THEN STEPMOM = .;
   IF (FATHER >= 91) THEN FATHER = .;
   IF (STEPDAD >= 91) THEN STEPDAD = .;
   IF (SPOUSE >= 91) THEN SPOUSE = .;
   IF (INLAW >= 91) THEN INLAW = .;
   IF (OWNCHILD >= 91) THEN OWNCHILD = .;
   IF (STEPCHLD >= 91) THEN STEPCHLD = .;
   IF (BROSIS >= 91) THEN BROSIS = .;
   IF (OTHREL >= 91) THEN OTHREL = .;
   IF (FRIENDS >= 91) THEN FRIENDS = .;
   IF (OTHERNON >= 91) THEN OTHERNON = .;
   IF (SERVICE >= 91) THEN SERVICE = .;
   IF (MILSTAT >= 91) THEN MILSTAT = .;
   IF (MOVDAWAY >= 91) THEN MOVDAWAY = .;
   IF (DORM >= 91) THEN DORM = .;
   IF (MILBASE >= 91) THEN MILBASE = .;
   IF (HOSP >= 91) THEN HOSP = .;
   IF (TELNO >= 91) THEN TELNO = .;
   IF (MOVES >= 91) THEN MOVES = .;
   IF (INCOME >= 91) THEN INCOME = .;
   IF (UNDINT >= 91) THEN UNDINT = .;
   IF (COOPINT >= 91) THEN COOPINT = .;
   IF (PRIVACY >= 91) THEN PRIVACY = .;
   IF (PPRES >= 91) THEN PPRES = .;
   IF (SPRES >= 91) THEN SPRES = .;
   IF (PARPRES >= 91) THEN PARPRES = .;
   IF (OARPRES >= 91) THEN OARPRES = .;
   IF (OAPRES >= 91) THEN OAPRES = .;
   IF (CPRES >= 91) THEN CPRES = .;
   IF (OPRESSPA >= 91) THEN OPRESSPA = .;
   IF (OPRESSPB >= 91) THEN OPRESSPB = .;
   IF (OPRESNSP >= 91) THEN OPRESNSP = .;
   IF (IRAGE >= 91) THEN IRAGE = .;
   IF (IRHOGRP >= 9) THEN IRHOGRP = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IROTBRC >= 9) THEN IROTBRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRCRKRC >= 9) THEN IRCRKRC = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRMJFQ >= 10) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
   IF (NEEDLREC >= 91) THEN NEEDLREC = .;
   IF (VESTR >= 91) THEN VESTR = .;
   IF (CHAGE9 >= 91) THEN CHAGE9 = .;
   IF (CHAGE10 >= 91) THEN CHAGE10 = .;
   IF (CWEOCC2 >= 990) THEN CWEOCC2 = .;
   IF (ROCCUP2 >= 990) THEN ROCCUP2 = .;
   IF (BUSINES2 >= 990) THEN BUSINES2 = .;
   IF (CWEBUS2 >= 990) THEN CWEBUS2 = .;
   IF (IRDEP >= 91) THEN IRDEP = .;
   IF (IRARG >= 91) THEN IRARG = .;
   IF (IRALN >= 91) THEN IRALN = .;
   IF (IRANX >= 91) THEN IRANX = .;
   IF (IRHLT >= 91) THEN IRHLT = .;
   IF (IRNTK >= 91) THEN IRNTK = .;
   IF (IRUPS >= 91) THEN IRUPS = .;
   IF (IRLSW >= 91) THEN IRLSW = .;
   IF (IRSSP >= 91) THEN IRSSP = .;
   IF (IRCPE >= 91) THEN IRCPE = .;
   IF (IREMG >= 91) THEN IREMG = .;
   IF (IRDEP1 >= 991) THEN IRDEP1 = .;
   IF (IRDEP2 >= 991) THEN IRDEP2 = .;
   IF (IRDEP3 >= 991) THEN IRDEP3 = .;
   IF (IRDEP4 >= 991) THEN IRDEP4 = .;
   IF (IRDEP5 >= 991) THEN IRDEP5 = .;
   IF (IRARG1 >= 991) THEN IRARG1 = .;
   IF (IRARG2 >= 991) THEN IRARG2 = .;
   IF (IRARG3 >= 991) THEN IRARG3 = .;
   IF (IRARG4 >= 991) THEN IRARG4 = .;
   IF (IRARG5 >= 991) THEN IRARG5 = .;
   IF (IRALN1 >= 991) THEN IRALN1 = .;
   IF (IRALN2 >= 991) THEN IRALN2 = .;
   IF (IRALN3 >= 991) THEN IRALN3 = .;
   IF (IRALN4 >= 991) THEN IRALN4 = .;
   IF (IRALN5 >= 991) THEN IRALN5 = .;
   IF (IRANX1 >= 991) THEN IRANX1 = .;
   IF (IRANX2 >= 991) THEN IRANX2 = .;
   IF (IRANX3 >= 991) THEN IRANX3 = .;
   IF (IRANX4 >= 991) THEN IRANX4 = .;
   IF (IRANX5 >= 991) THEN IRANX5 = .;
   IF (IRHLT1 >= 991) THEN IRHLT1 = .;
   IF (IRHLT2 >= 991) THEN IRHLT2 = .;
   IF (IRHLT3 >= 991) THEN IRHLT3 = .;
   IF (IRHLT4 >= 991) THEN IRHLT4 = .;
   IF (IRHLT5 >= 991) THEN IRHLT5 = .;
   IF (IRNTK1 >= 991) THEN IRNTK1 = .;
   IF (IRNTK2 >= 991) THEN IRNTK2 = .;
   IF (IRNTK3 >= 991) THEN IRNTK3 = .;
   IF (IRNTK4 >= 991) THEN IRNTK4 = .;
   IF (IRNTK5 >= 991) THEN IRNTK5 = .;
   IF (IRUPS1 >= 991) THEN IRUPS1 = .;
   IF (IRUPS2 >= 991) THEN IRUPS2 = .;
   IF (IRUPS3 >= 991) THEN IRUPS3 = .;
   IF (IRUPS4 >= 991) THEN IRUPS4 = .;
   IF (IRUPS5 >= 991) THEN IRUPS5 = .;
   IF (IRLSW1 >= 991) THEN IRLSW1 = .;
   IF (IRLSW2 >= 991) THEN IRLSW2 = .;
   IF (IRLSW3 >= 991) THEN IRLSW3 = .;
   IF (IRLSW4 >= 991) THEN IRLSW4 = .;
   IF (IRLSW5 >= 991) THEN IRLSW5 = .;
   IF (IRSSP1 >= 991) THEN IRSSP1 = .;
   IF (IRSSP2 >= 991) THEN IRSSP2 = .;
   IF (IRSSP3 >= 991) THEN IRSSP3 = .;
   IF (IRSSP4 >= 991) THEN IRSSP4 = .;
   IF (IRSSP5 >= 991) THEN IRSSP5 = .;
   IF (IRCPE1 >= 991) THEN IRCPE1 = .;
   IF (IRCPE2 >= 991) THEN IRCPE2 = .;
   IF (IRCPE3 >= 991) THEN IRCPE3 = .;
   IF (IRCPE4 >= 991) THEN IRCPE4 = .;
   IF (IRCPE5 >= 991) THEN IRCPE5 = .;
   IF (IREMG1 >= 991) THEN IREMG1 = .;
   IF (IREMG2 >= 991) THEN IREMG2 = .;
   IF (IREMG3 >= 991) THEN IREMG3 = .;
   IF (IREMG4 >= 991) THEN IREMG4 = .;
   IF (IREMG5 >= 991) THEN IREMG5 = .;
   IF (IRCDCIG >= 13) THEN IRCDCIG = .;
   IF (IRCDALC >= 13) THEN IRCDALC = .;
   IF (IRCDMJ >= 13) THEN IRCDMJ = .;
   IF (IRCDCOC >= 13) THEN IRCDCOC = .;
   IF (IREFCIG >= 13) THEN IREFCIG = .;
   IF (IREFALC >= 13) THEN IREFALC = .;
   IF (IREFMJ >= 13) THEN IREFMJ = .;
   IF (IREFCOC >= 13) THEN IREFCOC = .;
   IF (IRUDCIG >= 13) THEN IRUDCIG = .;
   IF (IRUDALC >= 13) THEN IRUDALC = .;
   IF (IRUDMJ >= 13) THEN IRUDMJ = .;
   IF (IRUDCOC >= 13) THEN IRUDCOC = .;
   IF (IRDPCIG >= 13) THEN IRDPCIG = .;
   IF (IRDPALC >= 13) THEN IRDPALC = .;
   IF (IRDPMJ >= 13) THEN IRDPMJ = .;
   IF (IRDPCOC >= 13) THEN IRDPCOC = .;
   IF (IRWSCIG >= 13) THEN IRWSCIG = .;
   IF (IRWSALC >= 13) THEN IRWSALC = .;
   IF (IRWSMJ >= 13) THEN IRWSMJ = .;
   IF (IRWSCOC >= 13) THEN IRWSCOC = .;
   IF (IRALCAGG >= 91) THEN IRALCAGG = .;
   IF (IRALCARG >= 91) THEN IRALCARG = .;
   IF (IRALCABS >= 91) THEN IRALCABS = .;
   IF (IRALCHIG >= 91) THEN IRALCHIG = .;
   IF (IRALCJOB >= 91) THEN IRALCJOB = .;
   IF (IRALCMAT >= 91) THEN IRALCMAT = .;
   IF (IRALCREL >= 91) THEN IRALCREL = .;
   IF (IRALCFRD >= 91) THEN IRALCFRD = .;
   IF (IRALCTOS >= 91) THEN IRALCTOS = .;
   IF (IRALCHOL >= 91) THEN IRALCHOL = .;
   IF (IRALCDRU >= 91) THEN IRALCDRU = .;
   IF (IRALCINT >= 91) THEN IRALCINT = .;
   IF (IRALCREM >= 91) THEN IRALCREM = .;
   IF (IRALCQUI >= 91) THEN IRALCQUI = .;
   IF (IRALCMOR >= 91) THEN IRALCMOR = .;
   IF (IRALCSHO >= 91) THEN IRALCSHO = .;
   IF (IRALCALO >= 91) THEN IRALCALO = .;
   IF (IRALCBRK >= 91) THEN IRALCBRK = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CIGTRY cigtry. CIG5PK cig5pk. CIGREC cigrec.
         AVCIG avcig. CIGTIME cigtime. CIGINT cigint.
         CIGAGE cigage. CIGYRS cigyrs. PACKS packs.
         SNUFREC snufrec. SNUFFREQ snuffreq. ALCTRY alctry.
         ALCREC alcrec. ALCPREF alcpref. ALCDAYS alcdays.
         NODR30A nodr30a. MODR30A modr30a. MODR30DY modr30dy.
         DR5DAY dr5day. ALCAGE alcage. ALCPAT alcpat.
         DRUNKYR drunkyr. ALCSED alcsed. ALCTRAN alctran.
         ALCSTM alcstm. ALCANAL alcanal. ALCMJ alcmj.
         ALCINH alcinh. ALCCOC alccoc. ALCHAL alchal.
         ALCOPT alcopt. ALCNONE alcnone. NOSEDAT nosedat.
         BUTISOL butisol. BUTICAPS buticaps. AMYTAL amytal.
         MEBARAL mebaral. PLACIDYL placidyl. DORIDEN doriden.
         NOLUDAR noludar. NEMBUTAL nembutal. SECONAL seconal.
         TUINAL tuinal. DALMANE dalmane. RESTORIL restoril.
         HALCION halcion. AMOBARB amobarb. PHENOBAR phenobar.
         METHAQ methaq. CHHYD chhyd. PENTOB pentob.
         SECOB secob. SEDNEWA sednewa. SEDNEWB sednewb.
         SEDNOSP sednosp. SEDDKNAM seddknam. SEDAGE sedage.
         SEDTOT sedtot. SEDREC sedrec. SEDALC sedalc.
         SEDTR sedtr. SEDST sedst. SEDAN sedan.
         SEDMJ sedmj. SEDINH sedinh. SEDCOC sedcoc.
         SEDHAL sedhal. SEDOPT sedopt. SEDNONE sednone.
         AS3READ as3read. NOTRANQ notranq. VALIUM valium.
         LIBRIUM librium. LIMBTROL limbtrol. MENRIUM menrium.
         SERAX serax. TRANXENE tranxene. ATIVAN ativan.
         CENTRAX centrax. XANAX xanax. PAXIPAM paxipam.
         BUSPAR buspar. MILTOWN miltown. EQUANIL equanil.
         DEPROL deprol. VISTAR vistar. ATARAX atarax.
         DURRAX durrax. DIAZEPAM diazepam. SKLY skly.
         MEPROB meprob. TRNEWA trnewa. TRNOSP trnosp.
         TRDKNAM trdknam. TRANAGE tranage. TRANTOT trantot.
         TRANREC tranrec. TRALC tralc. TRSED trsed.
         TRSTM trstm. TRANAL tranal. TRMJ trmj.
         TRINH trinh. TRCOC trcoc. TRHAL trhal.
         TROPT tropt. TRNONE trnone. AS4READ as4read.
         NOSTIMS nostims. DEXED dexed. DEXAMYL dexamyl.
         ESKAT eskat. BENZ benz. BIPHET biphet.
         DESOXYN desoxyn. TENUATE tenuate. TEPANIL tepanil.
         DIDREX didrex. PLEGINE plegine. PRELUDIN preludin.
         IONAMIN ionamin. FASTIN fastin. PONDIMIN pondimin.
         VORANIL voranil. SANOREX sanorex. MAZANOR mazanor.
         RITALIN ritalin. CYLERT cylert. DETAMP detamp.
         METHI methi. METHAMP methamp. OBLA obla.
         STIMNEWA stimnewa. STIMNEWB stimnewb. STIMNEWC stimnewc.
         STIMNEWD stimnewd. STIMNOSP stimnosp. STMDKNAM stmdknam.
         STIMAGE stimage. STIMTOT stimtot. STIMREC stimrec.
         STALC stalc. STSED stsed. STTRAN sttran.
         STANAL stanal. STMJ stmj. STINH stinh.
         STCOC stcoc. STHAL sthal. STOPT stopt.
         STNONE stnone. STNEEDLE stneedle. STNDLREC stndlrec.
         AS5READ as5read. ANALNONE analnone. DARVON darvon.
         DOLENE dolene. SK65A sk65a. WYGESIC wygesic.
         LEVODRO levodro. PERCODAN percodan. DEMEROL demerol.
         DILAUD dilaud. TYLCOD tylcod. PHENCOD phencod.
         TALWIN talwin. TALWINNX talwinnx. TALACEN talacen.
         PROPOXY propoxy. CODEINE codeine. ANILERID anilerid.
         MORPHINE morphine. METHDON methdon. STADOL stadol.
         ANALNEWA analnewa. ANALNEWB analnewb. ANLNOSP anlnosp.
         ANLDKNAM anldknam. ANALAGE analage. ANALTOT analtot.
         ANALREC analrec. ANLALC anlalc. ANLSED anlsed.
         ANLTRAN anltran. ANLSTM anlstm. ANLMJ anlmj.
         ANLINH anlinh. ANLCOC anlcoc. ANLHAL anlhal.
         ANLOPT anlopt. ANLNONE anlnone. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJAMT30A mjamt30a.
         MJALC30A mjalc30a. MJYRFREQ mjyrfreq. MJALC mjalc.
         MJSED mjsed. MJTRAN mjtran. MJSTM mjstm.
         MJANAL mjanal. MJINH mjinh. MJCOC mjcoc.
         MJHAL mjhal. MJOPT mjopt. MJNONE mjnone.
         AS7READ as7read. INHAGE inhage. GAS gas.
         SPPAINT sppaint. AEROS aeros. GLUE glue.
         SOLVENT solvent. AMYLNIT amylnit. ETHER ether.
         NITOXID nitoxid. CLEFLU cleflu. INHNEWA inhnewa.
         INHNEWB inhnewb. INHNOSP inhnosp. INHTOT inhtot.
         GAS30A gas30a. SPPAN30A sppan30a. AEROS30A aeros30a.
         GLUE30A glue30a. SOLVN30A solvn30a. AMLNT30A amlnt30a.
         ETHER30A ether30a. NOX30A nox30a. CLFL30A clfl30a.
         INNEW30A innew30a. INNEW30B innew30b. IN30NOSP in30nosp.
         INH30NO inh30no. INHDY30A inhdy30a. INHREC inhrec.
         INHEFF inheff. INHPO inhpo. INHQNC1 inhqnc1f.
         INHQNC2 inhqnc2f. INHQNC3 inhqnc3f. INHQNC4 inhqnc4f.
         INHQNC5 inhqnc5f. INHQNC6 inhqnc6f. INHQNC7 inhqnc7f.
         INHQNC8 inhqnc8f. INHQNC9 inhqnc9f. INHANSY inhansy.
         COCOPP cocopp. COCAGE cocage. COCTOT coctot.
         COCREC cocrec. COCUS30A cocus30a. COC30ALC coc30alc.
         COCYRFRQ cocyrfrq. COCALC cocalc. COCSED cocsed.
         COCTRAN coctran. COCSTM cocstm. COCANAL cocanal.
         COCINH cocinh. COCMJ cocmj. COCHAL cochal.
         COCOPT cocopt. COCNONE cocnone. COCSNIFF cocsniff.
         COCSWAL cocswal. COCIV cociv. FREEBASE freebase.
         COCNEWA cocnewa. COCNOSP cocnosp. CONDLREC condlrec.
         CRAKREC crakrec. CRKAM30A crkam30a. CRAKBUCK crakbuck.
         COCAM30A cocam30a. COCBUCK cocbuck. AS9READ as9read.
         LSD lsd. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. PCP pcp. ECSTASY ecstasy.
         HALNEWA halnewa. HALNOSP halnosp. HALLOPP hallopp.
         HALLAGE hallage. HALLTOT halltot. HALLREC hallrec.
         HAL30USE hal30use. PCPREC pcprec. PCPFLASH pcpflash.
         PCPSENSE pcpsense. PCPFEELV pcpfeelv. PCPACTV pcpactv.
         PCPNEWA pcpnewa. PCPNEWB pcpnewb. PCPNEWC pcpnewc.
         PCPNOSP pcpnosp. PCPNORCT pcpnorct. HALLQCL hallqcl.
         AS10READ as10read. HEROPP heropp. HERAGE herage.
         HERTOT hertot. HERREC herrec. HER30USE her30use.
         HERNEEDL herneedl. HRNDLREC hrndlrec. AS11READ as11read.
         NODRUGS nodrugs. CDCIG cdcig. CDALC cdalc.
         CDSED cdsed. CDTRAN cdtran. CDSTM cdstm.
         CDANAL cdanal. CDMJ cdmj. CDINH cdinh.
         CDCOC cdcoc. CDHALL cdhall. CDHER cdher.
         CDOTHOP cdothop. CDNONE cdnone. EFFCIG effcig.
         EFFALC effalc. EFFSED effsed. EFFTRAN efftran.
         EFFSTM effstm. EFFANAL effanal. EFFMJ effmj.
         EFFINH effinh. EFFCOC effcoc. EFFHALL effhall.
         EFFHER effher. EFFOTHOP effothop. EFFNONE effnone.
         UDAYCIG udaycig. UDAYALC udayalc. UDAYSED udaysed.
         UDAYTRAN udaytran. UDAYSTM udaystm. UDAYANAL udayanal.
         UDAYMJ udaymj. UDAYINH udayinh. UDAYCOC udaycoc.
         UDAYHALL udayhall. UDAYHER udayher. UDAYOTH udayoth.
         UDAYNONE udaynone. DEPCIG depcig. DEPALC depalc.
         DEPSED depsed. DEPTRAN deptran. DEPSTM depstm.
         DEPANAL depanal. DEPMJ depmj. DEPINH depinh.
         DEPCOC depcoc. DEPHALL dephall. DEPHER depher.
         DEPOTHOP depothop. DEPNONE depnone. WSCIG wscig.
         WSALC wsalc. WSSED wssed. WSTRAN wstran.
         WSSTM wsstm. WSANAL wsanal. WSMJ wsmj.
         WSINH wsinh. WSCOC wscoc. WSHALL wshall.
         WSHER wsher. WSOTHOP wsothop. WSNONE wsnone.
         SHRNDLMO shrndlmo. NRSHRNDL nrshrndl. CLEANNDL cleanndl.
         SHRWMALE shrwmale. SHRWSEXP shrwsexp. SHRWRACE shrwrace.
         RSNNOSHR rsnnoshr. NOBOOZYR noboozyr. ALCAGGR alcaggr.
         ALCARGUM alcargum. ALCABSNT alcabsnt. ALCHIGH alchigh.
         ALCJOB alcjob. ALCMATCD alcmatcd. ALCRELCD alcrelcd.
         ALCFRDCD alcfrdcd. ALCTOSS alctoss. ALCHOLIC alcholic.
         ALCDRUNK alcdrunk. ALCINTOX alcintox. ALCREM alcrem.
         ALCQUICK alcquick. ALCMORN alcmorn. ALCSHOOK alcshook.
         ALCALONE alcalone. ALCBRKPM alcbrkpm. AS13NONE as13none.
         DRDEPRSS drdeprss. DEPDRG1A depdrg1a. DEPDRG2A depdrg2a.
         DEPDRG3A depdrg3a. DEPDRG4A depdrg4a. DEPDRG5A depdrg5a.
         DRARGUM drargum. ARGDRG1A argdrg1a. ARGDRG2A argdrg2a.
         ARGDRG3A argdrg3a. ARGDRG4A argdrg4a. ARGDRG5A argdrg5a.
         DRALONE dralone. ALNDRG1A alndrg1a. ALNDRG2A alndrg2a.
         ALNDRG3A alndrg3a. ALNDRG4A alndrg4a. ALNDRG5A alndrg5a.
         DRANX dranx. ANXDRG1A anxdrg1a. ANXDRG2A anxdrg2a.
         ANXDRG3A anxdrg3a. ANXDRG4A anxdrg4a. ANXDRG5A anxdrg5a.
         DRHEALTH drhealth. HLTDRG1A hltdrg1a. HLTDRG2A hltdrg2a.
         HLTDRG3A hltdrg3a. HLTDRG4A hltdrg4a. HLTDRG5A hltdrg5a.
         DRNTHINK drnthink. NTKDRG1A ntkdrg1a. NTKDRG2A ntkdrg2a.
         NTKDRG3A ntkdrg3a. NTKDRG4A ntkdrg4a. NTKDRG5A ntkdrg5a.
         DRUPSET drupset. UPSDRG1A upsdrg1a. UPSDRG2A upsdrg2a.
         UPSDRG3A upsdrg3a. UPSDRG4A upsdrg4a. UPSDRG5A upsdrg5a.
         DRLSWORK drlswork. LSWDRG1A lswdrg1a. LSWDRG2A lswdrg2a.
         LSWDRG3A lswdrg3a. LSWDRG4A lswdrg4a. LSWDRG5A lswdrg5a.
         DRSUSPIC drsuspic. SSPDRG1A sspdrg1a. SSPDRG2A sspdrg2a.
         SSPDRG3A sspdrg3a. SSPDRG4A sspdrg4a. SSPDRG5A sspdrg5a.
         DRCOPE drcope. CPEDRG1A cpedrg1a. CPEDRG2A cpedrg2a.
         CPEDRG3A cpedrg3a. CPEDRG4A cpedrg4a. CPEDRG5A cpedrg5a.
         DREMGMED dremgmed. EMDRG1A emdrg1a. EMDRG2A emdrg2a.
         EMDRG3A emdrg3a. EMDRG4A emdrg4a. EMDRG5A emdrg5a.
         RSKPKCIG rskpkcig. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKTRYPCP rktrypcp. RKPCPREG rkpcpreg. RKTRYHER rktryher.
         RKHERREG rkherreg. RKTRYCOC rktrycoc. RKCOCOCC rkcococc.
         RKCOCREG rkcocreg. RKCRKOCC rkcrkocc. RK2DRINK rk2drink.
         RK5DRINK rk5drink. RSKBINGE rskbinge. HIGHBP highbp.
         BPMED bpmed. WALKPAIN walkpain. TIMEPAIN timepain.
         UPSHOR upshor. ASTHMA asthma. TRPSYCH trpsych.
         HEART heart. FLU flu. ALLERG allerg.
         HOSPYR hospyr. SOREYR soreyr. RUNNYYR runnyyr.
         COUGHYR coughyr. PHLEGMYR phlegmyr. HEALTHYR healthyr.
         MARITAL marital. NOMARR nomarr. WORKSTAT workstat.
         PAYMO paymo. PAYYR payyr. NO5JOB no5job.
         WORKDAYS workdays. WORKBLAH workblah. CWE cwe.
         FULLPART fullpart. EDUC educ. ENROLLD enrolld.
         SCHPLANS schplans. STUDENT student. SCHDAYS schdays.
         SKIPPED skipped. MILES miles. ACCID accid.
         NOCHILD nochild. MOTHER mother. STEPMOM stepmom.
         FATHER father. STEPDAD stepdad. SPOUSE spouse.
         INLAW inlaw. OWNCHILD ownchild. STEPCHLD stepchld.
         BROSIS brosis. OTHREL othrel. FRIENDS friends.
         OTHERNON othernon. SERVICE service. MILSTAT milstat.
         MOVDAWAY movdaway. DORM dorm. MILBASE milbase.
         HOSP hosp. TELNO telno. MOVES moves.
         INCOME income. BAP bap. EAP eap.
         LANGVER langver. UNDINT undint. COOPINT coopint.
         PRIVACY privacy. PPRES ppres. SPRES spres.
         PARPRES parpres. OARPRES oarpres. OAPRES oapres.
         CPRES cpres. OPRESSPA opresspa. OPRESSPB opresspb.
         OPRESNSP opresnsp. REGION region. DIVISION division.
         IIAGE iiage. AGEGR agegr. ORAGEGR oragegr.
         SEX sex. ORSEX orsex. IRRACE irrace.
         IIRACE iirace. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRALCRC iralcrc.
         IIALCRC iialcrc. IRMJRC irmjrc. IIMJRC iimjrc.
         IRCOCRC ircocrc. IICOCRC iicocrc. IRSEDRC irsedrc.
         IISEDRC iisedrc. IRTRNRC irtrnrc. IITRNRC iitrnrc.
         IRSTMRC irstmrc. IISTMRC iistmrc. IRANLRC iranlrc.
         IIANLRC iianlrc. IRCIGRC ircigrc. IICIGRC iicigrc.
         IROTBRC irotbrc. IIOTBRC iiotbrc. IRINHRC irinhrc.
         IIINHRC iiinhrc. IRCRKRC ircrkrc. IICRKRC iicrkrc.
         IRHALRC irhalrc. IIHALRC iihalrc. IRHERRC irherrc.
         IIHERRC iiherrc. IRPCPRC irpcprc. IIPCPRC iipcprc.
         IRALCFQ iralcfq. IIALCFQ iialcfq. IRMJFQ irmjfq.
         IIMJFQ iimjfq. IRCOCFQ ircocfq. IICOCFQ iicocfq.
         CATAGE catage. CATAG2 catag2ff. RACE race.
         EDUCCAT educcat. EMPSTAT empstat. SMOKCOK smokcok.
         CONDLRC2 condlrcf. HALFLAG halflag. HALYR halyr.
         HALMON halmon. PCPFLAG pcpflag. PCPYR pcpyr.
         PCPMON pcpmon. STMFLAG stmflag. STMYR stmyr.
         STMMON stmmon. SEDFLAG sedflag. SEDYR sedyr.
         SEDMON sedmon. TRQFLAG trqflag. TRQYR trqyr.
         TRQMON trqmon. ANLFLAG anlflag. ANLYR anlyr.
         ANLMON anlmon. ALCFLAG alcflag. ALCYR alcyr.
         ALCMON alcmon. CIGFLAG cigflag. CIGYR cigyr.
         CIGMON cigmon. SMKFLAG smkflag. SMKYR smkyr.
         SMKMON smkmon. HERFLAG herflag. HERYR heryr.
         HERMON hermon. MRJFLAG mrjflag. MRJYR mrjyr.
         MRJMON mrjmon. COCFLAG cocflag. COCYR cocyr.
         COCMON cocmon. CRKFLAG crkflag. CRKYR crkyr.
         CRKMON crkmon. INHFLAG inhflag. INHYR inhyr.
         INHMON inhmon. NEEDLREC needlrec. NEDFLAG nedflag.
         NEDYR nedyr. COCYRF cocyrf. COCMONF cocmonf.
         COCWKF cocwkf. ALCYRF alcyrf. ALCMONF alcmonf.
         ALCWKF alcwkf. MRJYRF mrjyrf. MRJMONF mrjmonf.
         MRJWKF mrjwkf. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAG sumflag. SUMYR sumyr.
         SUMMON summon. MJOFLAG mjoflag. MJOYR2 mjoyr2ff.
         MJOMON2 mjomon2f. CWEOCC2 cweocc2f. ROCCUP2 roccup2f.
         BUSINES2 businesf. CWEBUS2 cwebus2f. POPDEN popden.
         MRJMON2 mrjmon2f. ALCMON2 alcmon2f. CIGMON2 cigmon2f.
         LSD2 lsd2ffff. PEYOTE2 peyote2f. MESC2 mesc2fff.
         PSILCY2 psilcy2f. GAS2 gas2ffff. SPPAINT2 sppaintf.
         AEROS2 aeros2ff. GLUE2 glue2fff. SOLVENT2 solventf.
         AMYLNIT2 amylnitf. ETHER2 ether2ff. NITOXID2 nitoxidf.
         CLEFLU2 cleflu2f. COCSNIF2 cocsni0f. FREEBAS2 freebasf.
         COCSWAL2 cocswalf. COCIV2 cociv2ff. COCNEWA2 cocnewaf.
         MJTOT2 mjtot2ff. COCTOT2 coctot2f. MJTOT3 mjtot3ff.
         COCTOT3 coctot3f. MJDY30A2 mjdy30af. ALCDAYS2 alcdaysf.
         RACESEX racesex. NOTMARJ notmarj. EDUCCAT2 educcatf.
         EMPSTAT2 empstatf. MJDY30A3 mjdy300f. ALCDAYS3 alcday0f.
         DRINKER drinker. HVYDRK hvydrk. AVCIG2 avcig2ff.
         IRDEP irdep. IRARG irarg. IRALN iraln.
         IRANX iranx. IRHLT irhlt. IRNTK irntk.
         IRUPS irups. IRLSW irlsw. IRSSP irssp.
         IRCPE ircpe. IREMG iremg. IRDEP1 irdep1ff.
         IRDEP2 irdep2ff. IRDEP3 irdep3ff. IRDEP4 irdep4ff.
         IRDEP5 irdep5ff. IRARG1 irarg1ff. IRARG2 irarg2ff.
         IRARG3 irarg3ff. IRARG4 irarg4ff. IRARG5 irarg5ff.
         IRALN1 iraln1ff. IRALN2 iraln2ff. IRALN3 iraln3ff.
         IRALN4 iraln4ff. IRALN5 iraln5ff. IRANX1 iranx1ff.
         IRANX2 iranx2ff. IRANX3 iranx3ff. IRANX4 iranx4ff.
         IRANX5 iranx5ff. IRHLT1 irhlt1ff. IRHLT2 irhlt2ff.
         IRHLT3 irhlt3ff. IRHLT4 irhlt4ff. IRHLT5 irhlt5ff.
         IRNTK1 irntk1ff. IRNTK2 irntk2ff. IRNTK3 irntk3ff.
         IRNTK4 irntk4ff. IRNTK5 irntk5ff. IRUPS1 irups1ff.
         IRUPS2 irups2ff. IRUPS3 irups3ff. IRUPS4 irups4ff.
         IRUPS5 irups5ff. IRLSW1 irlsw1ff. IRLSW2 irlsw2ff.
         IRLSW3 irlsw3ff. IRLSW4 irlsw4ff. IRLSW5 irlsw5ff.
         IRSSP1 irssp1ff. IRSSP2 irssp2ff. IRSSP3 irssp3ff.
         IRSSP4 irssp4ff. IRSSP5 irssp5ff. IRCPE1 ircpe1ff.
         IRCPE2 ircpe2ff. IRCPE3 ircpe3ff. IRCPE4 ircpe4ff.
         IRCPE5 ircpe5ff. IREMG1 iremg1ff. IREMG2 iremg2ff.
         IREMG3 iremg3ff. IREMG4 iremg4ff. IREMG5 iremg5ff.
         ANYPROB anyprob. TWOPROB twoprob. THREPROB threprob.
         DEPCIG2 depcig2f. DEPALC2 depalc2f. DEPMRJ2 depmrj2f.
         DEPCOC2 depcoc2f. ARGCIG2 argcig2f. ARGALC2 argalc2f.
         ARGMRJ2 argmrj2f. ARGCOC2 argcoc2f. ALNCIG2 alncig2f.
         ALNALC2 alnalc2f. ALNMRJ2 alnmrj2f. ALNCOC2 alncoc2f.
         ANXCIG2 anxcig2f. ANXALC2 anxalc2f. ANXMRJ2 anxmrj2f.
         ANXCOC2 anxcoc2f. HLTCIG2 hltcig2f. HLTALC2 hltalc2f.
         HLTMRJ2 hltmrj2f. HLTCOC2 hltcoc2f. NTKCIG2 ntkcig2f.
         NTKALC2 ntkalc2f. NTKMRJ2 ntkmrj2f. NTKCOC2 ntkcoc2f.
         UPSCIG2 upscig2f. UPSALC2 upsalc2f. UPSMRJ2 upsmrj2f.
         UPSCOC2 upscoc2f. LSWCIG2 lswcig2f. LSWALC2 lswalc2f.
         LSWMRJ2 lswmrj2f. LSWCOC2 lswcoc2f. SSPCIG2 sspcig2f.
         SSPALC2 sspalc2f. SSPMRJ2 sspmrj2f. SSPCOC2 sspcoc2f.
         CPECIG2 cpecig2f. CPEALC2 cpealc2f. CPEMRJ2 cpemrj2f.
         CPECOC2 cpecoc2f. EMCIG2 emcig2ff. EMALC2 emalc2ff.
         EMMRJ2 emmrj2ff. EMCOC2 emcoc2ff. PRB1CIG prb1cig.
         PRB1ALC prb1alc. PRB1MRJ prb1mrj. PRB1COC prb1coc.
         PRB2CIG prb2cig. PRB2ALC prb2alc. PRB2MRJ prb2mrj.
         PRB2COC prb2coc. PRB3CIG prb3cig. PRB3ALC prb3alc.
         PRB3MRJ prb3mrj. PRB3COC prb3coc. IRCDCIG ircdcig.
         IRCDALC ircdalc. IRCDMJ ircdmj. IRCDCOC ircdcoc.
         IREFCIG irefcig. IREFALC irefalc. IREFMJ irefmj.
         IREFCOC irefcoc. IRUDCIG irudcig. IRUDALC irudalc.
         IRUDMJ irudmj. IRUDCOC irudcoc. IRDPCIG irdpcig.
         IRDPALC irdpalc. IRDPMJ irdpmj. IRDPCOC irdpcoc.
         IRWSCIG irwscig. IRWSALC irwsalc. IRWSMJ irwsmj.
         IRWSCOC irwscoc. ALCPROBS alcprobs. MJPROBS mjprobs.
         COCPROBS cocprobs. CIGPROBS cigprobs. IRALCAGG iralcagg.
         IRALCARG iralcarg. IRALCABS iralcabs. IRALCHIG iralchig.
         IRALCJOB iralcjob. IRALCMAT iralcmat. IRALCREL iralcrel.
         IRALCFRD iralcfrd. IRALCTOS iralctos. IRALCHOL iralchol.
         IRALCDRU iralcdru. IRALCINT iralcint. IRALCREM iralcrem.
         IRALCQUI iralcqui. IRALCMOR iralcmor. IRALCSHO iralcsho.
         IRALCALO iralcalo. IRALCBRK iralcbrk. IRNOBOOZ irnobooz.
         ANYALC anyalc. THREALC threalc. DRUNKYR2 drunkyrf.
         IRAS13 iras13ff. AVCIG3 avcig3ff. IRNODRUG irnodrug.
         ALCONLYL alconlyl. ALCONLYY alconlyy. ALCONLYM alconlym.
         ILLONLYL illonlyl. ILLONLYY illonlyy. ILLONLYM illonlym.
         MRJONLYL mrjonlyl. MRJONLYY mrjonlyy. MRJONLYM mrjonlym.
         PSYONLYL psyonlyl. PSYONLYY psyonlyy. PSYONLYM psyonlym.
         OTHONLYL othonlyl. OTHONLYY othonlyy. OTHONLYM othonlym.
         ALCILLL alcilll. ALCILLY alcilly. ALCILLM alcillm.
         ALCMRJL alcmrjl. ALCMRJY alcmrjy. ALCMRJM alcmrjm.
         ALCPSYL alcpsyl. ALCPSYY alcpsyy. ALCPSYM alcpsym.
         ALCOTHL alcothl. ALCOTHY alcothy. ALCOTHM alcothm.
         SUB1LIF sub1lif. SUB2LIF sub2lif. SUB3LIF sub3lif.
         SUB1YR sub1yr. SUB2YR sub2yr. SUB3YR sub3yr.
         SUB1MON sub1mon. SUB2MON sub2mon. SUB3MON sub3mon.
          ;
*/

RUN ;
